/**
 * StayEase - 景区民宿发展管理系统
 * 全局JavaScript文件
 */

document.addEventListener('DOMContentLoaded', function () {
    // 初始化导航菜单高亮
    initActiveNavItem();

    // 初始化表单验证
    initFormValidation();

    // 初始化警告消息自动关闭
    initAlertDismiss();

    // 初始化模块内容加载
    initModuleContentLoad();
});

/**
 * 初始化导航菜单高亮
 */
function initActiveNavItem() {
    // 获取当前页面URL
    const currentUrl = window.location.pathname;

    // 查找所有导航链接
    const navItems = document.querySelectorAll('.module-nav-item');

    // 遍历导航链接，找到匹配当前URL的链接并添加active类
    navItems.forEach(item => {
        const href = item.getAttribute('href');
        if (href && currentUrl.includes(href)) {
            item.classList.add('active');
        }
    });
}

/**
 * 初始化表单验证
 */
function initFormValidation() {
    // 获取所有需要验证的表单
    const forms = document.querySelectorAll('form[data-validate="true"]');

    forms.forEach(form => {
        form.addEventListener('submit', function (event) {
            let isValid = true;

            // 获取所有必填字段
            const requiredFields = form.querySelectorAll('[required]');

            // 验证每个必填字段
            requiredFields.forEach(field => {
                if (!field.value.trim()) {
                    isValid = false;

                    // 添加错误样式
                    field.classList.add('is-invalid');

                    // 显示错误消息
                    const errorElement = field.nextElementSibling;
                    if (errorElement && errorElement.classList.contains('error-message')) {
                        errorElement.textContent = '此字段不能为空';
                        errorElement.style.display = 'block';
                    }
                } else {
                    // 移除错误样式
                    field.classList.remove('is-invalid');

                    // 隐藏错误消息
                    const errorElement = field.nextElementSibling;
                    if (errorElement && errorElement.classList.contains('error-message')) {
                        errorElement.style.display = 'none';
                    }
                }
            });

            // 如果表单无效，阻止提交
            if (!isValid) {
                event.preventDefault();
            }
        });
    });
}

/**
 * 初始化警告消息自动关闭
 */
function initAlertDismiss() {
    // 获取所有警告消息
    const alerts = document.querySelectorAll('.alert');

    // 为每个警告消息设置自动关闭
    alerts.forEach(alert => {
        // 创建关闭按钮
        const closeButton = document.createElement('button');
        closeButton.innerHTML = '&times;';
        closeButton.className = 'alert-close';
        closeButton.addEventListener('click', function () {
            alert.style.display = 'none';
        });

        // 添加关闭按钮到警告消息
        alert.appendChild(closeButton);

        // 设置自动关闭（5秒后）
        setTimeout(function () {
            alert.style.opacity = '0';
            setTimeout(function () {
                alert.style.display = 'none';
            }, 500);
        }, 5000);
    });
}

/**
 * 初始化模块内容加载
 */
function initModuleContentLoad() {
    // 获取所有模块导航链接
    const moduleNavItems = document.querySelectorAll('.module-nav-item[data-ajax="true"]');

    // 获取内容容器
    const contentContainer = document.querySelector('.module-content');

    if (!contentContainer) return;

    // 为每个导航链接添加点击事件
    moduleNavItems.forEach(item => {
        item.addEventListener('click', function (event) {
            event.preventDefault();

            // 获取链接URL
            const url = this.getAttribute('href');

            // 移除所有导航项的active类
            moduleNavItems.forEach(navItem => {
                navItem.classList.remove('active');
            });

            // 为当前点击的导航项添加active类
            this.classList.add('active');

            // 使用AJAX加载内容
            fetch(url)
                .then(response => response.text())
                .then(html => {
                    contentContainer.innerHTML = html;

                    // 更新浏览器历史记录
                    history.pushState({}, '', url);

                    // 重新初始化表单验证
                    initFormValidation();
                })
                .catch(error => {
                    console.error('加载内容失败:', error);
                    contentContainer.innerHTML = '<div class="alert alert-error">加载内容失败，请重试。</div>';
                });
        });
    });
}

/**
 * 确认对话框
 * @param {string} message 确认消息
 * @param {function} callback 确认后的回调函数
 */
function confirmAction(message, callback) {
    if (confirm(message)) {
        callback();
    }
}

/**
 * 格式化日期时间
 * @param {string|Date} datetime 日期时间
 * @param {string} format 格式 (默认: YYYY-MM-DD HH:mm:ss)
 * @returns {string} 格式化后的日期时间
 */
function formatDateTime(datetime, format = 'YYYY-MM-DD HH:mm:ss') {
    const date = new Date(datetime);

    const year = date.getFullYear();
    const month = String(date.getMonth() + 1).padStart(2, '0');
    const day = String(date.getDate()).padStart(2, '0');
    const hours = String(date.getHours()).padStart(2, '0');
    const minutes = String(date.getMinutes()).padStart(2, '0');
    const seconds = String(date.getSeconds()).padStart(2, '0');

    return format
        .replace('YYYY', year)
        .replace('MM', month)
        .replace('DD', day)
        .replace('HH', hours)
        .replace('mm', minutes)
        .replace('ss', seconds);
}

/**
 * 格式化货币
 * @param {number} amount 金额
 * @param {string} currency 货币符号 (默认: ¥)
 * @returns {string} 格式化后的货币
 */
function formatCurrency(amount, currency = '¥') {
    return currency + amount.toFixed(2).replace(/\d(?=(\d{3})+\.)/g, '$&,');
}

/**
 * 显示加载中指示器
 * @param {HTMLElement} container 容器元素
 */
function showLoading(container) {
    // 创建加载中指示器
    const loadingElement = document.createElement('div');
    loadingElement.className = 'loading-indicator';
    loadingElement.innerHTML = '<div class="spinner"></div><p>加载中...</p>';

    // 清空容器并添加加载中指示器
    container.innerHTML = '';
    container.appendChild(loadingElement);
}

/**
 * 隐藏加载中指示器
 * @param {HTMLElement} container 容器元素
 */
function hideLoading(container) {
    // 移除加载中指示器
    const loadingElement = container.querySelector('.loading-indicator');
    if (loadingElement) {
        container.removeChild(loadingElement);
    }
} 