<?php

/**
 * 通用函数库
 */

/**
 * 安全过滤输入数据
 * @param string $data 需要过滤的数据
 * @return string 过滤后的数据
 */
function sanitize($data)
{
    global $conn;
    $data = trim($data);
    $data = stripslashes($data);
    $data = htmlspecialchars($data);
    if ($conn) {
        $data = $conn->real_escape_string($data);
    }
    return $data;
}

/**
 * 生成随机字符串
 * @param int $length 字符串长度
 * @return string 随机字符串
 */
function generateRandomString($length = 10)
{
    $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
    $charactersLength = strlen($characters);
    $randomString = '';
    for ($i = 0; $i < $length; $i++) {
        $randomString .= $characters[rand(0, $charactersLength - 1)];
    }
    return $randomString;
}

/**
 * 检查用户是否已登录
 * @return bool 是否已登录
 */
function isLoggedIn()
{
    return isset($_SESSION['user_id']);
}

/**
 * 检查用户是否有权限访问
 * @param string $requiredRole 需要的角色
 * @return bool 是否有权限
 */
function hasPermission($requiredRole)
{
    if (!isLoggedIn()) {
        return false;
    }

    // 如果用户是管理员，拥有所有权限
    if ($_SESSION['user_role'] == 'admin') {
        return true;
    }

    // 检查用户角色是否匹配所需角色
    return $_SESSION['user_role'] == $requiredRole;
}

/**
 * 记录系统日志
 * @param string $action 操作类型
 * @param string $description 操作描述
 * @param int $userId 用户ID，默认为当前登录用户
 * @return bool 是否记录成功
 */
function logActivity($action, $description, $userId = null)
{
    global $conn;

    if (!$conn) {
        return false;
    }

    if ($userId === null && isset($_SESSION['user_id'])) {
        $userId = $_SESSION['user_id'];
    }

    $action = sanitize($action);
    $description = sanitize($description);
    $userId = (int)$userId;
    $ipAddress = $_SERVER['REMOTE_ADDR'];

    $sql = "INSERT INTO system_logs (user_id, action, description, ip_address, created_at) 
            VALUES (?, ?, ?, ?, NOW())";

    $stmt = $conn->prepare($sql);
    $stmt->bind_param("isss", $userId, $action, $description, $ipAddress);

    return $stmt->execute();
}

/**
 * 显示提示消息
 * @param string $message 消息内容
 * @param string $type 消息类型 (success, error, warning, info)
 * @return string HTML消息
 */
function showAlert($message, $type = 'info')
{
    return '<div class="alert alert-' . $type . '">' . $message . '</div>';
}

/**
 * 重定向到指定页面
 * @param string $url 目标URL
 */
function redirect($url)
{
    header("Location: $url");
    exit;
}

/**
 * 获取当前页面名称
 * @return string 当前页面名称
 */
function getCurrentPage()
{
    return basename($_SERVER['PHP_SELF']);
}

/**
 * 格式化日期时间
 * @param string $datetime 日期时间字符串
 * @param string $format 格式化模式
 * @return string 格式化后的日期时间
 */
function formatDateTime($datetime, $format = 'Y-m-d H:i:s')
{
    $date = new DateTime($datetime);
    return $date->format($format);
}

/**
 * 上传文件
 * @param array $file $_FILES数组中的文件
 * @param string $targetDir 目标目录
 * @param array $allowedTypes 允许的文件类型
 * @param int $maxSize 最大文件大小(字节)
 * @return array 上传结果 ['success' => bool, 'message' => string, 'filename' => string]
 */
function uploadFile($file, $targetDir = UPLOAD_PATH, $allowedTypes = ['jpg', 'jpeg', 'png', 'gif'], $maxSize = 5242880)
{
    // 检查目录是否存在，不存在则创建
    if (!file_exists($targetDir)) {
        mkdir($targetDir, 0777, true);
    }

    // 检查文件是否通过HTTP POST上传
    if (!is_uploaded_file($file['tmp_name'])) {
        return ['success' => false, 'message' => '文件未通过HTTP POST上传'];
    }

    // 检查文件大小
    if ($file['size'] > $maxSize) {
        return ['success' => false, 'message' => '文件大小超过限制'];
    }

    // 检查文件类型
    $fileType = strtolower(pathinfo($file['name'], PATHINFO_EXTENSION));
    if (!in_array($fileType, $allowedTypes)) {
        return ['success' => false, 'message' => '不支持的文件类型'];
    }

    // 生成唯一文件名
    $newFilename = uniqid() . '.' . $fileType;
    $targetFile = $targetDir . $newFilename;

    // 尝试上传文件
    if (move_uploaded_file($file['tmp_name'], $targetFile)) {
        return [
            'success' => true,
            'message' => '文件上传成功',
            'filename' => $newFilename,
            'filepath' => $targetFile
        ];
    } else {
        return ['success' => false, 'message' => '文件上传失败'];
    }
}

/**
 * 生成预订号
 * 格式：BK + 年月日 + 4位随机数
 * 例如：BK2024031512345
 * @return string
 */
function generateBookingNumber()
{
    $prefix = 'BK';
    $date = date('Ymd');
    $random = str_pad(mt_rand(1, 9999), 4, '0', STR_PAD_LEFT);
    return $prefix . $date . $random;
}

/**
 * 记录系统操作日志
 * 
 * @param int $user_id 用户ID
 * @param string $action 操作描述
 * @return bool 操作是否成功
 */
function logSystemAction($user_id, $action)
{
    global $conn;

    try {
        // 获取用户名
        $username = '';
        $stmt = $conn->prepare("SELECT username FROM users WHERE id = ?");
        if ($stmt) {
            $stmt->bind_param("i", $user_id);
            $stmt->execute();
            $stmt->bind_result($username);
            $stmt->fetch();
            $stmt->close();
        }

        // 记录操作日志
        $stmt = $conn->prepare("INSERT INTO system_logs (user_id, username, action, ip_address, user_agent) VALUES (?, ?, ?, ?, ?)");
        if ($stmt) {
            $ip = $_SERVER['REMOTE_ADDR'] ?? '';
            $userAgent = $_SERVER['HTTP_USER_AGENT'] ?? '';
            $stmt->bind_param("issss", $user_id, $username, $action, $ip, $userAgent);
            $result = $stmt->execute();
            $stmt->close();
            return $result;
        }
        return false;
    } catch (Exception $e) {
        // 错误处理
        error_log("记录系统日志失败: " . $e->getMessage());
        return false;
    }
}
