<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 获取所有可用房间
$roomSql = "SELECT r.id, r.room_number, r.floor, rt.name as room_type, rt.base_price, r.price_adjustment 
            FROM rooms r 
            JOIN room_types rt ON r.room_type_id = rt.id 
            WHERE r.status = 'available' 
            ORDER BY r.floor, r.room_number";
$roomResult = $conn->query($roomSql);
$rooms = [];
if ($roomResult && $roomResult->num_rows > 0) {
    while ($row = $roomResult->fetch_assoc()) {
        $rooms[] = $row;
    }
}

// 获取所有房型
$roomTypeSql = "SELECT id, name, base_price FROM room_types WHERE status = 'active' ORDER BY name";
$roomTypeResult = $conn->query($roomTypeSql);
$roomTypes = [];
if ($roomTypeResult && $roomTypeResult->num_rows > 0) {
    while ($row = $roomTypeResult->fetch_assoc()) {
        $roomTypes[] = $row;
    }
}

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // 获取表单数据
    $guestName = sanitize($_POST['guest_name']);
    $guestPhone = sanitize($_POST['guest_phone']);
    $guestEmail = sanitize($_POST['guest_email']);
    $guestIdType = sanitize($_POST['guest_id_type']);
    $guestIdNumber = sanitize($_POST['guest_id_number']);
    $checkInDate = sanitize($_POST['check_in_date']);
    $checkOutDate = sanitize($_POST['check_out_date']);
    $adults = (int)$_POST['adults'];
    $children = (int)$_POST['children'];
    $bookingSource = sanitize($_POST['source']);
    $specialRequests = sanitize(isset($_POST['special_requests']) ? $_POST['special_requests'] : '');
    $totalAmount = (float)$_POST['total_amount'];
    $depositAmount = (float)$_POST['deposit'];
    $status = sanitize($_POST['status']);
    $selectedRooms = isset($_POST['selected_rooms']) ? $_POST['selected_rooms'] : [];

    // 验证数据
    $errors = [];

    if (empty($guestName)) {
        $errors[] = '客人姓名不能为空';
    }

    if (empty($guestPhone)) {
        $errors[] = '联系电话不能为空';
    }

    if (empty($checkInDate) || empty($checkOutDate)) {
        $errors[] = '入住日期和退房日期不能为空';
    } elseif (strtotime($checkInDate) >= strtotime($checkOutDate)) {
        $errors[] = '入住日期必须早于退房日期';
    }

    if ($adults <= 0) {
        $errors[] = '成人数量必须大于0';
    }

    if (empty($selectedRooms)) {
        $errors[] = '请至少选择一个房间';
    }

    // 如果没有错误，插入数据
    if (empty($errors)) {
        // 生成预订号
        $bookingNumber = 'BK' . date('Ymd') . rand(1000, 9999);

        // 开始事务
        $conn->begin_transaction();

        try {
            // 插入预订信息
            $sql = "INSERT INTO bookings (
                        booking_number, guest_name, guest_phone, guest_email, 
                        guest_id_type, guest_id_number, check_in_date, check_out_date, 
                        adults, children, booking_source, special_requests, 
                        total_amount, deposit_amount, status, created_at
                    ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, NOW())";
            $stmt = $conn->prepare($sql);

            // 检查SQL准备是否成功
            if ($stmt === false) {
                throw new Exception("SQL准备失败: " . $conn->error . " SQL: " . $sql);
            }

            $stmt->bind_param(
                "ssssssssiissdds",
                $bookingNumber,
                $guestName,
                $guestPhone,
                $guestEmail,
                $guestIdType,
                $guestIdNumber,
                $checkInDate,
                $checkOutDate,
                $adults,
                $children,
                $bookingSource,
                $specialRequests,
                $totalAmount,
                $depositAmount,
                $status
            );
            $stmt->execute();

            $bookingId = $conn->insert_id;

            // 插入预订房间关联
            foreach ($selectedRooms as $roomId) {
                $roomId = (int)$roomId;

                // 获取房间价格
                $roomPriceSql = "SELECT r.price_adjustment, rt.base_price 
                                 FROM rooms r 
                                 JOIN room_types rt ON r.room_type_id = rt.id 
                                 WHERE r.id = ?";
                $roomPriceStmt = $conn->prepare($roomPriceSql);
                if ($roomPriceStmt === false) {
                    throw new Exception("SQL准备失败: " . $conn->error . " SQL: " . $roomPriceSql);
                }
                $roomPriceStmt->bind_param("i", $roomId);
                $roomPriceStmt->execute();
                $roomPriceResult = $roomPriceStmt->get_result();
                $roomPrice = $roomPriceResult->fetch_assoc();

                $roomRate = $roomPrice['base_price'] + $roomPrice['price_adjustment'];

                // 插入预订房间关联
                $bookingRoomSql = "INSERT INTO booking_rooms (booking_id, room_id, room_rate) VALUES (?, ?, ?)";
                $bookingRoomStmt = $conn->prepare($bookingRoomSql);
                if ($bookingRoomStmt === false) {
                    throw new Exception("SQL准备失败: " . $conn->error . " SQL: " . $bookingRoomSql);
                }
                $bookingRoomStmt->bind_param("iid", $bookingId, $roomId, $roomRate);
                $bookingRoomStmt->execute();

                // 更新房间状态
                if ($status == 'confirmed') {
                    $updateRoomSql = "UPDATE rooms SET status = 'booked' WHERE id = ?";
                    $updateRoomStmt = $conn->prepare($updateRoomSql);
                    if ($updateRoomStmt === false) {
                        throw new Exception("SQL准备失败: " . $conn->error . " SQL: " . $updateRoomSql);
                    }
                    $updateRoomStmt->bind_param("i", $roomId);
                    $updateRoomStmt->execute();
                }
            }

            // 提交事务
            $conn->commit();

            // 记录操作日志
            logActivity('add_booking', '添加预订: ' . $bookingNumber);

            // 设置成功消息并重定向
            $_SESSION['success_message'] = '预订添加成功';
            header('Location: index.php?page=booking_list');
            exit;
        } catch (Exception $e) {
            // 回滚事务
            $conn->rollback();
            $errors[] = '添加预订失败: ' . $e->getMessage();
        }
    }
}

// 预设值
$presetCheckInDate = isset($_GET['check_in_date']) ? $_GET['check_in_date'] : date('Y-m-d');
$presetRoomId = isset($_GET['room_id']) ? (int)$_GET['room_id'] : 0;
$presetNights = isset($_GET['nights']) ? (int)$_GET['nights'] : 1;
$presetCheckOutDate = date('Y-m-d', strtotime($presetCheckInDate . ' + ' . $presetNights . ' days'));
?>

<div class="content-wrapper">
    <div class="page-header">
        <h2>添加预订</h2>
        <nav class="breadcrumb">
            <a href="index.php">概览</a> /
            <a href="index.php?page=booking_list">订单列表</a> /
            <span>添加预订</span>
        </nav>
    </div>

    <?php if (!empty($errors)): ?>
        <div class="alert alert-error">
            <ul>
                <?php foreach ($errors as $error): ?>
                    <li><?php echo $error; ?></li>
                <?php endforeach; ?>
            </ul>
        </div>
    <?php endif; ?>

    <div class="card">
        <div class="card-body">
            <form method="post" action="" class="form-horizontal">
                <div class="form-section">
                    <h3>客人信息</h3>

                    <div class="form-row">
                        <div class="form-group col-md-6">
                            <label for="guest_name">客人姓名 <span class="required">*</span></label>
                            <input type="text" id="guest_name" name="guest_name" value="<?php echo isset($_POST['guest_name']) ? htmlspecialchars($_POST['guest_name']) : ''; ?>" required>
                        </div>

                        <div class="form-group col-md-6">
                            <label for="guest_phone">联系电话 <span class="required">*</span></label>
                            <input type="text" id="guest_phone" name="guest_phone" value="<?php echo isset($_POST['guest_phone']) ? htmlspecialchars($_POST['guest_phone']) : ''; ?>" required>
                        </div>
                    </div>

                    <div class="form-row">
                        <div class="form-group col-md-6">
                            <label for="guest_email">电子邮箱</label>
                            <input type="email" id="guest_email" name="guest_email" value="<?php echo isset($_POST['guest_email']) ? htmlspecialchars($_POST['guest_email']) : ''; ?>">
                        </div>

                        <div class="form-group col-md-6">
                            <label for="source">预订来源</label>
                            <select id="source" name="source">
                                <option value="direct" <?php echo (isset($_POST['source']) && $_POST['source'] == 'direct') ? 'selected' : ''; ?>>直接预订</option>
                                <option value="website" <?php echo (isset($_POST['source']) && $_POST['source'] == 'website') ? 'selected' : ''; ?>>官网</option>
                                <option value="phone" <?php echo (isset($_POST['source']) && $_POST['source'] == 'phone') ? 'selected' : ''; ?>>电话</option>
                                <option value="email" <?php echo (isset($_POST['source']) && $_POST['source'] == 'email') ? 'selected' : ''; ?>>邮件</option>
                                <option value="walk_in" <?php echo (isset($_POST['source']) && $_POST['source'] == 'walk_in') ? 'selected' : ''; ?>>门店</option>
                                <option value="ota" <?php echo (isset($_POST['source']) && $_POST['source'] == 'ota') ? 'selected' : ''; ?>>OTA平台</option>
                            </select>
                        </div>
                    </div>

                    <div class="form-row">
                        <div class="form-group col-md-6">
                            <label for="guest_id_type">证件类型</label>
                            <select id="guest_id_type" name="guest_id_type">
                                <option value="id_card" <?php echo (isset($_POST['guest_id_type']) && $_POST['guest_id_type'] == 'id_card') ? 'selected' : ''; ?>>身份证</option>
                                <option value="passport" <?php echo (isset($_POST['guest_id_type']) && $_POST['guest_id_type'] == 'passport') ? 'selected' : ''; ?>>护照</option>
                                <option value="driving_license" <?php echo (isset($_POST['guest_id_type']) && $_POST['guest_id_type'] == 'driving_license') ? 'selected' : ''; ?>>驾驶证</option>
                                <option value="other" <?php echo (isset($_POST['guest_id_type']) && $_POST['guest_id_type'] == 'other') ? 'selected' : ''; ?>>其他</option>
                            </select>
                        </div>

                        <div class="form-group col-md-6">
                            <label for="guest_id_number">证件号码</label>
                            <input type="text" id="guest_id_number" name="guest_id_number" value="<?php echo isset($_POST['guest_id_number']) ? htmlspecialchars($_POST['guest_id_number']) : ''; ?>">
                        </div>
                    </div>
                </div>

                <div class="form-section">
                    <h3>预订信息</h3>

                    <div class="form-row">
                        <div class="form-group col-md-6">
                            <label for="check_in_date">入住日期 <span class="required">*</span></label>
                            <input type="date" id="check_in_date" name="check_in_date" value="<?php echo isset($_POST['check_in_date']) ? htmlspecialchars($_POST['check_in_date']) : $presetCheckInDate; ?>" required>
                        </div>

                        <div class="form-group col-md-6">
                            <label for="check_out_date">退房日期 <span class="required">*</span></label>
                            <input type="date" id="check_out_date" name="check_out_date" value="<?php echo isset($_POST['check_out_date']) ? htmlspecialchars($_POST['check_out_date']) : $presetCheckOutDate; ?>" required>
                        </div>
                    </div>

                    <div class="form-row">
                        <div class="form-group col-md-6">
                            <label for="adults">成人数量 <span class="required">*</span></label>
                            <input type="number" id="adults" name="adults" min="1" value="<?php echo isset($_POST['adults']) ? (int)$_POST['adults'] : 1; ?>" required>
                        </div>

                        <div class="form-group col-md-6">
                            <label for="children">儿童数量</label>
                            <input type="number" id="children" name="children" min="0" value="<?php echo isset($_POST['children']) ? (int)$_POST['children'] : 0; ?>">
                        </div>
                    </div>

                    <div class="form-group">
                        <label for="special_requests">特殊要求</label>
                        <textarea id="special_requests" name="special_requests" rows="3"><?php echo isset($_POST['special_requests']) ? htmlspecialchars($_POST['special_requests']) : ''; ?></textarea>
                    </div>
                </div>

                <div class="form-section">
                    <h3>房间选择</h3>

                    <div class="room-selection">
                        <?php if (empty($rooms)): ?>
                            <p class="no-rooms">当前没有可用房间</p>
                        <?php else: ?>
                            <div class="room-filter">
                                <div class="form-group">
                                    <label for="room_type_filter">按房型筛选</label>
                                    <select id="room_type_filter">
                                        <option value="0">所有房型</option>
                                        <?php foreach ($roomTypes as $type): ?>
                                            <option value="<?php echo $type['id']; ?>"><?php echo htmlspecialchars($type['name']); ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>

                                <div class="form-group">
                                    <label for="floor_filter">按楼层筛选</label>
                                    <select id="floor_filter">
                                        <option value="">所有楼层</option>
                                        <?php
                                        $floors = [];
                                        foreach ($rooms as $room) {
                                            if (!in_array($room['floor'], $floors)) {
                                                $floors[] = $room['floor'];
                                                echo '<option value="' . htmlspecialchars($room['floor']) . '">' . htmlspecialchars($room['floor']) . '楼</option>';
                                            }
                                        }
                                        ?>
                                    </select>
                                </div>
                            </div>

                            <div class="room-list">
                                <?php foreach ($rooms as $room): ?>
                                    <div class="room-item" data-room-type="<?php echo $room['room_type']; ?>" data-floor="<?php echo $room['floor']; ?>">
                                        <div class="room-info">
                                            <div class="room-number"><?php echo htmlspecialchars($room['room_number']); ?></div>
                                            <div class="room-details">
                                                <div class="room-type"><?php echo htmlspecialchars($room['room_type']); ?></div>
                                                <div class="room-floor"><?php echo htmlspecialchars($room['floor']); ?>楼</div>
                                            </div>
                                            <div class="room-price">¥<?php echo number_format($room['base_price'] + $room['price_adjustment'], 2); ?></div>
                                        </div>
                                        <div class="room-select">
                                            <input type="checkbox" name="selected_rooms[]" value="<?php echo $room['id']; ?>" <?php echo ($presetRoomId == $room['id'] || (isset($_POST['selected_rooms']) && in_array($room['id'], $_POST['selected_rooms']))) ? 'checked' : ''; ?> class="room-checkbox">
                                        </div>
                                    </div>
                                <?php endforeach; ?>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>

                <div class="form-section">
                    <h3>付款信息</h3>

                    <div class="form-row">
                        <div class="form-group col-md-6">
                            <label for="total_amount">总金额 <span class="required">*</span></label>
                            <input type="number" id="total_amount" name="total_amount" step="0.01" min="0" value="<?php echo isset($_POST['total_amount']) ? (float)$_POST['total_amount'] : 0; ?>" required>
                        </div>

                        <div class="form-group col-md-6">
                            <label for="deposit">已付定金</label>
                            <input type="number" id="deposit" name="deposit" step="0.01" min="0" value="<?php echo isset($_POST['deposit']) ? (float)$_POST['deposit'] : 0; ?>">
                        </div>
                    </div>

                    <div class="form-group">
                        <label for="status">预订状态</label>
                        <select id="status" name="status">
                            <option value="pending" <?php echo (isset($_POST['status']) && $_POST['status'] == 'pending') ? 'selected' : ''; ?>>待确认</option>
                            <option value="confirmed" <?php echo (isset($_POST['status']) && $_POST['status'] == 'confirmed') ? 'selected' : ''; ?>>已确认</option>
                        </select>
                    </div>
                </div>

                <div class="form-actions">
                    <button type="submit" class="btn btn-primary">保存</button>
                    <a href="index.php?page=booking_list" class="btn btn-secondary">取消</a>
                </div>
            </form>
        </div>
    </div>
</div>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 房间筛选
        const roomTypeFilter = document.getElementById('room_type_filter');
        const floorFilter = document.getElementById('floor_filter');
        const roomItems = document.querySelectorAll('.room-item');

        function filterRooms() {
            const selectedRoomType = roomTypeFilter.value;
            const selectedFloor = floorFilter.value;

            roomItems.forEach(item => {
                const roomType = item.getAttribute('data-room-type');
                const floor = item.getAttribute('data-floor');

                let showRoom = true;

                if (selectedRoomType !== '0' && !roomType.includes(selectedRoomType)) {
                    showRoom = false;
                }

                if (selectedFloor !== '' && floor !== selectedFloor) {
                    showRoom = false;
                }

                item.style.display = showRoom ? 'flex' : 'none';
            });
        }

        roomTypeFilter.addEventListener('change', filterRooms);
        floorFilter.addEventListener('change', filterRooms);

        // 计算总金额
        const checkInDateInput = document.getElementById('check_in_date');
        const checkOutDateInput = document.getElementById('check_out_date');
        const totalAmountInput = document.getElementById('total_amount');
        const roomCheckboxes = document.querySelectorAll('.room-checkbox');

        function calculateTotalAmount() {
            const checkInDate = new Date(checkInDateInput.value);
            const checkOutDate = new Date(checkOutDateInput.value);

            // 计算入住天数
            const timeDiff = checkOutDate.getTime() - checkInDate.getTime();
            const nights = Math.ceil(timeDiff / (1000 * 3600 * 24));

            if (nights <= 0) {
                return;
            }

            // 计算选中房间的总价
            let totalAmount = 0;

            roomCheckboxes.forEach(checkbox => {
                if (checkbox.checked) {
                    const roomItem = checkbox.closest('.room-item');
                    const roomPrice = parseFloat(roomItem.querySelector('.room-price').textContent.replace('¥', '').replace(',', ''));
                    totalAmount += roomPrice * nights;
                }
            });

            totalAmountInput.value = totalAmount.toFixed(2);
        }

        checkInDateInput.addEventListener('change', calculateTotalAmount);
        checkOutDateInput.addEventListener('change', calculateTotalAmount);

        roomCheckboxes.forEach(checkbox => {
            checkbox.addEventListener('change', calculateTotalAmount);
        });

        // 初始计算总金额
        calculateTotalAmount();
    });
</script>

<style>
    .content-wrapper {
        padding: 15px 0;
    }

    .page-header {
        margin-bottom: 20px;
    }

    .page-header h2 {
        margin-bottom: 5px;
    }

    .breadcrumb {
        font-size: 14px;
        color: #6c757d;
    }

    .breadcrumb a {
        color: #0066cc;
    }

    .card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        margin-bottom: 20px;
    }

    .card-body {
        padding: 20px;
    }

    .form-section {
        margin-bottom: 30px;
    }

    .form-section h3 {
        font-size: 18px;
        color: #0066cc;
        margin-bottom: 15px;
        padding-bottom: 10px;
        border-bottom: 1px solid #e9ecef;
    }

    .form-row {
        display: flex;
        flex-wrap: wrap;
        margin-right: -10px;
        margin-left: -10px;
    }

    .col-md-6 {
        flex: 0 0 50%;
        max-width: 50%;
        padding-right: 10px;
        padding-left: 10px;
    }

    .required {
        color: #dc3545;
    }

    .room-selection {
        margin-bottom: 20px;
    }

    .room-filter {
        display: flex;
        gap: 15px;
        margin-bottom: 15px;
    }

    .room-list {
        display: grid;
        grid-template-columns: repeat(auto-fill, minmax(250px, 1fr));
        gap: 15px;
    }

    .room-item {
        border: 1px solid #e9ecef;
        border-radius: 8px;
        padding: 15px;
        display: flex;
        justify-content: space-between;
        align-items: center;
    }

    .room-item:hover {
        background-color: #f8f9fa;
    }

    .room-info {
        flex: 1;
    }

    .room-number {
        font-size: 18px;
        font-weight: bold;
        margin-bottom: 5px;
    }

    .room-details {
        display: flex;
        gap: 10px;
        font-size: 14px;
        color: #6c757d;
        margin-bottom: 5px;
    }

    .room-price {
        font-weight: bold;
        color: #dc3545;
    }

    .no-rooms {
        text-align: center;
        padding: 20px;
        color: #6c757d;
        background-color: #f8f9fa;
        border-radius: 8px;
    }

    .form-actions {
        display: flex;
        gap: 10px;
        margin-top: 20px;
    }

    @media (max-width: 768px) {
        .col-md-6 {
            flex: 0 0 100%;
            max-width: 100%;
        }

        .room-filter {
            flex-direction: column;
        }
    }
</style>