<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 检查是否有预订ID
if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    header('Location: index.php?page=booking_list');
    exit;
}

$bookingId = (int)$_GET['id'];

// 获取预订信息
$sql = "SELECT * FROM bookings WHERE id = ?";
$stmt = $conn->prepare($sql);
$stmt->bind_param("i", $bookingId);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows === 0) {
    header('Location: index.php?page=booking_list');
    exit;
}

$booking = $result->fetch_assoc();

// 检查预订状态，已入住或已退房的预订不能取消
if (in_array($booking['status'], ['checked_in', 'checked_out'])) {
    $_SESSION['error_message'] = '已入住或已退房的预订不能取消';
    header('Location: index.php?page=booking_view&id=' . $bookingId);
    exit;
}

// 获取预订房间信息
$roomsSql = "SELECT br.*, r.room_number, r.floor, rt.name as room_type 
             FROM booking_rooms br 
             JOIN rooms r ON br.room_id = r.id 
             JOIN room_types rt ON r.room_type_id = rt.id 
             WHERE br.booking_id = ?";
$roomsStmt = $conn->prepare($roomsSql);
$roomsStmt->bind_param("i", $bookingId);
$roomsStmt->execute();
$roomsResult = $roomsStmt->get_result();
$rooms = [];
if ($roomsResult && $roomsResult->num_rows > 0) {
    while ($row = $roomsResult->fetch_assoc()) {
        $rooms[] = $row;
    }
}

// 获取已付款信息
$paymentsSql = "SELECT * FROM payments WHERE booking_id = ? ORDER BY payment_date ASC";
$paymentsStmt = $conn->prepare($paymentsSql);
$paymentsStmt->bind_param("i", $bookingId);
$paymentsStmt->execute();
$paymentsResult = $paymentsStmt->get_result();
$payments = [];
$totalPaid = 0;
if ($paymentsResult && $paymentsResult->num_rows > 0) {
    while ($row = $paymentsResult->fetch_assoc()) {
        $payments[] = $row;
        $totalPaid += $row['amount'];
    }
}

// 计算退款金额
$refundAmount = $totalPaid;

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // 获取表单数据
    $cancelReason = sanitize($_POST['cancel_reason']);
    $refundMethod = sanitize($_POST['refund_method']);
    $actualRefundAmount = (float)$_POST['refund_amount'];
    $notes = sanitize($_POST['notes']);

    // 验证数据
    $errors = [];

    if (empty($cancelReason)) {
        $errors[] = '取消原因不能为空';
    }

    if ($actualRefundAmount > $totalPaid) {
        $errors[] = '退款金额不能大于已付金额';
    }

    // 如果没有错误，处理取消
    if (empty($errors)) {
        // 开始事务
        $conn->begin_transaction();

        try {
            // 更新预订状态为已取消
            $updateBookingSql = "UPDATE bookings SET 
                                status = 'cancelled',
                                special_requests = CONCAT(IFNULL(special_requests, ''), '\n取消原因: ', ?, '\n备注: ', ?) 
                                WHERE id = ?";
            $updateBookingStmt = $conn->prepare($updateBookingSql);
            $updateBookingStmt->bind_param("ssi", $cancelReason, $notes, $bookingId);
            $updateBookingStmt->execute();

            // 更新房间状态为可用
            foreach ($rooms as $room) {
                $updateRoomSql = "UPDATE rooms SET status = 'available' WHERE id = ?";
                $updateRoomStmt = $conn->prepare($updateRoomSql);
                $updateRoomStmt->bind_param("i", $room['room_id']);
                $updateRoomStmt->execute();
            }

            // 记录退款（如果有）
            if ($actualRefundAmount > 0) {
                $refundSql = "INSERT INTO refunds (booking_id, amount, refund_method, refund_date, notes) 
                             VALUES (?, ?, ?, NOW(), '取消预订退款')";
                $refundStmt = $conn->prepare($refundSql);
                $refundStmt->bind_param("ids", $bookingId, $actualRefundAmount, $refundMethod);
                $refundStmt->execute();
            }

            // 提交事务
            $conn->commit();

            // 记录操作日志
            logActivity('booking_cancel', '取消预订: ' . $booking['booking_number']);

            // 设置成功消息并重定向
            $_SESSION['success_message'] = '预订取消成功';
            header('Location: index.php?page=booking_view&id=' . $bookingId);
            exit;
        } catch (Exception $e) {
            // 回滚事务
            $conn->rollback();
            $errors[] = '取消预订失败: ' . $e->getMessage();
        }
    }
}
?>

<div class="content-wrapper">
    <div class="page-header">
        <h2>取消预订</h2>
        <nav class="breadcrumb">
            <a href="index.php">概览</a> /
            <a href="index.php?page=booking_list">订单列表</a> /
            <a href="index.php?page=booking_view&id=<?php echo $bookingId; ?>">预订详情</a> /
            <span>取消预订</span>
        </nav>
    </div>

    <?php if (!empty($errors)): ?>
        <div class="alert alert-error">
            <ul>
                <?php foreach ($errors as $error): ?>
                    <li><?php echo $error; ?></li>
                <?php endforeach; ?>
            </ul>
        </div>
    <?php endif; ?>

    <div class="cancel-container">
        <div class="booking-summary">
            <div class="card">
                <div class="card-header">
                    <h3>预订信息</h3>
                </div>
                <div class="card-body">
                    <div class="detail-row">
                        <div class="detail-label">预订号</div>
                        <div class="detail-value"><?php echo htmlspecialchars($booking['booking_number']); ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">客人姓名</div>
                        <div class="detail-value"><?php echo htmlspecialchars($booking['guest_name']); ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">联系电话</div>
                        <div class="detail-value"><?php echo htmlspecialchars($booking['guest_phone']); ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">入住日期</div>
                        <div class="detail-value"><?php echo date('Y-m-d', strtotime($booking['check_in_date'])); ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">退房日期</div>
                        <div class="detail-value"><?php echo date('Y-m-d', strtotime($booking['check_out_date'])); ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">预订状态</div>
                        <div class="detail-value">
                            <?php
                            switch ($booking['status']) {
                                case 'pending_payment':
                                    echo '<span class="status-badge status-pending">待付款</span>';
                                    break;
                                case 'confirmed':
                                    echo '<span class="status-badge status-confirmed">已确认</span>';
                                    break;
                                default:
                                    echo htmlspecialchars($booking['status']);
                            }
                            ?>
                        </div>
                    </div>
                </div>
            </div>

            <div class="card">
                <div class="card-header">
                    <h3>房间信息</h3>
                </div>
                <div class="card-body">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>房间号</th>
                                <th>楼层</th>
                                <th>房型</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($rooms as $room): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($room['room_number']); ?></td>
                                    <td><?php echo htmlspecialchars($room['floor']); ?> 楼</td>
                                    <td><?php echo htmlspecialchars($room['room_type']); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            </div>

            <div class="card">
                <div class="card-header">
                    <h3>付款信息</h3>
                </div>
                <div class="card-body">
                    <div class="detail-row">
                        <div class="detail-label">预订总金额</div>
                        <div class="detail-value">¥<?php echo number_format($booking['total_amount'], 2); ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">已付金额</div>
                        <div class="detail-value">¥<?php echo number_format($totalPaid, 2); ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">可退款金额</div>
                        <div class="detail-value price-highlight">¥<?php echo number_format($refundAmount, 2); ?></div>
                    </div>

                    <?php if (!empty($payments)): ?>
                        <div class="detail-section">
                            <h4>付款记录</h4>
                            <table class="data-table">
                                <thead>
                                    <tr>
                                        <th>日期</th>
                                        <th>金额</th>
                                        <th>支付方式</th>
                                        <th>备注</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($payments as $payment): ?>
                                        <tr>
                                            <td><?php echo date('Y-m-d', strtotime($payment['payment_date'])); ?></td>
                                            <td>¥<?php echo number_format($payment['amount'], 2); ?></td>
                                            <td>
                                                <?php
                                                switch ($payment['payment_method']) {
                                                    case 'cash':
                                                        echo '现金';
                                                        break;
                                                    case 'credit_card':
                                                        echo '信用卡';
                                                        break;
                                                    case 'debit_card':
                                                        echo '借记卡';
                                                        break;
                                                    case 'wechat':
                                                        echo '微信支付';
                                                        break;
                                                    case 'alipay':
                                                        echo '支付宝';
                                                        break;
                                                    default:
                                                        echo htmlspecialchars($payment['payment_method']);
                                                }
                                                ?>
                                            </td>
                                            <td><?php echo htmlspecialchars($payment['notes']); ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>

        <div class="cancel-form">
            <div class="card">
                <div class="card-header">
                    <h3>取消预订</h3>
                </div>
                <div class="card-body">
                    <div class="alert alert-warning">
                        <p><strong>警告：</strong> 取消预订后，所选房间将重新变为可用状态，此操作不可撤销。</p>
                    </div>

                    <form method="post" action="">
                        <div class="form-section">
                            <h4>取消原因</h4>

                            <div class="form-group">
                                <label for="cancel_reason">取消原因 <span class="required">*</span></label>
                                <select id="cancel_reason" name="cancel_reason" required>
                                    <option value="">请选择取消原因</option>
                                    <option value="guest_request">客人要求取消</option>
                                    <option value="payment_issue">支付问题</option>
                                    <option value="duplicate_booking">重复预订</option>
                                    <option value="no_show">客人未到</option>
                                    <option value="hotel_issue">酒店原因</option>
                                    <option value="other">其他原因</option>
                                </select>
                            </div>
                        </div>

                        <div class="form-section">
                            <h4>退款信息</h4>

                            <div class="form-row">
                                <div class="form-group col-md-6">
                                    <label for="refund_amount">退款金额</label>
                                    <input type="number" id="refund_amount" name="refund_amount" step="0.01" min="0" max="<?php echo $refundAmount; ?>" value="<?php echo $refundAmount; ?>">
                                </div>

                                <div class="form-group col-md-6">
                                    <label for="refund_method">退款方式</label>
                                    <select id="refund_method" name="refund_method">
                                        <option value="original">原路退回</option>
                                        <option value="cash">现金</option>
                                        <option value="credit_card">信用卡</option>
                                        <option value="debit_card">借记卡</option>
                                        <option value="wechat">微信支付</option>
                                        <option value="alipay">支付宝</option>
                                    </select>
                                </div>
                            </div>
                        </div>

                        <div class="form-section">
                            <h4>备注</h4>

                            <div class="form-group">
                                <textarea id="notes" name="notes" rows="3" placeholder="请输入取消预订的其他说明信息"></textarea>
                            </div>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-danger">确认取消预订</button>
                            <a href="index.php?page=booking_view&id=<?php echo $bookingId; ?>" class="btn btn-secondary">返回</a>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>
</div>

<style>
    .content-wrapper {
        padding: 15px 0;
    }

    .page-header {
        margin-bottom: 20px;
    }

    .page-header h2 {
        margin-bottom: 5px;
    }

    .breadcrumb {
        font-size: 14px;
        color: #6c757d;
    }

    .breadcrumb a {
        color: #0066cc;
    }

    .cancel-container {
        display: flex;
        flex-wrap: wrap;
        gap: 20px;
    }

    .booking-summary {
        flex: 1;
        min-width: 300px;
    }

    .cancel-form {
        flex: 1;
        min-width: 300px;
    }

    .card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        margin-bottom: 20px;
        overflow: hidden;
    }

    .card-header {
        padding: 15px;
        border-bottom: 1px solid #e9ecef;
        background-color: #f8f9fa;
    }

    .card-header h3 {
        margin: 0;
        font-size: 18px;
        color: #0066cc;
    }

    .card-body {
        padding: 15px;
    }

    .detail-row {
        display: flex;
        margin-bottom: 10px;
    }

    .detail-label {
        width: 120px;
        font-weight: bold;
        color: #495057;
    }

    .detail-value {
        flex: 1;
    }

    .price-highlight {
        font-weight: bold;
        color: #dc3545;
    }

    .status-badge {
        display: inline-block;
        padding: 3px 8px;
        border-radius: 4px;
        font-size: 12px;
        font-weight: bold;
    }

    .status-pending {
        background-color: #fff3cd;
        color: #856404;
    }

    .status-confirmed {
        background-color: #d4edda;
        color: #155724;
    }

    .detail-section {
        margin-top: 15px;
    }

    .detail-section h4 {
        font-size: 16px;
        color: #495057;
        margin-bottom: 10px;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 10px;
        text-align: left;
        border-bottom: 1px solid #e9ecef;
    }

    .data-table th {
        background-color: #f8f9fa;
        font-weight: bold;
        color: #495057;
    }

    .alert {
        padding: 15px;
        margin-bottom: 20px;
        border-radius: 4px;
    }

    .alert-error {
        background-color: #f8d7da;
        color: #721c24;
        border: 1px solid #f5c6cb;
    }

    .alert-warning {
        background-color: #fff3cd;
        color: #856404;
        border: 1px solid #ffeeba;
    }

    .form-section {
        margin-bottom: 20px;
    }

    .form-section h4 {
        font-size: 16px;
        color: #495057;
        margin-bottom: 15px;
        padding-bottom: 5px;
        border-bottom: 1px solid #e9ecef;
    }

    .form-row {
        display: flex;
        flex-wrap: wrap;
        margin-right: -10px;
        margin-left: -10px;
    }

    .col-md-6 {
        flex: 0 0 50%;
        max-width: 50%;
        padding-right: 10px;
        padding-left: 10px;
    }

    .form-group {
        margin-bottom: 15px;
    }

    .form-group label {
        display: block;
        margin-bottom: 5px;
        font-weight: bold;
    }

    .form-group input,
    .form-group select,
    .form-group textarea {
        width: 100%;
        padding: 8px;
        border: 1px solid #ced4da;
        border-radius: 4px;
    }

    .required {
        color: #dc3545;
    }

    .form-actions {
        display: flex;
        gap: 10px;
        margin-top: 20px;
    }

    .btn {
        display: inline-block;
        font-weight: 400;
        text-align: center;
        white-space: nowrap;
        vertical-align: middle;
        user-select: none;
        border: 1px solid transparent;
        padding: 0.375rem 0.75rem;
        font-size: 1rem;
        line-height: 1.5;
        border-radius: 0.25rem;
        transition: color 0.15s ease-in-out, background-color 0.15s ease-in-out, border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
        cursor: pointer;
    }

    .btn-primary {
        color: #fff;
        background-color: #0066cc;
        border-color: #0066cc;
    }

    .btn-secondary {
        color: #fff;
        background-color: #6c757d;
        border-color: #6c757d;
    }

    .btn-danger {
        color: #fff;
        background-color: #dc3545;
        border-color: #dc3545;
    }

    @media (max-width: 768px) {
        .col-md-6 {
            flex: 0 0 100%;
            max-width: 100%;
        }
    }
</style>