<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 检查是否有预订ID
if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    header('Location: index.php?page=booking_list');
    exit;
}

$bookingId = (int)$_GET['id'];

// 获取预订信息
$sql = "SELECT * FROM bookings WHERE id = ?";
$stmt = $conn->prepare($sql);
$stmt->bind_param("i", $bookingId);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows === 0) {
    header('Location: index.php?page=booking_list');
    exit;
}

$booking = $result->fetch_assoc();

// 检查预订状态，已入住或已退房的预订不能编辑
if (in_array($booking['status'], ['checked_in', 'checked_out'])) {
    $_SESSION['error_message'] = '已入住或已退房的预订不能编辑';
    header('Location: index.php?page=booking_view&id=' . $bookingId);
    exit;
}

// 获取预订房间信息
$roomsSql = "SELECT br.*, r.room_number, r.floor, r.price_adjustment, rt.name as room_type, rt.id as room_type_id, rt.base_price 
             FROM booking_rooms br 
             JOIN rooms r ON br.room_id = r.id 
             JOIN room_types rt ON r.room_type_id = rt.id 
             WHERE br.booking_id = ?";
$roomsStmt = $conn->prepare($roomsSql);
if ($roomsStmt === false) {
    die("SQL准备失败: " . $conn->error . " SQL: " . $roomsSql);
}
$roomsStmt->bind_param("i", $bookingId);
$roomsStmt->execute();
$roomsResult = $roomsStmt->get_result();
$bookedRooms = [];
if ($roomsResult && $roomsResult->num_rows > 0) {
    while ($row = $roomsResult->fetch_assoc()) {
        $bookedRooms[] = $row;
    }
}

// 获取所有可用房间类型
$roomTypesSql = "SELECT * FROM room_types WHERE status = 'active' ORDER BY name";
$roomTypesResult = $conn->query($roomTypesSql);
$roomTypes = [];
if ($roomTypesResult && $roomTypesResult->num_rows > 0) {
    while ($row = $roomTypesResult->fetch_assoc()) {
        $roomTypes[] = $row;
    }
}

// 获取所有可用房间（包括当前预订的房间）
$roomsSql = "SELECT r.*, rt.name as room_type, rt.base_price, r.price_adjustment 
             FROM rooms r 
             JOIN room_types rt ON r.room_type_id = rt.id 
             WHERE r.status = 'available' OR r.id IN (SELECT room_id FROM booking_rooms WHERE booking_id = ?)
             ORDER BY r.room_number";
$roomsStmt = $conn->prepare($roomsSql);
if ($roomsStmt === false) {
    die("SQL准备失败: " . $conn->error . " SQL: " . $roomsSql);
}
$roomsStmt->bind_param("i", $bookingId);
$roomsStmt->execute();
$roomsResult = $roomsStmt->get_result();
$availableRooms = [];
if ($roomsResult && $roomsResult->num_rows > 0) {
    while ($row = $roomsResult->fetch_assoc()) {
        $availableRooms[] = $row;
    }
}

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // 获取表单数据
    $guestName = sanitize($_POST['guest_name']);
    $guestPhone = sanitize($_POST['guest_phone']);
    $guestEmail = sanitize($_POST['guest_email']);
    $guestIdType = sanitize($_POST['guest_id_type']);
    $guestIdNumber = sanitize($_POST['guest_id_number']);
    $checkInDate = sanitize($_POST['check_in_date']);
    $checkOutDate = sanitize($_POST['check_out_date']);
    $adults = (int)$_POST['adults'];
    $children = (int)$_POST['children'];
    $bookingSource = sanitize($_POST['booking_source']);
    $status = sanitize($_POST['status']);
    $notes = sanitize($_POST['notes']);
    $selectedRooms = isset($_POST['rooms']) ? $_POST['rooms'] : [];

    // 验证数据
    $errors = [];

    if (empty($guestName)) {
        $errors[] = '客人姓名不能为空';
    }

    if (empty($guestPhone)) {
        $errors[] = '联系电话不能为空';
    }

    if (empty($checkInDate)) {
        $errors[] = '入住日期不能为空';
    }

    if (empty($checkOutDate)) {
        $errors[] = '退房日期不能为空';
    }

    if (strtotime($checkOutDate) <= strtotime($checkInDate)) {
        $errors[] = '退房日期必须晚于入住日期';
    }

    if (empty($selectedRooms)) {
        $errors[] = '必须选择至少一个房间';
    }

    // 如果没有错误，更新预订
    if (empty($errors)) {
        // 开始事务
        $conn->begin_transaction();

        try {
            // 计算总金额
            $totalAmount = 0;
            $checkInDateTime = new DateTime($checkInDate);
            $checkOutDateTime = new DateTime($checkOutDate);
            $interval = $checkInDateTime->diff($checkOutDateTime);
            $nights = $interval->days;

            foreach ($selectedRooms as $roomId) {
                // 查找房间价格
                foreach ($availableRooms as $room) {
                    if ($room['id'] == $roomId) {
                        $totalAmount += ($room['base_price'] + $room['price_adjustment']) * $nights;
                        break;
                    }
                }
            }

            // 更新预订信息
            $updateBookingSql = "UPDATE bookings SET 
                                guest_name = ?, 
                                guest_phone = ?, 
                                guest_email = ?, 
                                guest_id_type = ?, 
                                guest_id_number = ?, 
                                check_in_date = ?, 
                                check_out_date = ?, 
                                adults = ?, 
                                children = ?, 
                                total_amount = ?, 
                                booking_source = ?, 
                                status = ?, 
                                special_requests = ? 
                                WHERE id = ?";
            $updateBookingStmt = $conn->prepare($updateBookingSql);
            if ($updateBookingStmt === false) {
                throw new Exception("SQL准备失败: " . $conn->error . " SQL: " . $updateBookingSql);
            }
            $updateBookingStmt->bind_param(
                "sssssssiiisssi",
                $guestName,
                $guestPhone,
                $guestEmail,
                $guestIdType,
                $guestIdNumber,
                $checkInDate,
                $checkOutDate,
                $adults,
                $children,
                $totalAmount,
                $bookingSource,
                $status,
                $notes,
                $bookingId
            );
            $updateBookingStmt->execute();

            // 删除旧的房间关联
            $deleteRoomsSql = "DELETE FROM booking_rooms WHERE booking_id = ?";
            $deleteRoomsStmt = $conn->prepare($deleteRoomsSql);
            $deleteRoomsStmt->bind_param("i", $bookingId);
            $deleteRoomsStmt->execute();

            // 将之前预订的房间状态重置为可用
            foreach ($bookedRooms as $room) {
                $updateRoomSql = "UPDATE rooms SET status = 'available' WHERE id = ?";
                $updateRoomStmt = $conn->prepare($updateRoomSql);
                $updateRoomStmt->bind_param("i", $room['room_id']);
                $updateRoomStmt->execute();
            }

            // 添加新的房间关联并更新房间状态
            foreach ($selectedRooms as $roomId) {
                // 添加房间关联
                $insertRoomSql = "INSERT INTO booking_rooms (booking_id, room_id) VALUES (?, ?)";
                $insertRoomStmt = $conn->prepare($insertRoomSql);
                $insertRoomStmt->bind_param("ii", $bookingId, $roomId);
                $insertRoomStmt->execute();

                // 更新房间状态
                $roomStatus = ($status == 'confirmed') ? 'booked' : 'available';
                $updateRoomSql = "UPDATE rooms SET status = ? WHERE id = ?";
                $updateRoomStmt = $conn->prepare($updateRoomSql);
                $updateRoomStmt->bind_param("si", $roomStatus, $roomId);
                $updateRoomStmt->execute();
            }

            // 提交事务
            $conn->commit();

            // 记录操作日志
            logActivity('booking_edit', '编辑预订: ' . $booking['booking_number']);

            // 设置成功消息并重定向
            $_SESSION['success_message'] = '预订更新成功';
            header('Location: index.php?page=booking_view&id=' . $bookingId);
            exit;
        } catch (Exception $e) {
            // 回滚事务
            $conn->rollback();
            $errors[] = '更新预订失败: ' . $e->getMessage();
        }
    }
}
?>

<div class="content-wrapper">
    <div class="page-header">
        <h2>编辑预订</h2>
        <nav class="breadcrumb">
            <a href="index.php">概览</a> /
            <a href="index.php?page=booking_list">订单列表</a> /
            <a href="index.php?page=booking_view&id=<?php echo $bookingId; ?>">预订详情</a> /
            <span>编辑预订</span>
        </nav>
    </div>

    <?php if (!empty($errors)): ?>
        <div class="alert alert-error">
            <ul>
                <?php foreach ($errors as $error): ?>
                    <li><?php echo $error; ?></li>
                <?php endforeach; ?>
            </ul>
        </div>
    <?php endif; ?>

    <div class="card">
        <div class="card-header">
            <h3>编辑预订 #<?php echo htmlspecialchars($booking['booking_number']); ?></h3>
        </div>
        <div class="card-body">
            <form method="post" action="" id="booking-edit-form">
                <div class="form-section">
                    <h4>客人信息</h4>

                    <div class="form-row">
                        <div class="form-group col-md-6">
                            <label for="guest_name">客人姓名 <span class="required">*</span></label>
                            <input type="text" id="guest_name" name="guest_name" value="<?php echo htmlspecialchars($booking['guest_name']); ?>" required>
                        </div>

                        <div class="form-group col-md-6">
                            <label for="guest_phone">联系电话 <span class="required">*</span></label>
                            <input type="text" id="guest_phone" name="guest_phone" value="<?php echo htmlspecialchars($booking['guest_phone']); ?>" required>
                        </div>
                    </div>

                    <div class="form-row">
                        <div class="form-group col-md-6">
                            <label for="guest_email">电子邮箱</label>
                            <input type="email" id="guest_email" name="guest_email" value="<?php echo htmlspecialchars($booking['guest_email'] ?? ''); ?>">
                        </div>

                        <div class="form-group col-md-3">
                            <label for="guest_id_type">证件类型</label>
                            <select id="guest_id_type" name="guest_id_type">
                                <option value="id_card" <?php echo ($booking['guest_id_type'] == 'id_card') ? 'selected' : ''; ?>>身份证</option>
                                <option value="passport" <?php echo ($booking['guest_id_type'] == 'passport') ? 'selected' : ''; ?>>护照</option>
                                <option value="driving_license" <?php echo ($booking['guest_id_type'] == 'driving_license') ? 'selected' : ''; ?>>驾驶证</option>
                                <option value="other" <?php echo ($booking['guest_id_type'] == 'other') ? 'selected' : ''; ?>>其他</option>
                            </select>
                        </div>

                        <div class="form-group col-md-3">
                            <label for="guest_id_number">证件号码</label>
                            <input type="text" id="guest_id_number" name="guest_id_number" value="<?php echo htmlspecialchars($booking['guest_id_number'] ?? ''); ?>">
                        </div>
                    </div>
                </div>

                <div class="form-section">
                    <h4>预订详情</h4>

                    <div class="form-row">
                        <div class="form-group col-md-6">
                            <label for="check_in_date">入住日期 <span class="required">*</span></label>
                            <input type="date" id="check_in_date" name="check_in_date" value="<?php echo date('Y-m-d', strtotime($booking['check_in_date'])); ?>" required>
                        </div>

                        <div class="form-group col-md-6">
                            <label for="check_out_date">退房日期 <span class="required">*</span></label>
                            <input type="date" id="check_out_date" name="check_out_date" value="<?php echo date('Y-m-d', strtotime($booking['check_out_date'])); ?>" required>
                        </div>
                    </div>

                    <div class="form-row">
                        <div class="form-group col-md-3">
                            <label for="adults">成人数量</label>
                            <input type="number" id="adults" name="adults" min="1" value="<?php echo (int)$booking['adults']; ?>">
                        </div>

                        <div class="form-group col-md-3">
                            <label for="children">儿童数量</label>
                            <input type="number" id="children" name="children" min="0" value="<?php echo (int)$booking['children']; ?>">
                        </div>

                        <div class="form-group col-md-3">
                            <label for="booking_source">预订来源</label>
                            <select id="booking_source" name="booking_source">
                                <option value="direct" <?php echo ($booking['booking_source'] == 'direct') ? 'selected' : ''; ?>>直接预订</option>
                                <option value="website" <?php echo ($booking['booking_source'] == 'website') ? 'selected' : ''; ?>>官网</option>
                                <option value="phone" <?php echo ($booking['booking_source'] == 'phone') ? 'selected' : ''; ?>>电话</option>
                                <option value="email" <?php echo ($booking['booking_source'] == 'email') ? 'selected' : ''; ?>>邮件</option>
                                <option value="walk_in" <?php echo ($booking['booking_source'] == 'walk_in') ? 'selected' : ''; ?>>上门</option>
                                <option value="ota" <?php echo ($booking['booking_source'] == 'ota') ? 'selected' : ''; ?>>OTA平台</option>
                            </select>
                        </div>

                        <div class="form-group col-md-3">
                            <label for="status">预订状态</label>
                            <select id="status" name="status">
                                <option value="pending" <?php echo ($booking['status'] == 'pending') ? 'selected' : ''; ?>>待确认</option>
                                <option value="confirmed" <?php echo ($booking['status'] == 'confirmed') ? 'selected' : ''; ?>>已确认</option>
                                <option value="cancelled" <?php echo ($booking['status'] == 'cancelled') ? 'selected' : ''; ?>>已取消</option>
                            </select>
                        </div>
                    </div>
                </div>

                <div class="form-section">
                    <h4>房间选择</h4>

                    <div class="room-filter">
                        <div class="form-row">
                            <div class="form-group col-md-4">
                                <label for="filter_room_type">按房型筛选</label>
                                <select id="filter_room_type" class="filter-control">
                                    <option value="">所有房型</option>
                                    <?php foreach ($roomTypes as $roomType): ?>
                                        <option value="<?php echo $roomType['id']; ?>"><?php echo htmlspecialchars($roomType['name']); ?></option>
                                    <?php endforeach; ?>
                                </select>
                            </div>

                            <div class="form-group col-md-4">
                                <label for="filter_floor">按楼层筛选</label>
                                <select id="filter_floor" class="filter-control">
                                    <option value="">所有楼层</option>
                                    <?php
                                    $floors = [];
                                    foreach ($availableRooms as $room) {
                                        if (!in_array($room['floor'], $floors)) {
                                            $floors[] = $room['floor'];
                                            echo '<option value="' . $room['floor'] . '">' . $room['floor'] . ' 楼</option>';
                                        }
                                    }
                                    ?>
                                </select>
                            </div>
                        </div>
                    </div>

                    <div class="room-selection">
                        <?php foreach ($availableRooms as $room): ?>
                            <?php
                            $isBooked = false;
                            foreach ($bookedRooms as $bookedRoom) {
                                if ($bookedRoom['room_id'] == $room['id']) {
                                    $isBooked = true;
                                    break;
                                }
                            }
                            ?>
                            <div class="room-item" data-room-type="<?php echo $room['room_type_id']; ?>" data-floor="<?php echo $room['floor']; ?>">
                                <input type="checkbox" id="room_<?php echo $room['id']; ?>" name="rooms[]" value="<?php echo $room['id']; ?>" <?php echo $isBooked ? 'checked' : ''; ?>>
                                <label for="room_<?php echo $room['id']; ?>" class="room-label">
                                    <div class="room-number"><?php echo htmlspecialchars($room['room_number']); ?></div>
                                    <div class="room-details">
                                        <div class="room-type"><?php echo htmlspecialchars($room['room_type']); ?></div>
                                        <div class="room-floor"><?php echo htmlspecialchars($room['floor']); ?> 楼</div>
                                        <div class="room-price">¥<?php echo number_format($room['base_price'] + $room['price_adjustment'], 2); ?>/晚</div>
                                    </div>
                                </label>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>

                <div class="form-section">
                    <h4>特殊要求</h4>

                    <div class="form-group">
                        <textarea id="notes" name="notes" rows="3"><?php echo htmlspecialchars($booking['special_requests'] ?? ''); ?></textarea>
                    </div>
                </div>

                <div class="form-actions">
                    <button type="submit" class="btn btn-primary">保存更改</button>
                    <a href="index.php?page=booking_view&id=<?php echo $bookingId; ?>" class="btn btn-secondary">取消</a>
                </div>
            </form>
        </div>
    </div>
</div>

<style>
    .content-wrapper {
        padding: 15px 0;
    }

    .page-header {
        margin-bottom: 20px;
    }

    .page-header h2 {
        margin-bottom: 5px;
    }

    .breadcrumb {
        font-size: 14px;
        color: #6c757d;
    }

    .breadcrumb a {
        color: #0066cc;
    }

    .card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        margin-bottom: 20px;
        overflow: hidden;
    }

    .card-header {
        padding: 15px;
        border-bottom: 1px solid #e9ecef;
        background-color: #f8f9fa;
    }

    .card-header h3 {
        margin: 0;
        font-size: 18px;
        color: #0066cc;
    }

    .card-body {
        padding: 15px;
    }

    .form-section {
        margin-bottom: 20px;
    }

    .form-section h4 {
        font-size: 16px;
        color: #495057;
        margin-bottom: 15px;
        padding-bottom: 5px;
        border-bottom: 1px solid #e9ecef;
    }

    .form-row {
        display: flex;
        flex-wrap: wrap;
        margin-right: -10px;
        margin-left: -10px;
    }

    .col-md-3 {
        flex: 0 0 25%;
        max-width: 25%;
        padding-right: 10px;
        padding-left: 10px;
    }

    .col-md-4 {
        flex: 0 0 33.333333%;
        max-width: 33.333333%;
        padding-right: 10px;
        padding-left: 10px;
    }

    .col-md-6 {
        flex: 0 0 50%;
        max-width: 50%;
        padding-right: 10px;
        padding-left: 10px;
    }

    .form-group {
        margin-bottom: 15px;
    }

    .form-group label {
        display: block;
        margin-bottom: 5px;
        font-weight: bold;
    }

    .form-group input,
    .form-group select,
    .form-group textarea {
        width: 100%;
        padding: 8px;
        border: 1px solid #ced4da;
        border-radius: 4px;
    }

    .required {
        color: #dc3545;
    }

    .room-filter {
        margin-bottom: 15px;
    }

    .room-selection {
        display: flex;
        flex-wrap: wrap;
        gap: 10px;
        margin-bottom: 15px;
    }

    .room-item {
        position: relative;
        width: 150px;
    }

    .room-item input[type="checkbox"] {
        position: absolute;
        opacity: 0;
    }

    .room-label {
        display: block;
        padding: 10px;
        border: 1px solid #ced4da;
        border-radius: 4px;
        cursor: pointer;
        transition: all 0.2s;
    }

    .room-item input[type="checkbox"]:checked+.room-label {
        background-color: #e6f7ff;
        border-color: #1890ff;
    }

    .room-number {
        font-size: 16px;
        font-weight: bold;
        color: #0066cc;
        margin-bottom: 5px;
    }

    .room-details {
        font-size: 12px;
    }

    .room-type {
        font-weight: bold;
    }

    .room-price {
        color: #dc3545;
    }

    .form-actions {
        display: flex;
        gap: 10px;
        margin-top: 20px;
    }

    @media (max-width: 768px) {

        .col-md-3,
        .col-md-4,
        .col-md-6 {
            flex: 0 0 100%;
            max-width: 100%;
        }
    }
</style>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 房间筛选功能
        const filterRoomType = document.getElementById('filter_room_type');
        const filterFloor = document.getElementById('filter_floor');
        const roomItems = document.querySelectorAll('.room-item');

        function applyFilters() {
            const roomTypeValue = filterRoomType.value;
            const floorValue = filterFloor.value;

            roomItems.forEach(function(item) {
                const roomType = item.getAttribute('data-room-type');
                const floor = item.getAttribute('data-floor');

                let showRoom = true;

                if (roomTypeValue && roomType !== roomTypeValue) {
                    showRoom = false;
                }

                if (floorValue && floor !== floorValue) {
                    showRoom = false;
                }

                item.style.display = showRoom ? 'block' : 'none';
            });
        }

        filterRoomType.addEventListener('change', applyFilters);
        filterFloor.addEventListener('change', applyFilters);

        // 日期变更时重新计算总价
        const checkInDate = document.getElementById('check_in_date');
        const checkOutDate = document.getElementById('check_out_date');

        function updateTotalAmount() {
            // 这里可以添加总价计算逻辑
        }

        checkInDate.addEventListener('change', updateTotalAmount);
        checkOutDate.addEventListener('change', updateTotalAmount);
    });
</script>