<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 检查是否有预订ID
if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    header('Location: index.php?page=booking_list');
    exit;
}

$bookingId = (int)$_GET['id'];

// 获取预订信息
$sql = "SELECT * FROM bookings WHERE id = ?";
$stmt = $conn->prepare($sql);
$stmt->bind_param("i", $bookingId);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows === 0) {
    header('Location: index.php?page=booking_list');
    exit;
}

$booking = $result->fetch_assoc();

// 获取预订房间信息
$roomsSql = "SELECT br.*, r.room_number, r.floor, rt.name as room_type 
             FROM booking_rooms br 
             JOIN rooms r ON br.room_id = r.id 
             JOIN room_types rt ON r.room_type_id = rt.id 
             WHERE br.booking_id = ?";
$roomsStmt = $conn->prepare($roomsSql);
$roomsStmt->bind_param("i", $bookingId);
$roomsStmt->execute();
$roomsResult = $roomsStmt->get_result();
$rooms = [];
if ($roomsResult && $roomsResult->num_rows > 0) {
    while ($row = $roomsResult->fetch_assoc()) {
        $rooms[] = $row;
    }
}

// 计算入住天数
$checkInDate = new DateTime($booking['check_in_date']);
$checkOutDate = new DateTime($booking['check_out_date']);
$interval = $checkInDate->diff($checkOutDate);
$nights = $interval->days;

// 处理更新预订状态
if (isset($_POST['action']) && $_POST['action'] == 'update_status') {
    $newStatus = sanitize($_POST['status']);

    // 验证状态值
    $validStatuses = ['pending', 'confirmed', 'checked_in', 'checked_out', 'cancelled'];
    if (!in_array($newStatus, $validStatuses)) {
        $errorMessage = '无效的状态值';
    } else {
        // 更新预订状态
        $updateSql = "UPDATE bookings SET status = ? WHERE id = ?";
        $updateStmt = $conn->prepare($updateSql);
        $updateStmt->bind_param("si", $newStatus, $bookingId);

        if ($updateStmt->execute()) {
            // 更新房间状态
            if ($newStatus == 'confirmed') {
                // 将房间状态更新为已预订
                foreach ($rooms as $room) {
                    $updateRoomSql = "UPDATE rooms SET status = 'booked' WHERE id = ?";
                    $updateRoomStmt = $conn->prepare($updateRoomSql);
                    $updateRoomStmt->bind_param("i", $room['room_id']);
                    $updateRoomStmt->execute();
                }
            } elseif ($newStatus == 'checked_in') {
                // 将房间状态更新为已入住
                foreach ($rooms as $room) {
                    $updateRoomSql = "UPDATE rooms SET status = 'occupied' WHERE id = ?";
                    $updateRoomStmt = $conn->prepare($updateRoomSql);
                    $updateRoomStmt->bind_param("i", $room['room_id']);
                    $updateRoomStmt->execute();
                }
            } elseif ($newStatus == 'checked_out' || $newStatus == 'cancelled') {
                // 将房间状态更新为可用
                foreach ($rooms as $room) {
                    $updateRoomSql = "UPDATE rooms SET status = 'available' WHERE id = ?";
                    $updateRoomStmt = $conn->prepare($updateRoomSql);
                    $updateRoomStmt->bind_param("i", $room['room_id']);
                    $updateRoomStmt->execute();
                }
            }

            // 记录操作日志
            logActivity('update_booking_status', '更新预订状态: ' . $booking['booking_number'] . ' - ' . $newStatus);

            // 设置成功消息并刷新页面
            $_SESSION['success_message'] = '预订状态更新成功';
            header('Location: index.php?page=booking_view&id=' . $bookingId);
            exit;
        } else {
            $errorMessage = '更新预订状态失败: ' . $conn->error;
        }
    }
}
?>

<div class="content-wrapper">
    <div class="page-header">
        <h2>预订详情</h2>
        <nav class="breadcrumb">
            <a href="index.php">概览</a> /
            <a href="index.php?page=booking_list">订单列表</a> /
            <span>预订详情</span>
        </nav>
    </div>

    <?php if (isset($_SESSION['success_message'])): ?>
        <div class="alert alert-success">
            <?php
            echo $_SESSION['success_message'];
            unset($_SESSION['success_message']);
            ?>
        </div>
    <?php endif; ?>

    <?php if (isset($errorMessage)): ?>
        <div class="alert alert-error"><?php echo $errorMessage; ?></div>
    <?php endif; ?>

    <div class="booking-header">
        <div class="booking-title">
            <h1>预订号: <?php echo htmlspecialchars($booking['booking_number']); ?></h1>
            <span class="status-badge status-<?php echo $booking['status']; ?>">
                <?php
                switch ($booking['status']) {
                    case 'pending':
                        echo '待确认';
                        break;
                    case 'confirmed':
                        echo '已确认';
                        break;
                    case 'checked_in':
                        echo '已入住';
                        break;
                    case 'checked_out':
                        echo '已完成';
                        break;
                    case 'cancelled':
                        echo '已取消';
                        break;
                    default:
                        echo $booking['status'];
                }
                ?>
            </span>
        </div>

        <div class="booking-actions">
            <a href="index.php?page=booking_edit&id=<?php echo $bookingId; ?>" class="btn btn-primary">编辑预订</a>

            <?php if ($booking['status'] == 'pending'): ?>
                <form method="post" action="" class="inline-form">
                    <input type="hidden" name="action" value="update_status">
                    <input type="hidden" name="status" value="confirmed">
                    <button type="submit" class="btn btn-success">确认预订</button>
                </form>
            <?php endif; ?>

            <?php if ($booking['status'] == 'confirmed'): ?>
                <a href="index.php?page=check_in&booking_id=<?php echo $bookingId; ?>" class="btn btn-success">办理入住</a>
                <form method="post" action="" class="inline-form">
                    <input type="hidden" name="action" value="update_status">
                    <input type="hidden" name="status" value="cancelled">
                    <button type="submit" class="btn btn-danger" onclick="return confirm('确定要取消此预订吗？');">取消预订</button>
                </form>
            <?php endif; ?>

            <?php if ($booking['status'] == 'checked_in'): ?>
                <a href="index.php?page=check_out&booking_id=<?php echo $bookingId; ?>" class="btn btn-success">办理退房</a>
            <?php endif; ?>
        </div>
    </div>

    <div class="booking-content">
        <div class="booking-details">
            <div class="card">
                <div class="card-header">
                    <h3>客人信息</h3>
                </div>
                <div class="card-body">
                    <div class="detail-row">
                        <div class="detail-label">客人姓名</div>
                        <div class="detail-value"><?php echo htmlspecialchars($booking['guest_name']); ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">联系电话</div>
                        <div class="detail-value"><?php echo htmlspecialchars($booking['guest_phone']); ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">电子邮箱</div>
                        <div class="detail-value"><?php echo htmlspecialchars($booking['guest_email']); ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">证件类型</div>
                        <div class="detail-value">
                            <?php
                            switch ($booking['guest_id_type']) {
                                case 'id_card':
                                    echo '身份证';
                                    break;
                                case 'passport':
                                    echo '护照';
                                    break;
                                case 'driving_license':
                                    echo '驾驶证';
                                    break;
                                case 'other':
                                    echo '其他';
                                    break;
                                default:
                                    echo $booking['guest_id_type'];
                            }
                            ?>
                        </div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">证件号码</div>
                        <div class="detail-value"><?php echo htmlspecialchars($booking['guest_id_number']); ?></div>
                    </div>
                </div>
            </div>

            <div class="card">
                <div class="card-header">
                    <h3>预订信息</h3>
                </div>
                <div class="card-body">
                    <div class="detail-row">
                        <div class="detail-label">入住日期</div>
                        <div class="detail-value"><?php echo date('Y-m-d', strtotime($booking['check_in_date'])); ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">退房日期</div>
                        <div class="detail-value"><?php echo date('Y-m-d', strtotime($booking['check_out_date'])); ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">入住天数</div>
                        <div class="detail-value"><?php echo $nights; ?> 晚</div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">成人数量</div>
                        <div class="detail-value"><?php echo $booking['adults']; ?> 人</div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">儿童数量</div>
                        <div class="detail-value"><?php echo $booking['children']; ?> 人</div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">预订来源</div>
                        <div class="detail-value">
                            <?php
                            switch ($booking['booking_source']) {
                                case 'direct':
                                    echo '直接预订';
                                    break;
                                case 'website':
                                    echo '官网';
                                    break;
                                case 'phone':
                                    echo '电话';
                                    break;
                                case 'email':
                                    echo '邮件';
                                    break;
                                case 'walk_in':
                                    echo '门店';
                                    break;
                                case 'ota':
                                    echo 'OTA平台';
                                    break;
                                default:
                                    echo htmlspecialchars($booking['booking_source']);
                            }
                            ?>
                        </div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">创建时间</div>
                        <div class="detail-value"><?php echo date('Y-m-d H:i:s', strtotime($booking['created_at'])); ?></div>
                    </div>
                    <?php if (!empty($booking['special_requests'])): ?>
                        <div class="detail-section">
                            <h4>特殊要求</h4>
                            <div class="special-requests">
                                <?php echo nl2br(htmlspecialchars($booking['special_requests'])); ?>
                            </div>
                        </div>
                    <?php endif; ?>
                </div>
            </div>

            <div class="card">
                <div class="card-header">
                    <h3>付款信息</h3>
                </div>
                <div class="card-body">
                    <div class="detail-row">
                        <div class="detail-label">总金额</div>
                        <div class="detail-value price-highlight">¥<?php echo number_format($booking['total_amount'], 2); ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">已付定金</div>
                        <div class="detail-value">¥<?php echo number_format($booking['deposit_amount'], 2); ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">待付金额</div>
                        <div class="detail-value price-highlight">¥<?php echo number_format($booking['total_amount'] - $booking['deposit_amount'], 2); ?></div>
                    </div>
                </div>
            </div>
        </div>

        <div class="booking-rooms">
            <div class="card">
                <div class="card-header">
                    <h3>预订房间</h3>
                </div>
                <div class="card-body">
                    <?php if (empty($rooms)): ?>
                        <p class="no-data">暂无房间数据</p>
                    <?php else: ?>
                        <table class="data-table">
                            <thead>
                                <tr>
                                    <th>房间号</th>
                                    <th>楼层</th>
                                    <th>房型</th>
                                    <th>房价/晚</th>
                                    <th>总价</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($rooms as $room): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($room['room_number']); ?></td>
                                        <td><?php echo htmlspecialchars($room['floor']); ?> 楼</td>
                                        <td><?php echo htmlspecialchars($room['room_type']); ?></td>
                                        <td>¥<?php echo number_format($room['room_rate'], 2); ?></td>
                                        <td>¥<?php echo number_format($room['room_rate'] * $nights, 2); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                            <tfoot>
                                <tr>
                                    <td colspan="4" class="text-right"><strong>总计</strong></td>
                                    <td class="price-highlight">¥<?php echo number_format($booking['total_amount'], 2); ?></td>
                                </tr>
                            </tfoot>
                        </table>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>
</div>

<style>
    .content-wrapper {
        padding: 15px 0;
    }

    .page-header {
        margin-bottom: 20px;
    }

    .page-header h2 {
        margin-bottom: 5px;
    }

    .breadcrumb {
        font-size: 14px;
        color: #6c757d;
    }

    .breadcrumb a {
        color: #0066cc;
    }

    .booking-header {
        display: flex;
        justify-content: space-between;
        align-items: center;
        margin-bottom: 20px;
    }

    .booking-title h1 {
        font-size: 24px;
        margin: 0 0 5px 0;
    }

    .booking-actions {
        display: flex;
        gap: 10px;
    }

    .inline-form {
        display: inline;
    }

    .booking-content {
        display: flex;
        flex-wrap: wrap;
        gap: 20px;
    }

    .booking-details {
        flex: 1;
        min-width: 300px;
    }

    .booking-rooms {
        flex: 1;
        min-width: 300px;
    }

    .card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        margin-bottom: 20px;
        overflow: hidden;
    }

    .card-header {
        padding: 15px;
        border-bottom: 1px solid #e9ecef;
        background-color: #f8f9fa;
    }

    .card-header h3 {
        margin: 0;
        font-size: 18px;
        color: #0066cc;
    }

    .card-body {
        padding: 15px;
    }

    .detail-row {
        display: flex;
        margin-bottom: 10px;
    }

    .detail-label {
        width: 120px;
        font-weight: bold;
        color: #495057;
    }

    .detail-value {
        flex: 1;
    }

    .price-highlight {
        font-weight: bold;
        color: #dc3545;
    }

    .detail-section {
        margin-top: 15px;
    }

    .detail-section h4 {
        font-size: 16px;
        color: #495057;
        margin-bottom: 10px;
    }

    .special-requests {
        background-color: #f8f9fa;
        padding: 10px;
        border-radius: 4px;
        line-height: 1.6;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 10px;
        text-align: left;
        border-bottom: 1px solid #e9ecef;
    }

    .data-table th {
        background-color: #f8f9fa;
        font-weight: bold;
        color: #495057;
    }

    .data-table tfoot td {
        border-top: 2px solid #dee2e6;
        font-weight: bold;
    }

    .text-right {
        text-align: right;
    }

    .status-badge {
        display: inline-block;
        padding: 3px 8px;
        border-radius: 4px;
        font-size: 12px;
        color: #fff;
    }

    .status-pending {
        background-color: #ffc107;
        color: #212529;
    }

    .status-confirmed {
        background-color: #17a2b8;
    }

    .status-checked_in {
        background-color: #28a745;
    }

    .status-checked_out {
        background-color: #0066cc;
    }

    .status-cancelled {
        background-color: #dc3545;
    }

    .no-data {
        text-align: center;
        padding: 20px;
        color: #6c757d;
        background-color: #f8f9fa;
        border-radius: 8px;
    }

    @media (max-width: 768px) {
        .booking-header {
            flex-direction: column;
            align-items: flex-start;
        }

        .booking-actions {
            margin-top: 10px;
            flex-wrap: wrap;
        }
    }
</style>