<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 检查是否有预订ID
if (!isset($_GET['booking_id']) || !is_numeric($_GET['booking_id'])) {
    header('Location: index.php?page=booking_list');
    exit;
}

$bookingId = (int)$_GET['booking_id'];

// 获取预订信息
$sql = "SELECT * FROM bookings WHERE id = ?";
$stmt = $conn->prepare($sql);
$stmt->bind_param("i", $bookingId);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows === 0) {
    header('Location: index.php?page=booking_list');
    exit;
}

$booking = $result->fetch_assoc();

// 检查预订状态是否为已入住
if ($booking['status'] !== 'checked_in') {
    $_SESSION['error_message'] = '只有已入住的预订才能办理退房';
    header('Location: index.php?page=booking_view&id=' . $bookingId);
    exit;
}

// 获取预订房间信息
$roomsSql = "SELECT br.*, r.room_number, r.floor, rt.name as room_type 
             FROM booking_rooms br 
             JOIN rooms r ON br.room_id = r.id 
             JOIN room_types rt ON r.room_type_id = rt.id 
             WHERE br.booking_id = ?";
$roomsStmt = $conn->prepare($roomsSql);
$roomsStmt->bind_param("i", $bookingId);
$roomsStmt->execute();
$roomsResult = $roomsStmt->get_result();
$rooms = [];
if ($roomsResult && $roomsResult->num_rows > 0) {
    while ($row = $roomsResult->fetch_assoc()) {
        $rooms[] = $row;
    }
}

// 获取已付款信息
$paymentsSql = "SELECT * FROM payments WHERE booking_id = ? ORDER BY payment_date ASC";
$paymentsStmt = $conn->prepare($paymentsSql);
$paymentsStmt->bind_param("i", $bookingId);
$paymentsStmt->execute();
$paymentsResult = $paymentsStmt->get_result();
$payments = [];
$totalPaid = 0;
if ($paymentsResult && $paymentsResult->num_rows > 0) {
    while ($row = $paymentsResult->fetch_assoc()) {
        $payments[] = $row;
        $totalPaid += $row['amount'];
    }
}

// 计算入住天数
$checkInDate = new DateTime($booking['check_in_date']);
$checkOutDate = new DateTime($booking['check_out_date']);
$interval = $checkInDate->diff($checkOutDate);
$bookedNights = $interval->days;

// 计算实际入住天数
$actualCheckInDate = new DateTime($booking['actual_check_in_date'] ?? $booking['check_in_date']);
$today = new DateTime();
$actualInterval = $actualCheckInDate->diff($today);
$actualNights = $actualInterval->days;

// 计算额外费用（如果实际入住天数超过预订天数）
$extraNights = max(0, $actualNights - $bookedNights);
$extraFees = 0;
if ($extraNights > 0) {
    // 计算每晚平均价格
    $avgNightlyRate = $booking['total_amount'] / $bookedNights;
    $extraFees = $extraNights * $avgNightlyRate;
}

// 计算待付金额
$balanceDue = $booking['total_amount'] + $extraFees - $totalPaid;

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // 获取表单数据
    $actualCheckOutDate = sanitize($_POST['actual_check_out_date']);
    $additionalCharges = (float)$_POST['additional_charges'];
    $additionalChargesDesc = sanitize($_POST['additional_charges_desc']);
    $paymentAmount = (float)$_POST['payment_amount'];
    $paymentMethod = sanitize($_POST['payment_method']);
    $roomCondition = sanitize($_POST['room_condition']);
    $notes = sanitize($_POST['notes']);

    // 验证数据
    $errors = [];

    if (empty($actualCheckOutDate)) {
        $errors[] = '实际退房日期不能为空';
    }

    // 如果没有错误，处理退房
    if (empty($errors)) {
        // 开始事务
        $conn->begin_transaction();

        try {
            // 更新预订状态为已退房
            $updateBookingSql = "UPDATE bookings SET 
                                 status = 'checked_out',
                                 special_requests = CONCAT(IFNULL(special_requests, ''), '\n', ?) 
                                 WHERE id = ?";
            $updateBookingStmt = $conn->prepare($updateBookingSql);
            $updateBookingStmt->bind_param("si", $notes, $bookingId);
            $updateBookingStmt->execute();

            // 更新房间状态为可用
            foreach ($rooms as $room) {
                $updateRoomSql = "UPDATE rooms SET status = 'available' WHERE id = ?";
                $updateRoomStmt = $conn->prepare($updateRoomSql);
                $updateRoomStmt->bind_param("i", $room['room_id']);
                $updateRoomStmt->execute();
            }

            // 记录付款（如果有）
            if ($paymentAmount > 0) {
                $paymentSql = "INSERT INTO payments (booking_id, amount, payment_method, payment_date, notes) 
                               VALUES (?, ?, ?, NOW(), '退房时付款')";
                $paymentStmt = $conn->prepare($paymentSql);
                $paymentStmt->bind_param("ids", $bookingId, $paymentAmount, $paymentMethod);
                $paymentStmt->execute();
            }

            // 提交事务
            $conn->commit();

            // 记录操作日志
            logActivity('check_out', '办理退房: ' . $booking['booking_number']);

            // 设置成功消息并重定向
            $_SESSION['success_message'] = '退房办理成功';
            header('Location: index.php?page=booking_view&id=' . $bookingId);
            exit;
        } catch (Exception $e) {
            // 回滚事务
            $conn->rollback();
            $errors[] = '办理退房失败: ' . $e->getMessage();
        }
    }
}
?>

<div class="content-wrapper">
    <div class="page-header">
        <h2>办理退房</h2>
        <nav class="breadcrumb">
            <a href="index.php">概览</a> /
            <a href="index.php?page=booking_list">订单列表</a> /
            <a href="index.php?page=booking_view&id=<?php echo $bookingId; ?>">预订详情</a> /
            <span>办理退房</span>
        </nav>
    </div>

    <?php if (!empty($errors)): ?>
        <div class="alert alert-error">
            <ul>
                <?php foreach ($errors as $error): ?>
                    <li><?php echo $error; ?></li>
                <?php endforeach; ?>
            </ul>
        </div>
    <?php endif; ?>

    <div class="check-out-container">
        <div class="booking-summary">
            <div class="card">
                <div class="card-header">
                    <h3>预订信息</h3>
                </div>
                <div class="card-body">
                    <div class="detail-row">
                        <div class="detail-label">预订号</div>
                        <div class="detail-value"><?php echo htmlspecialchars($booking['booking_number']); ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">客人姓名</div>
                        <div class="detail-value"><?php echo htmlspecialchars($booking['guest_name']); ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">联系电话</div>
                        <div class="detail-value"><?php echo htmlspecialchars($booking['guest_phone']); ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">预订入住日期</div>
                        <div class="detail-value"><?php echo date('Y-m-d', strtotime($booking['check_in_date'])); ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">预订退房日期</div>
                        <div class="detail-value"><?php echo date('Y-m-d', strtotime($booking['check_out_date'])); ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">实际入住日期</div>
                        <div class="detail-value"><?php echo date('Y-m-d', strtotime($booking['actual_check_in_date'] ?? $booking['check_in_date'])); ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">预订天数</div>
                        <div class="detail-value"><?php echo $bookedNights; ?> 晚</div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">实际入住天数</div>
                        <div class="detail-value"><?php echo $actualNights; ?> 晚</div>
                    </div>
                    <?php if ($extraNights > 0): ?>
                        <div class="detail-row">
                            <div class="detail-label">超出天数</div>
                            <div class="detail-value price-highlight"><?php echo $extraNights; ?> 晚</div>
                        </div>
                    <?php endif; ?>
                </div>
            </div>

            <div class="card">
                <div class="card-header">
                    <h3>房间信息</h3>
                </div>
                <div class="card-body">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>房间号</th>
                                <th>楼层</th>
                                <th>房型</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($rooms as $room): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($room['room_number']); ?></td>
                                    <td><?php echo htmlspecialchars($room['floor']); ?> 楼</td>
                                    <td><?php echo htmlspecialchars($room['room_type']); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            </div>

            <div class="card">
                <div class="card-header">
                    <h3>付款信息</h3>
                </div>
                <div class="card-body">
                    <div class="detail-row">
                        <div class="detail-label">预订总金额</div>
                        <div class="detail-value">¥<?php echo number_format($booking['total_amount'], 2); ?></div>
                    </div>
                    <?php if ($extraFees > 0): ?>
                        <div class="detail-row">
                            <div class="detail-label">额外住宿费</div>
                            <div class="detail-value price-highlight">¥<?php echo number_format($extraFees, 2); ?></div>
                        </div>
                    <?php endif; ?>
                    <div class="detail-row">
                        <div class="detail-label">已付金额</div>
                        <div class="detail-value">¥<?php echo number_format($totalPaid, 2); ?></div>
                    </div>
                    <div class="detail-row">
                        <div class="detail-label">待付金额</div>
                        <div class="detail-value price-highlight">¥<?php echo number_format($balanceDue, 2); ?></div>
                    </div>

                    <?php if (!empty($payments)): ?>
                        <div class="detail-section">
                            <h4>付款记录</h4>
                            <table class="data-table">
                                <thead>
                                    <tr>
                                        <th>日期</th>
                                        <th>金额</th>
                                        <th>支付方式</th>
                                        <th>备注</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($payments as $payment): ?>
                                        <tr>
                                            <td><?php echo date('Y-m-d', strtotime($payment['payment_date'])); ?></td>
                                            <td>¥<?php echo number_format($payment['amount'], 2); ?></td>
                                            <td>
                                                <?php
                                                switch ($payment['payment_method']) {
                                                    case 'cash':
                                                        echo '现金';
                                                        break;
                                                    case 'credit_card':
                                                        echo '信用卡';
                                                        break;
                                                    case 'debit_card':
                                                        echo '借记卡';
                                                        break;
                                                    case 'wechat':
                                                        echo '微信支付';
                                                        break;
                                                    case 'alipay':
                                                        echo '支付宝';
                                                        break;
                                                    default:
                                                        echo htmlspecialchars($payment['payment_method']);
                                                }
                                                ?>
                                            </td>
                                            <td><?php echo htmlspecialchars($payment['notes']); ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>

        <div class="check-out-form">
            <div class="card">
                <div class="card-header">
                    <h3>退房信息</h3>
                </div>
                <div class="card-body">
                    <form method="post" action="">
                        <div class="form-section">
                            <h4>退房详情</h4>

                            <div class="form-group">
                                <label for="actual_check_out_date">实际退房日期 <span class="required">*</span></label>
                                <input type="date" id="actual_check_out_date" name="actual_check_out_date" value="<?php echo isset($_POST['actual_check_out_date']) ? htmlspecialchars($_POST['actual_check_out_date']) : date('Y-m-d'); ?>" required>
                            </div>

                            <div class="form-group">
                                <label for="room_condition">房间状况</label>
                                <select id="room_condition" name="room_condition">
                                    <option value="good" <?php echo (isset($_POST['room_condition']) && $_POST['room_condition'] == 'good') ? 'selected' : ''; ?>>良好</option>
                                    <option value="minor_issues" <?php echo (isset($_POST['room_condition']) && $_POST['room_condition'] == 'minor_issues') ? 'selected' : ''; ?>>轻微问题</option>
                                    <option value="damaged" <?php echo (isset($_POST['room_condition']) && $_POST['room_condition'] == 'damaged') ? 'selected' : ''; ?>>损坏</option>
                                </select>
                            </div>
                        </div>

                        <div class="form-section">
                            <h4>额外费用</h4>

                            <div class="form-row">
                                <div class="form-group col-md-6">
                                    <label for="additional_charges">额外费用</label>
                                    <input type="number" id="additional_charges" name="additional_charges" step="0.01" min="0" value="<?php echo isset($_POST['additional_charges']) ? (float)$_POST['additional_charges'] : $extraFees; ?>">
                                </div>

                                <div class="form-group col-md-6">
                                    <label for="additional_charges_desc">费用说明</label>
                                    <input type="text" id="additional_charges_desc" name="additional_charges_desc" value="<?php echo isset($_POST['additional_charges_desc']) ? htmlspecialchars($_POST['additional_charges_desc']) : ($extraNights > 0 ? '额外住宿 ' . $extraNights . ' 晚' : ''); ?>">
                                </div>
                            </div>
                        </div>

                        <div class="form-section">
                            <h4>付款信息</h4>

                            <div class="form-row">
                                <div class="form-group col-md-6">
                                    <label for="payment_amount">付款金额</label>
                                    <input type="number" id="payment_amount" name="payment_amount" step="0.01" min="0" value="<?php echo isset($_POST['payment_amount']) ? (float)$_POST['payment_amount'] : $balanceDue; ?>">
                                </div>

                                <div class="form-group col-md-6">
                                    <label for="payment_method">付款方式</label>
                                    <select id="payment_method" name="payment_method">
                                        <option value="cash" <?php echo (isset($_POST['payment_method']) && $_POST['payment_method'] == 'cash') ? 'selected' : ''; ?>>现金</option>
                                        <option value="credit_card" <?php echo (isset($_POST['payment_method']) && $_POST['payment_method'] == 'credit_card') ? 'selected' : ''; ?>>信用卡</option>
                                        <option value="debit_card" <?php echo (isset($_POST['payment_method']) && $_POST['payment_method'] == 'debit_card') ? 'selected' : ''; ?>>借记卡</option>
                                        <option value="wechat" <?php echo (isset($_POST['payment_method']) && $_POST['payment_method'] == 'wechat') ? 'selected' : ''; ?>>微信支付</option>
                                        <option value="alipay" <?php echo (isset($_POST['payment_method']) && $_POST['payment_method'] == 'alipay') ? 'selected' : ''; ?>>支付宝</option>
                                    </select>
                                </div>
                            </div>
                        </div>

                        <div class="form-section">
                            <h4>备注</h4>

                            <div class="form-group">
                                <textarea id="notes" name="notes" rows="3"><?php echo isset($_POST['notes']) ? htmlspecialchars($_POST['notes']) : ''; ?></textarea>
                            </div>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-primary">确认退房</button>
                            <a href="index.php?page=booking_view&id=<?php echo $bookingId; ?>" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>
</div>

<style>
    .content-wrapper {
        padding: 15px 0;
    }

    .page-header {
        margin-bottom: 20px;
    }

    .page-header h2 {
        margin-bottom: 5px;
    }

    .breadcrumb {
        font-size: 14px;
        color: #6c757d;
    }

    .breadcrumb a {
        color: #0066cc;
    }

    .check-out-container {
        display: flex;
        flex-wrap: wrap;
        gap: 20px;
    }

    .booking-summary {
        flex: 1;
        min-width: 300px;
    }

    .check-out-form {
        flex: 2;
        min-width: 300px;
    }

    .card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        margin-bottom: 20px;
        overflow: hidden;
    }

    .card-header {
        padding: 15px;
        border-bottom: 1px solid #e9ecef;
        background-color: #f8f9fa;
    }

    .card-header h3 {
        margin: 0;
        font-size: 18px;
        color: #0066cc;
    }

    .card-body {
        padding: 15px;
    }

    .detail-row {
        display: flex;
        margin-bottom: 10px;
    }

    .detail-label {
        width: 120px;
        font-weight: bold;
        color: #495057;
    }

    .detail-value {
        flex: 1;
    }

    .price-highlight {
        font-weight: bold;
        color: #dc3545;
    }

    .detail-section {
        margin-top: 15px;
    }

    .detail-section h4 {
        font-size: 16px;
        color: #495057;
        margin-bottom: 10px;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 10px;
        text-align: left;
        border-bottom: 1px solid #e9ecef;
    }

    .data-table th {
        background-color: #f8f9fa;
        font-weight: bold;
        color: #495057;
    }

    .form-section {
        margin-bottom: 20px;
    }

    .form-section h4 {
        font-size: 16px;
        color: #495057;
        margin-bottom: 15px;
        padding-bottom: 5px;
        border-bottom: 1px solid #e9ecef;
    }

    .form-row {
        display: flex;
        flex-wrap: wrap;
        margin-right: -10px;
        margin-left: -10px;
    }

    .col-md-6 {
        flex: 0 0 50%;
        max-width: 50%;
        padding-right: 10px;
        padding-left: 10px;
    }

    .form-group {
        margin-bottom: 15px;
    }

    .form-group label {
        display: block;
        margin-bottom: 5px;
        font-weight: bold;
    }

    .required {
        color: #dc3545;
    }

    .form-actions {
        display: flex;
        gap: 10px;
        margin-top: 20px;
    }

    @media (max-width: 768px) {
        .col-md-6 {
            flex: 0 0 100%;
            max-width: 100%;
        }
    }
</style>