<?php

require_once '../../config/config.php';
require_once '../../includes/functions.php';
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $errors = [];

    // 获取基本信息
    $groupName = sanitize($_POST['group_name']);
    $contactPerson = sanitize($_POST['contact_person']);
    $contactPhone = sanitize($_POST['contact_phone']);
    $checkInDate = sanitize($_POST['check_in_date']);
    $checkOutDate = sanitize($_POST['check_out_date']);
    $totalGuests = (int)$_POST['total_guests'];
    $bookingType = sanitize($_POST['booking_type']); // group 或 long_term
    $specialRequests = sanitize($_POST['special_requests']);
    $guestIdType = sanitize($_POST['guest_id_type']);
    $guestIdNumber = sanitize($_POST['guest_id_number']);

    // 验证数据
    if (empty($groupName)) {
        $errors[] = '团队名称不能为空';
    }

    if (empty($contactPerson)) {
        $errors[] = '联系人不能为空';
    }

    if (empty($contactPhone)) {
        $errors[] = '联系电话不能为空';
    }

    if (empty($checkInDate) || empty($checkOutDate)) {
        $errors[] = '入住和退房日期不能为空';
    }

    if ($totalGuests <= 0) {
        $errors[] = '总人数必须大于0';
    }

    // 验证选择的房间
    $selectedRooms = isset($_POST['rooms']) ? $_POST['rooms'] : [];
    if (empty($selectedRooms)) {
        $errors[] = '请至少选择一个房间';
    }

    // 如果没有错误，创建团队预订
    if (empty($errors)) {
        try {
            // 检查数据库连接
            if ($conn->connect_error) {
                throw new Exception("数据库连接失败: " . $conn->connect_error);
            }

            $conn->begin_transaction();

            // 创建主预订记录
            $bookingNumber = generateBookingNumber();
            $insertBookingSql = "INSERT INTO bookings (
                booking_number, guest_name, guest_phone, guest_email,
                guest_id_type, guest_id_number, check_in_date, check_out_date,
                adults, children, booking_source,
                status, total_amount, payment_status, created_by, created_at, updated_at
            ) VALUES (?, ?, ?, NULL, ?, ?, ?, ?, ?, ?, ?,
                ?, ?, ?, ?, NOW(), NOW())";

            $stmt = $conn->prepare($insertBookingSql);
            if ($stmt === false) {
                throw new Exception("准备SQL语句失败: " . $conn->error . "\nSQL: " . $insertBookingSql);
            }
            $status = 'pending';
            $bookingSource = 'direct';
            $totalAmount = 0.00;
            $paymentStatus = 'unpaid';
            $children = 0; // children默认为0
            $createdBy = isset($_SESSION['user_id']) ? $_SESSION['user_id'] : NULL; // 添加创建者ID

            $stmt->bind_param(
                "ssssssiissdssi",
                $bookingNumber,
                $groupName,
                $contactPhone,
                $guestIdType,
                $guestIdNumber,
                $checkInDate,
                $checkOutDate,
                $totalGuests,
                $children,
                $bookingSource,
                $status,
                $totalAmount,
                $paymentStatus,
                $createdBy
            );
            $stmt->execute();
            $bookingId = $conn->insert_id;

            // 添加团队/长租信息到bookings表的special_requests字段中
            $updateBookingSql = "UPDATE bookings SET special_requests = ? WHERE id = ?";
            $stmt = $conn->prepare($updateBookingSql);
            if ($stmt === false) {
                throw new Exception("准备更新SQL语句失败: " . $conn->error . "\nSQL: " . $updateBookingSql . "\nbookingId: " . $bookingId);
            }
            $specialRequestsValue = sprintf(
                '预订类型: %s, 联系人: %s, 电话: %s%s',
                $bookingType == 'group' ? '团队预订' : '长租预订',
                $contactPerson,
                $contactPhone,
                $specialRequests ? ", " . $specialRequests : ""
            );
            $stmt->bind_param("si", $specialRequestsValue, $bookingId);
            if (!$stmt->execute()) {
                throw new Exception("执行更新special_requests语句失败: " . $stmt->error);
            }

            // 添加房间信息
            $totalAmount = 0;
            foreach ($selectedRooms as $roomId => $roomData) {
                if (!isset($roomData['selected']) || $roomData['selected'] != 1) {
                    continue;
                }

                $insertBookingRoomSql = "INSERT INTO booking_rooms (
                    booking_id, room_id, room_rate, date_from, date_to
                ) VALUES (?, ?, ?, ?, ?)";
                $stmt = $conn->prepare($insertBookingRoomSql);
                if ($stmt === false) {
                    throw new Exception("准备房间预订SQL语句失败: " . $conn->error . "\nSQL: " . $insertBookingRoomSql);
                }

                $roomIdValue = (int)$roomId;
                $roomRate = (float)$roomData['rate'];
                $stmt->bind_param("iidss", $bookingId, $roomIdValue, $roomRate, $checkInDate, $checkOutDate);
                $stmt->execute();

                // 更新房间状态
                $updateRoomSql = "UPDATE rooms SET status = ? WHERE id = ?";
                $stmt = $conn->prepare($updateRoomSql);
                if ($stmt === false) {
                    throw new Exception("准备更新房间状态SQL语句失败: " . $conn->error . "\nSQL: " . $updateRoomSql);
                }
                $roomStatus = 'booked';
                $stmt->bind_param("si", $roomStatus, $roomIdValue);
                $stmt->execute();

                // 计算总金额
                $totalAmount += $roomRate;
            }

            // 更新预订总金额
            $updateAmountSql = "UPDATE bookings SET total_amount = ? WHERE id = ?";
            $stmt = $conn->prepare($updateAmountSql);
            if ($stmt === false) {
                throw new Exception("准备更新总金额SQL语句失败: " . $conn->error . "\nSQL: " . $updateAmountSql);
            }
            $stmt->bind_param("di", $totalAmount, $bookingId);
            $stmt->execute();

            $conn->commit();

            // 记录操作日志
            logActivity('group_booking', '创建' . ($bookingType == 'group' ? '团队预订' : '长租预订') . ': ' . $bookingNumber);

            // 设置成功消息并重定向
            $_SESSION['success_message'] = '预订创建成功';
            header('Location: index.php?page=booking_view&id=' . $bookingId);
            exit;
        } catch (Exception $e) {
            $conn->rollback();
            $errors[] = '创建预订失败: ' . $e->getMessage();
        }
    }
}

// 获取可用房间
$availableRoomsSql = "SELECT r.*, rt.name as room_type, rt.base_price 
                      FROM rooms r 
                      JOIN room_types rt ON r.room_type_id = rt.id 
                      WHERE r.status = 'available' 
                      ORDER BY r.floor, r.room_number";
$availableRoomsResult = $conn->query($availableRoomsSql);
$availableRooms = [];
if ($availableRoomsResult && $availableRoomsResult->num_rows > 0) {
    while ($row = $availableRoomsResult->fetch_assoc()) {
        $availableRooms[] = $row;
    }
}
?>

<div class="content-wrapper">
    <div class="page-header">
        <h2>团队/长租预订</h2>
        <nav class="breadcrumb">
            <a href="index.php">概览</a> /
            <span>团队/长租预订</span>
        </nav>
    </div>

    <?php if (!empty($errors)): ?>
        <div class="alert alert-error">
            <ul>
                <?php foreach ($errors as $error): ?>
                    <li><?php echo $error; ?></li>
                <?php endforeach; ?>
            </ul>
        </div>
    <?php endif; ?>

    <div class="booking-container">
        <form method="post" action="" id="groupBookingForm">
            <div class="form-section">
                <h3>基本信息</h3>
                <div class="form-row">
                    <div class="form-group col-md-6">
                        <label for="booking_type">预订类型 <span class="required">*</span></label>
                        <select id="booking_type" name="booking_type" required>
                            <option value="group">团队预订</option>
                            <option value="long_term">长租预订</option>
                        </select>
                    </div>
                </div>

                <div class="form-row">
                    <div class="form-group col-md-6">
                        <label for="group_name">团队名称 <span class="required">*</span></label>
                        <input type="text" id="group_name" name="group_name" required>
                    </div>

                    <div class="form-group col-md-6">
                        <label for="total_guests">总人数 <span class="required">*</span></label>
                        <input type="number" id="total_guests" name="total_guests" min="1" required>
                    </div>
                </div>

                <div class="form-row">
                    <div class="form-group col-md-6">
                        <label for="contact_person">联系人 <span class="required">*</span></label>
                        <input type="text" id="contact_person" name="contact_person" required>
                    </div>

                    <div class="form-group col-md-6">
                        <label for="contact_phone">联系电话 <span class="required">*</span></label>
                        <input type="text" id="contact_phone" name="contact_phone" required>
                    </div>
                </div>

                <div class="form-row">
                    <div class="form-group col-md-6">
                        <label for="check_in_date">入住日期 <span class="required">*</span></label>
                        <input type="date" id="check_in_date" name="check_in_date" required>
                    </div>

                    <div class="form-group col-md-6">
                        <label for="check_out_date">退房日期 <span class="required">*</span></label>
                        <input type="date" id="check_out_date" name="check_out_date" required>
                    </div>
                </div>

                <div class="form-row">
                    <div class="form-group col-md-6">
                        <label for="guest_id_type">证件类型 <span class="required">*</span></label>
                        <select id="guest_id_type" name="guest_id_type" required>
                            <option value="id_card">身份证</option>
                            <option value="passport">护照</option>
                            <option value="driving_license">驾驶证</option>
                            <option value="other">其他</option>
                        </select>
                    </div>

                    <div class="form-group col-md-6">
                        <label for="guest_id_number">证件号码 <span class="required">*</span></label>
                        <input type="text" id="guest_id_number" name="guest_id_number" required>
                    </div>
                </div>
            </div>

            <div class="form-section">
                <h3>房间选择</h3>
                <div class="room-selection">
                    <?php foreach ($availableRooms as $room): ?>
                        <div class="room-item">
                            <div class="room-info">
                                <h4><?php echo htmlspecialchars($room['room_number']); ?> 号房</h4>
                                <p>楼层: <?php echo htmlspecialchars($room['floor']); ?> 楼</p>
                                <p>房型: <?php echo htmlspecialchars($room['room_type']); ?></p>
                                <p>基础价格: ¥<?php echo number_format($room['base_price'], 2); ?>/晚</p>
                            </div>
                            <div class="room-actions">
                                <label class="checkbox-container">
                                    <input type="checkbox" name="rooms[<?php echo $room['id']; ?>][selected]" value="1">
                                    <span class="checkmark"></span>
                                </label>
                                <input type="number"
                                    name="rooms[<?php echo $room['id']; ?>][rate]"
                                    value="<?php echo $room['base_price']; ?>"
                                    step="0.01"
                                    min="0"
                                    class="room-rate"
                                    placeholder="房价/晚">
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>

            <div class="form-section">
                <h3>其他信息</h3>
                <div class="form-group">
                    <label for="special_requests">特殊要求</label>
                    <textarea id="special_requests" name="special_requests" rows="4"></textarea>
                </div>
            </div>

            <div class="form-actions">
                <button type="submit" class="btn btn-primary">创建预订</button>
                <a href="index.php?page=booking_list" class="btn btn-secondary">取消</a>
            </div>
        </form>
    </div>
</div>

<style>
    .booking-container {
        max-width: 1200px;
        margin: 0 auto;
        padding: 20px;
    }

    .form-section {
        background: #fff;
        border-radius: 8px;
        padding: 20px;
        margin-bottom: 20px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
    }

    .form-section h3 {
        margin: 0 0 20px 0;
        color: #0066cc;
        border-bottom: 1px solid #eee;
        padding-bottom: 10px;
    }

    .room-selection {
        display: grid;
        grid-template-columns: repeat(auto-fill, minmax(300px, 1fr));
        gap: 20px;
    }

    .room-item {
        border: 1px solid #eee;
        border-radius: 8px;
        padding: 15px;
        display: flex;
        justify-content: space-between;
        align-items: center;
    }

    .room-info h4 {
        margin: 0 0 10px 0;
        color: #0066cc;
    }

    .room-info p {
        margin: 5px 0;
        color: #666;
    }

    .room-actions {
        display: flex;
        flex-direction: column;
        gap: 10px;
        align-items: flex-end;
    }

    .room-rate {
        width: 100px;
        padding: 5px;
        border: 1px solid #ddd;
        border-radius: 4px;
    }

    .checkbox-container {
        display: block;
        position: relative;
        padding-left: 35px;
        margin-bottom: 12px;
        cursor: pointer;
        user-select: none;
    }

    .checkbox-container input {
        position: absolute;
        opacity: 0;
        cursor: pointer;
        height: 0;
        width: 0;
    }

    .checkmark {
        position: absolute;
        top: 0;
        left: 0;
        height: 25px;
        width: 25px;
        background-color: #eee;
        border-radius: 4px;
    }

    .checkbox-container:hover input~.checkmark {
        background-color: #ccc;
    }

    .checkbox-container input:checked~.checkmark {
        background-color: #0066cc;
    }

    .checkmark:after {
        content: "";
        position: absolute;
        display: none;
    }

    .checkbox-container input:checked~.checkmark:after {
        display: block;
    }

    .checkbox-container .checkmark:after {
        left: 9px;
        top: 5px;
        width: 5px;
        height: 10px;
        border: solid white;
        border-width: 0 3px 3px 0;
        transform: rotate(45deg);
    }

    @media (max-width: 768px) {
        .room-selection {
            grid-template-columns: 1fr;
        }
    }
</style>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        const form = document.getElementById('groupBookingForm');
        const checkInDate = document.getElementById('check_in_date');
        const checkOutDate = document.getElementById('check_out_date');

        // 设置最小日期为今天
        const today = new Date().toISOString().split('T')[0];
        checkInDate.min = today;

        // 入住日期变化时更新退房日期最小值
        checkInDate.addEventListener('change', function() {
            checkOutDate.min = this.value;
            if (checkOutDate.value && checkOutDate.value < this.value) {
                checkOutDate.value = this.value;
            }
        });

        // 表单提交前验证
        form.addEventListener('submit', function(e) {
            const selectedRooms = document.querySelectorAll('input[type="checkbox"][name^="rooms"]:checked');
            if (selectedRooms.length === 0) {
                e.preventDefault();
                alert('请至少选择一个房间');
            }
        });
    });
</script>