<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 通知类型常量
define('NOTIFICATION_TYPE_BOOKING_CONFIRMATION', 'booking_confirmation');
define('NOTIFICATION_TYPE_CHECKIN_REMINDER', 'checkin_reminder');
define('NOTIFICATION_TYPE_CHECKOUT_REMINDER', 'checkout_reminder');
define('NOTIFICATION_TYPE_PAYMENT_REMINDER', 'payment_reminder');

/**
 * 发送通知
 * @param string $type 通知类型
 * @param array $booking 预订信息
 * @param array $params 额外参数
 * @return bool
 */
function sendNotification($type, $booking, $params = [])
{
    global $conn;

    try {
        // 获取通知模板
        $templateSql = "SELECT * FROM notification_templates WHERE type = ?";
        $stmt = $conn->prepare($templateSql);
        $stmt->bind_param("s", $type);
        $stmt->execute();
        $template = $stmt->get_result()->fetch_assoc();

        if (!$template) {
            throw new Exception('通知模板不存在');
        }

        // 替换模板变量
        $message = $template['content'];
        $message = str_replace('{booking_number}', $booking['booking_number'], $message);
        $message = str_replace('{guest_name}', $booking['guest_name'], $message);
        $message = str_replace('{check_in_date}', date('Y-m-d', strtotime($booking['check_in_date'])), $message);
        $message = str_replace('{check_out_date}', date('Y-m-d', strtotime($booking['check_out_date'])), $message);

        // 根据通知方式发送
        $methods = explode(',', $template['methods']);
        foreach ($methods as $method) {
            switch (trim($method)) {
                case 'sms':
                    sendSMS($booking['guest_phone'], $message);
                    break;

                case 'email':
                    if (!empty($booking['guest_email'])) {
                        sendEmail($booking['guest_email'], $template['subject'], $message);
                    }
                    break;

                case 'wechat':
                    if (!empty($booking['guest_wechat'])) {
                        sendWechatMessage($booking['guest_wechat'], $message);
                    }
                    break;
            }
        }

        // 记录通知历史
        $insertHistorySql = "INSERT INTO notification_history (
            booking_id, type, content, sent_at
        ) VALUES (?, ?, ?, NOW())";
        $stmt = $conn->prepare($insertHistorySql);
        $stmt->bind_param("iss", $booking['id'], $type, $message);
        $stmt->execute();

        return true;
    } catch (Exception $e) {
        error_log('发送通知失败: ' . $e->getMessage());
        return false;
    }
}

/**
 * 发送短信
 * @param string $phone 手机号
 * @param string $message 消息内容
 */
function sendSMS($phone, $message)
{
    // TODO: 实现短信发送逻辑
    // 这里需要集成具体的短信服务商API
}

/**
 * 发送邮件
 * @param string $email 邮箱
 * @param string $subject 主题
 * @param string $message 消息内容
 */
function sendEmail($email, $subject, $message)
{
    // TODO: 实现邮件发送逻辑
    // 这里需要配置SMTP服务器
}

/**
 * 发送微信消息
 * @param string $openid 微信openid
 * @param string $message 消息内容
 */
function sendWechatMessage($openid, $message)
{
    // TODO: 实现微信消息发送逻辑
    // 这里需要集成微信公众号或小程序API
}

/**
 * 处理预订确认通知
 * @param int $bookingId 预订ID
 */
function handleBookingConfirmation($bookingId)
{
    global $conn;

    $sql = "SELECT * FROM bookings WHERE id = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("i", $bookingId);
    $stmt->execute();
    $booking = $stmt->get_result()->fetch_assoc();

    if ($booking) {
        sendNotification(NOTIFICATION_TYPE_BOOKING_CONFIRMATION, $booking);
    }
}

/**
 * 处理入住提醒
 * 默认在入住前1天发送提醒
 */
function handleCheckinReminders()
{
    global $conn;

    $sql = "SELECT * FROM bookings 
            WHERE status = 'confirmed' 
            AND check_in_date = DATE_ADD(CURDATE(), INTERVAL 1 DAY)
            AND id NOT IN (
                SELECT booking_id FROM notification_history 
                WHERE type = ? AND DATE(sent_at) = CURDATE()
            )";

    $stmt = $conn->prepare($sql);
    $type = NOTIFICATION_TYPE_CHECKIN_REMINDER;
    $stmt->bind_param("s", $type);
    $stmt->execute();
    $result = $stmt->get_result();

    while ($booking = $result->fetch_assoc()) {
        sendNotification(NOTIFICATION_TYPE_CHECKIN_REMINDER, $booking);
    }
}

/**
 * 处理退房提醒
 * 默认在退房当天早上发送提醒
 */
function handleCheckoutReminders()
{
    global $conn;

    $sql = "SELECT * FROM bookings 
            WHERE status = 'checked_in' 
            AND check_out_date = CURDATE()
            AND id NOT IN (
                SELECT booking_id FROM notification_history 
                WHERE type = ? AND DATE(sent_at) = CURDATE()
            )";

    $stmt = $conn->prepare($sql);
    $type = NOTIFICATION_TYPE_CHECKOUT_REMINDER;
    $stmt->bind_param("s", $type);
    $stmt->execute();
    $result = $stmt->get_result();

    while ($booking = $result->fetch_assoc()) {
        sendNotification(NOTIFICATION_TYPE_CHECKOUT_REMINDER, $booking);
    }
}

/**
 * 处理付款提醒
 * 对于未付款的预订发送提醒
 */
function handlePaymentReminders()
{
    global $conn;

    $sql = "SELECT * FROM bookings 
            WHERE status = 'pending_payment' 
            AND created_at <= DATE_SUB(NOW(), INTERVAL 24 HOUR)
            AND id NOT IN (
                SELECT booking_id FROM notification_history 
                WHERE type = ? AND sent_at >= DATE_SUB(NOW(), INTERVAL 24 HOUR)
            )";

    $stmt = $conn->prepare($sql);
    $type = NOTIFICATION_TYPE_PAYMENT_REMINDER;
    $stmt->bind_param("s", $type);
    $stmt->execute();
    $result = $stmt->get_result();

    while ($booking = $result->fetch_assoc()) {
        sendNotification(NOTIFICATION_TYPE_PAYMENT_REMINDER, $booking);
    }
}

// 如果是通过命令行运行（用于定时任务），则执行提醒检查
if (php_sapi_name() === 'cli') {
    handleCheckinReminders();
    handleCheckoutReminders();
    handlePaymentReminders();
}

// 如果是通过Web访问，显示通知历史
if (php_sapi_name() !== 'cli') {
    // 获取通知历史
    $historySql = "SELECT nh.*, b.booking_number, b.guest_name 
                   FROM notification_history nh 
                   JOIN bookings b ON nh.booking_id = b.id 
                   ORDER BY nh.sent_at DESC 
                   LIMIT 100";
    $historyResult = $conn->query($historySql);
    $notifications = [];
    if ($historyResult && $historyResult->num_rows > 0) {
        while ($row = $historyResult->fetch_assoc()) {
            $notifications[] = $row;
        }
    }
?>

    <div class="content-wrapper">
        <div class="page-header">
            <h2>通知记录</h2>
            <nav class="breadcrumb">
                <a href="index.php">概览</a> /
                <span>通知记录</span>
            </nav>
        </div>

        <div class="notification-container">
            <div class="card">
                <div class="card-header">
                    <h3>最近通知</h3>
                </div>
                <div class="card-body">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>时间</th>
                                <th>预订号</th>
                                <th>客人</th>
                                <th>类型</th>
                                <th>内容</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($notifications as $notification): ?>
                                <tr>
                                    <td><?php echo date('Y-m-d H:i', strtotime($notification['sent_at'])); ?></td>
                                    <td>
                                        <a href="index.php?page=booking_view&id=<?php echo $notification['booking_id']; ?>">
                                            <?php echo htmlspecialchars($notification['booking_number']); ?>
                                        </a>
                                    </td>
                                    <td><?php echo htmlspecialchars($notification['guest_name']); ?></td>
                                    <td>
                                        <?php
                                        switch ($notification['type']) {
                                            case NOTIFICATION_TYPE_BOOKING_CONFIRMATION:
                                                echo '预订确认';
                                                break;
                                            case NOTIFICATION_TYPE_CHECKIN_REMINDER:
                                                echo '入住提醒';
                                                break;
                                            case NOTIFICATION_TYPE_CHECKOUT_REMINDER:
                                                echo '退房提醒';
                                                break;
                                            case NOTIFICATION_TYPE_PAYMENT_REMINDER:
                                                echo '付款提醒';
                                                break;
                                            default:
                                                echo htmlspecialchars($notification['type']);
                                        }
                                        ?>
                                    </td>
                                    <td><?php echo htmlspecialchars($notification['content']); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>

    <style>
        .notification-container {
            max-width: 1200px;
            margin: 0 auto;
            padding: 20px;
        }

        .data-table {
            width: 100%;
            border-collapse: collapse;
        }

        .data-table th,
        .data-table td {
            padding: 12px;
            text-align: left;
            border-bottom: 1px solid #eee;
        }

        .data-table th {
            background-color: #f8f9fa;
            font-weight: bold;
        }

        .data-table td {
            vertical-align: top;
        }

        .data-table tr:hover {
            background-color: #f8f9fa;
        }
    </style>
<?php
}
?>