<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

require_once '../../config/config.php';
require_once '../../includes/functions.php';

// 检查并创建积分兑换项目表（如果不存在）
$sql = "CREATE TABLE IF NOT EXISTS points_exchange_items (
    id INT AUTO_INCREMENT PRIMARY KEY,
    name VARCHAR(100) NOT NULL,
    description TEXT,
    type ENUM('room_discount', 'gift', 'service') NOT NULL,
    points_required INT NOT NULL,
    discount_value DECIMAL(10,2) DEFAULT NULL,
    inventory INT DEFAULT NULL,
    status ENUM('active', 'inactive') NOT NULL DEFAULT 'active',
    created_by INT,
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN KEY (created_by) REFERENCES users(id) ON DELETE SET NULL
)";
$conn->query($sql);

// 检查并创建积分兑换记录表（如果不存在）
$sql = "CREATE TABLE IF NOT EXISTS points_exchange_records (
    id INT AUTO_INCREMENT PRIMARY KEY,
    member_id INT NOT NULL,
    item_id INT NOT NULL,
    points_used INT NOT NULL,
    booking_id INT DEFAULT NULL,
    status ENUM('pending', 'completed', 'cancelled') NOT NULL DEFAULT 'pending',
    notes TEXT,
    created_by INT,
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN KEY (member_id) REFERENCES members(id),
    FOREIGN KEY (item_id) REFERENCES points_exchange_items(id),
    FOREIGN KEY (booking_id) REFERENCES bookings(id) ON DELETE SET NULL,
    FOREIGN KEY (created_by) REFERENCES users(id) ON DELETE SET NULL
)";
$conn->query($sql);

// 处理积分兑换项目的添加和编辑
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['save_item'])) {
    $id = isset($_POST['id']) ? $_POST['id'] : null;
    $name = $_POST['name'];
    $description = $_POST['description'];
    $type = $_POST['type'];
    $points_required = $_POST['points_required'];
    $discount_value = isset($_POST['discount_value']) ? $_POST['discount_value'] : null;
    $inventory = isset($_POST['inventory']) ? $_POST['inventory'] : null;
    $status = $_POST['status'];

    try {
        if ($id) {
            // 更新兑换项目
            $stmt = $conn->prepare("UPDATE points_exchange_items SET 
                name = ?, description = ?, type = ?, points_required = ?, 
                discount_value = ?, inventory = ?, status = ?
                WHERE id = ?");
            $stmt->bind_param(
                "sssiidsi",
                $name,
                $description,
                $type,
                $points_required,
                $discount_value,
                $inventory,
                $status,
                $id
            );
            $stmt->execute();
            $success_message = "积分兑换项目更新成功!";
        } else {
            // 添加新兑换项目
            $stmt = $conn->prepare("INSERT INTO points_exchange_items 
                (name, description, type, points_required, discount_value, inventory, status, created_by) 
                VALUES (?, ?, ?, ?, ?, ?, ?, ?)");
            $stmt->bind_param(
                "sssiidsi",
                $name,
                $description,
                $type,
                $points_required,
                $discount_value,
                $inventory,
                $status,
                $_SESSION['user_id']
            );
            $stmt->execute();
            $success_message = "积分兑换项目添加成功!";
        }
    } catch (Exception $e) {
        $error_message = "操作失败: " . $e->getMessage();
    }
}

// 处理积分兑换记录的处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['process_exchange'])) {
    $record_id = $_POST['record_id'];
    $status = $_POST['status'];
    $notes = $_POST['notes'];

    try {
        $conn->begin_transaction();

        // 更新分享状态
        $stmt = $conn->prepare("UPDATE points_exchange_records SET 
            status = ?, notes = ? WHERE id = ?");
        $stmt->bind_param("ssi", $status, $notes, $record_id);
        $stmt->execute();

        // 如果取消兑换，则需要退回积分
        if ($status === 'cancelled') {
            // 获取该记录信息
            $stmt = $conn->prepare("SELECT member_id, points_used FROM points_exchange_records WHERE id = ?");
            $stmt->bind_param("i", $record_id);
            $stmt->execute();
            $result = $stmt->get_result();
            $record = $result->fetch_assoc();

            if ($record) {
                // 更新会员积分
                $stmt = $conn->prepare("UPDATE members SET points = points + ? WHERE id = ?");
                $stmt->bind_param("ii", $record['points_used'], $record['member_id']);
                $stmt->execute();

                // 添加积分历史记录
                $stmt = $conn->prepare("INSERT INTO point_history 
                    (member_id, points_change, change_type, reason, created_by) 
                    VALUES (?, ?, 'add', '积分兑换取消退回', ?)");
                $stmt->bind_param("iii", $record['member_id'], $record['points_used'], $_SESSION['user_id']);
                $stmt->execute();
            }
        }

        $conn->commit();
        $success_message = "兑换记录处理成功!";
    } catch (Exception $e) {
        $conn->rollback();
        $error_message = "处理失败: " . $e->getMessage();
    }
}

// 处理删除积分兑换项目
if (isset($_GET['action']) && $_GET['action'] == 'delete' && isset($_GET['id'])) {
    $id = $_GET['id'];
    try {
        // 检查是否有关联的兑换记录
        $stmt = $conn->prepare("SELECT COUNT(*) as count FROM points_exchange_records WHERE item_id = ?");
        $stmt->bind_param("i", $id);
        $stmt->execute();
        $result = $stmt->get_result();
        $row = $result->fetch_assoc();
        $count = $row['count'];

        if ($count > 0) {
            $error_message = "该兑换项目已有兑换记录，无法删除!";
        } else {
            $stmt = $conn->prepare("DELETE FROM points_exchange_items WHERE id = ?");
            $stmt->bind_param("i", $id);
            $stmt->execute();
            $success_message = "积分兑换项目删除成功!";
        }
    } catch (Exception $e) {
        $error_message = "删除失败: " . $e->getMessage();
    }
}

// 获取编辑的项目数据
$editing = false;
$exchange_item = [
    'name' => '',
    'description' => '',
    'type' => 'room_discount',
    'points_required' => 1000,
    'discount_value' => '',
    'inventory' => '',
    'status' => 'active'
];

if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $id = $_GET['id'];
    $stmt = $conn->prepare("SELECT * FROM points_exchange_items WHERE id = ?");
    $stmt->bind_param("i", $id);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        $editing = true;
        $exchange_item = $result->fetch_assoc();
    }
}

// 获取兑换项目列表
$result = $conn->query("SELECT * FROM points_exchange_items ORDER BY created_at DESC");
$exchange_items = [];
while ($row = $result->fetch_assoc()) {
    $exchange_items[] = $row;
}

// 获取最近的兑换记录列表
$stmt = $conn->prepare("SELECT 
                        per.*, 
                        pei.name as item_name, 
                        pei.type as item_type,
                        m.name as member_name, 
                        m.phone as member_phone
                      FROM points_exchange_records per
                      JOIN points_exchange_items pei ON per.item_id = pei.id
                      JOIN members m ON per.member_id = m.id
                      ORDER BY per.created_at DESC
                      LIMIT 50");
$stmt->execute();
$result = $stmt->get_result();
$exchange_records = [];
while ($row = $result->fetch_assoc()) {
    $exchange_records[] = $row;
}
?>

<div class="content">
    <?php if (isset($success_message)): ?>
        <div class="alert alert-success"><?php echo $success_message; ?></div>
    <?php endif; ?>
    <?php if (isset($error_message)): ?>
        <div class="alert alert-danger"><?php echo $error_message; ?></div>
    <?php endif; ?>

    <!-- 添加/编辑积分兑换项目表单 -->
    <div class="card mb-4">
        <div class="card-header">
            <h3><?php echo $editing ? '编辑积分兑换项目' : '添加积分兑换项目'; ?></h3>
        </div>
        <div class="card-body">
            <form method="post" id="exchangeItemForm">
                <?php if ($editing): ?>
                    <input type="hidden" name="id" value="<?php echo $exchange_item['id']; ?>">
                <?php endif; ?>

                <div class="form-row">
                    <div class="form-group col-md-6">
                        <label for="name">项目名称</label>
                        <input type="text" class="form-control" id="name" name="name" required
                            value="<?php echo htmlspecialchars($exchange_item['name']); ?>">
                    </div>
                    <div class="form-group col-md-6">
                        <label for="type">项目类型</label>
                        <select class="form-control" id="type" name="type" required>
                            <option value="room_discount" <?php echo $exchange_item['type'] == 'room_discount' ? 'selected' : ''; ?>>房费折扣</option>
                            <option value="gift" <?php echo $exchange_item['type'] == 'gift' ? 'selected' : ''; ?>>实物礼品</option>
                            <option value="service" <?php echo $exchange_item['type'] == 'service' ? 'selected' : ''; ?>>增值服务</option>
                        </select>
                    </div>
                </div>

                <div class="form-group">
                    <label for="description">项目描述</label>
                    <textarea class="form-control" id="description" name="description" rows="3"><?php echo htmlspecialchars($exchange_item['description']); ?></textarea>
                </div>

                <div class="form-row">
                    <div class="form-group col-md-4">
                        <label for="points_required">所需积分</label>
                        <input type="number" class="form-control" id="points_required" name="points_required" required
                            value="<?php echo $exchange_item['points_required']; ?>">
                    </div>
                    <div class="form-group col-md-4" id="discount_field">
                        <label for="discount_value">折扣金额/价值</label>
                        <input type="number" class="form-control" id="discount_value" name="discount_value" step="0.01"
                            value="<?php echo $exchange_item['discount_value']; ?>">
                    </div>
                    <div class="form-group col-md-4" id="inventory_field">
                        <label for="inventory">库存数量</label>
                        <input type="number" class="form-control" id="inventory" name="inventory"
                            value="<?php echo $exchange_item['inventory']; ?>">
                        <small class="form-text text-muted">0或空表示不限</small>
                    </div>
                </div>

                <div class="form-group">
                    <label for="status">状态</label>
                    <select class="form-control" id="status" name="status" required>
                        <option value="active" <?php echo $exchange_item['status'] == 'active' ? 'selected' : ''; ?>>启用</option>
                        <option value="inactive" <?php echo $exchange_item['status'] == 'inactive' ? 'selected' : ''; ?>>停用</option>
                    </select>
                </div>

                <button type="submit" name="save_item" class="btn btn-primary"><?php echo $editing ? '更新项目' : '添加项目'; ?></button>
                <?php if ($editing): ?>
                    <a href="index.php?page=points_exchange" class="btn btn-secondary">取消编辑</a>
                <?php endif; ?>
            </form>
        </div>
    </div>

    <!-- 积分兑换项目列表 -->
    <div class="card mb-4">
        <div class="card-header">
            <h3>积分兑换项目列表</h3>
        </div>
        <div class="card-body">
            <div class="table-responsive">
                <table class="table">
                    <thead>
                        <tr>
                            <th>项目名称</th>
                            <th>类型</th>
                            <th>描述</th>
                            <th>所需积分</th>
                            <th>折扣/价值</th>
                            <th>库存</th>
                            <th>状态</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($exchange_items as $item): ?>
                            <tr>
                                <td><?php echo htmlspecialchars($item['name']); ?></td>
                                <td><?php echo getItemTypeName($item['type']); ?></td>
                                <td><?php echo mb_substr(htmlspecialchars($item['description']), 0, 30) . (mb_strlen($item['description']) > 30 ? '...' : ''); ?></td>
                                <td><?php echo number_format($item['points_required']); ?> 积分</td>
                                <td><?php echo $item['discount_value'] ? '¥' . number_format($item['discount_value'], 2) : '-'; ?></td>
                                <td>
                                    <?php
                                    if ($item['type'] == 'gift' || $item['type'] == 'service') {
                                        echo $item['inventory'] ? $item['inventory'] : '不限';
                                    } else {
                                        echo '-';
                                    }
                                    ?>
                                </td>
                                <td>
                                    <span class="status-badge <?php echo $item['status']; ?>">
                                        <?php echo $item['status'] == 'active' ? '启用' : '停用'; ?>
                                    </span>
                                </td>
                                <td>
                                    <a href="index.php?page=points_exchange&action=edit&id=<?php echo $item['id']; ?>"
                                        class="btn btn-sm btn-primary">编辑</a>
                                    <a href="index.php?page=points_exchange&action=delete&id=<?php echo $item['id']; ?>"
                                        class="btn btn-sm btn-danger"
                                        onclick="return confirm('确定要删除此兑换项目吗？')">删除</a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                        <?php if (empty($exchange_items)): ?>
                            <tr>
                                <td colspan="8" class="text-center">暂无积分兑换项目</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    <!-- 积分兑换记录列表 -->
    <div class="card">
        <div class="card-header">
            <h3>最近积分兑换记录</h3>
        </div>
        <div class="card-body">
            <div class="table-responsive">
                <table class="table">
                    <thead>
                        <tr>
                            <th>会员</th>
                            <th>兑换项目</th>
                            <th>消耗积分</th>
                            <th>状态</th>
                            <th>兑换时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($exchange_records as $record): ?>
                            <tr>
                                <td>
                                    <?php echo htmlspecialchars($record['member_name']); ?><br>
                                    <small class="text-muted"><?php echo $record['member_phone']; ?></small>
                                </td>
                                <td>
                                    <?php echo htmlspecialchars($record['item_name']); ?><br>
                                    <small class="text-muted"><?php echo getItemTypeName($record['item_type']); ?></small>
                                </td>
                                <td><?php echo number_format($record['points_used']); ?> 积分</td>
                                <td>
                                    <span class="status-badge <?php echo $record['status']; ?>">
                                        <?php echo getExchangeStatusName($record['status']); ?>
                                    </span>
                                </td>
                                <td><?php echo date('Y-m-d H:i', strtotime($record['created_at'])); ?></td>
                                <td>
                                    <?php if ($record['status'] == 'pending'): ?>
                                        <button class="btn btn-sm btn-primary"
                                            onclick="showProcessDialog(<?php echo $record['id']; ?>, '<?php echo htmlspecialchars($record['member_name']); ?>', '<?php echo htmlspecialchars($record['item_name']); ?>')">
                                            处理
                                        </button>
                                    <?php else: ?>
                                        <button class="btn btn-sm btn-secondary"
                                            onclick="showRecordDetails(<?php echo htmlspecialchars(json_encode($record)); ?>)">
                                            详情
                                        </button>
                                    <?php endif; ?>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                        <?php if (empty($exchange_records)): ?>
                            <tr>
                                <td colspan="6" class="text-center">暂无兑换记录</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</div>

<!-- 处理兑换记录对话框 -->
<div class="modal fade" id="processExchangeModal" tabindex="-1" role="dialog" aria-labelledby="processExchangeModalLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="processExchangeModalLabel">处理积分兑换</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <form method="post">
                <div class="modal-body">
                    <input type="hidden" name="record_id" id="record_id">
                    <p id="exchange_info"></p>

                    <div class="form-group">
                        <label for="status">处理结果</label>
                        <select class="form-control" name="status" id="process_status" required>
                            <option value="completed">完成兑换</option>
                            <option value="cancelled">取消兑换</option>
                        </select>
                    </div>

                    <div class="form-group">
                        <label for="notes">处理备注</label>
                        <textarea class="form-control" name="notes" id="notes" rows="3"></textarea>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-dismiss="modal">关闭</button>
                    <button type="submit" name="process_exchange" class="btn btn-primary">确认处理</button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- 查看记录详情对话框 -->
<div class="modal fade" id="recordDetailsModal" tabindex="-1" role="dialog" aria-labelledby="recordDetailsModalLabel" aria-hidden="true">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="recordDetailsModalLabel">兑换记录详情</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body">
                <div class="record-details-content"></div>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-dismiss="modal">关闭</button>
            </div>
        </div>
    </div>
</div>

<script>
    $(document).ready(function() {
        // 确保jQuery和Bootstrap已加载
        if (typeof jQuery !== 'undefined' && typeof jQuery.fn.modal !== 'undefined') {
            console.log('jQuery和Bootstrap已正确加载');
            // 初始化并隐藏模态框
            $('#processExchangeModal').modal('hide');
            $('#recordDetailsModal').modal('hide');
        } else {
            console.error('jQuery或Bootstrap未正确加载，模态框可能无法正常工作');
        }

        // 根据项目类型显示/隐藏相关字段
        $('#type').change(function() {
            var type = $(this).val();
            if (type === 'room_discount') {
                $('#discount_field').show();
                $('#inventory_field').hide();
            } else if (type === 'gift' || type === 'service') {
                $('#discount_field').show(); // 显示礼品价值
                $('#inventory_field').show();
            }
        });

        // 初始化页面时触发一次
        $('#type').trigger('change');
    });

    // 显示处理对话框
    function showProcessDialog(recordId, memberName, itemName) {
        console.log('正在尝试显示处理对话框，记录ID: ' + recordId);
        $('#record_id').val(recordId);
        $('#exchange_info').html('处理会员 <strong>' + memberName + '</strong> 兑换的 <strong>' + itemName + '</strong>');

        if (typeof jQuery !== 'undefined' && typeof jQuery.fn.modal !== 'undefined') {
            $('#processExchangeModal').modal('show');
        } else {
            alert('无法显示模态框：jQuery或Bootstrap未正确加载');
        }
    }

    // 显示记录详情
    function showRecordDetails(record) {
        console.log('正在尝试显示记录详情，记录: ', record);
        var html = '<table class="table table-bordered">';
        html += '<tr><th>会员姓名</th><td>' + record.member_name + '</td></tr>';
        html += '<tr><th>会员电话</th><td>' + record.member_phone + '</td></tr>';
        html += '<tr><th>兑换项目</th><td>' + record.item_name + '</td></tr>';
        html += '<tr><th>项目类型</th><td>' + getItemTypeName(record.item_type) + '</td></tr>';
        html += '<tr><th>消耗积分</th><td>' + record.points_used + '</td></tr>';
        html += '<tr><th>状态</th><td>' + getExchangeStatusName(record.status) + '</td></tr>';
        html += '<tr><th>兑换时间</th><td>' + record.created_at + '</td></tr>';
        html += '<tr><th>处理备注</th><td>' + (record.notes || '-') + '</td></tr>';
        html += '</table>';

        $('.record-details-content').html(html);

        if (typeof jQuery !== 'undefined' && typeof jQuery.fn.modal !== 'undefined') {
            $('#recordDetailsModal').modal('show');
        } else {
            alert('无法显示模态框：jQuery或Bootstrap未正确加载');
        }
    }

    // 辅助函数
    function getItemTypeName(type) {
        switch (type) {
            case 'room_discount':
                return '房费折扣';
            case 'gift':
                return '实物礼品';
            case 'service':
                return '增值服务';
            default:
                return type;
        }
    }

    function getExchangeStatusName(status) {
        switch (status) {
            case 'pending':
                return '待处理';
            case 'completed':
                return '已完成';
            case 'cancelled':
                return '已取消';
            default:
                return status;
        }
    }
</script>

<style>
    .status-badge {
        display: inline-block;
        padding: 4px 8px;
        border-radius: 4px;
        font-size: 0.9em;
    }

    .status-badge.active {
        background: #e3f2fd;
        color: #1976d2;
    }

    .status-badge.inactive {
        background: #ffebee;
        color: #c62828;
    }

    .status-badge.pending {
        background: #fff8e1;
        color: #f57f17;
    }

    .status-badge.completed {
        background: #e8f5e9;
        color: #2e7d32;
    }

    .status-badge.cancelled {
        background: #ffebee;
        color: #c62828;
    }
</style>

<?php
function getItemTypeName($type)
{
    $types = [
        'room_discount' => '房费折扣',
        'gift' => '实物礼品',
        'service' => '增值服务'
    ];
    return isset($types[$type]) ? $types[$type] : $type;
}

function getExchangeStatusName($status)
{
    $statuses = [
        'pending' => '待处理',
        'completed' => '已完成',
        'cancelled' => '已取消'
    ];
    return isset($statuses[$status]) ? $statuses[$status] : $status;
}
?>