<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

require_once '../../config/config.php';
require_once '../../includes/functions.php';

// 检查并创建社交媒体分享表（如果不存在）
$sql = "CREATE TABLE IF NOT EXISTS social_media_shares (
    id INT AUTO_INCREMENT PRIMARY KEY,
    member_id INT,
    booking_id INT,
    share_platform ENUM('wechat', 'weibo', 'douyin', 'other') NOT NULL,
    share_content TEXT,
    share_image VARCHAR(255),
    share_status ENUM('pending', 'approved', 'rejected') NOT NULL DEFAULT 'pending',
    share_date DATETIME,
    reward_points INT DEFAULT 0,
    reward_status ENUM('pending', 'given', 'cancelled') NOT NULL DEFAULT 'pending',
    notes TEXT,
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN KEY (member_id) REFERENCES members(id) ON DELETE SET NULL,
    FOREIGN KEY (booking_id) REFERENCES bookings(id) ON DELETE SET NULL
)";
$conn->query($sql);

// 检查并创建分享奖励规则表（如果不存在）
$sql = "CREATE TABLE IF NOT EXISTS social_media_rewards (
    id INT AUTO_INCREMENT PRIMARY KEY,
    platform ENUM('wechat', 'weibo', 'douyin', 'other') NOT NULL,
    points INT NOT NULL DEFAULT 0,
    min_followers INT DEFAULT NULL,
    status ENUM('active', 'inactive') NOT NULL DEFAULT 'active',
    created_by INT,
    created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    FOREIGN KEY (created_by) REFERENCES users(id) ON DELETE SET NULL
)";
$conn->query($sql);

// 处理分享奖励设置
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['save_reward'])) {
    $platform = $_POST['platform'];
    $points = $_POST['points'];
    $min_followers = $_POST['min_followers'] ? $_POST['min_followers'] : null;
    $status = $_POST['status'];
    $id = isset($_POST['id']) ? $_POST['id'] : null;

    try {
        if ($id) {
            // 更新奖励规则
            $stmt = $conn->prepare("UPDATE social_media_rewards SET 
                platform = ?, points = ?, min_followers = ?, status = ?
                WHERE id = ?");
            $stmt->bind_param("siisi", $platform, $points, $min_followers, $status, $id);
            $stmt->execute();
            $success_message = "分享奖励规则更新成功!";
        } else {
            // 检查是否已存在相同平台的规则
            $stmt = $conn->prepare("SELECT id FROM social_media_rewards WHERE platform = ?");
            $stmt->bind_param("s", $platform);
            $stmt->execute();
            $result = $stmt->get_result();

            if ($result->num_rows > 0) {
                $error_message = "该平台已存在奖励规则，请使用编辑功能!";
            } else {
                // 添加新奖励规则
                $stmt = $conn->prepare("INSERT INTO social_media_rewards 
                    (platform, points, min_followers, status, created_by) 
                    VALUES (?, ?, ?, ?, ?)");
                $stmt->bind_param("siisi", $platform, $points, $min_followers, $status, $_SESSION['user_id']);
                $stmt->execute();
                $success_message = "分享奖励规则添加成功!";
            }
        }
    } catch (Exception $e) {
        $error_message = "操作失败: " . $e->getMessage();
    }
}

// 处理分享审核
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['review_share'])) {
    $share_id = $_POST['share_id'];
    $share_status = $_POST['share_status'];
    $reward_status = $_POST['reward_status'];
    $notes = $_POST['notes'];

    try {
        $conn->begin_transaction();

        // 更新分享状态
        $stmt = $conn->prepare("UPDATE social_media_shares SET 
            share_status = ?, reward_status = ?, notes = ?
            WHERE id = ?");
        $stmt->bind_param("sssi", $share_status, $reward_status, $notes, $share_id);
        $stmt->execute();

        // 如果奖励状态为已发放，则给会员添加积分
        if ($reward_status == 'given') {
            // 获取分享记录信息
            $stmt = $conn->prepare("SELECT member_id, reward_points FROM social_media_shares WHERE id = ?");
            $stmt->bind_param("i", $share_id);
            $stmt->execute();
            $result = $stmt->get_result();
            $share = $result->fetch_assoc();

            if ($share && $share['member_id'] && $share['reward_points'] > 0) {
                // 更新会员积分
                $stmt = $conn->prepare("UPDATE members SET points = points + ? WHERE id = ?");
                $stmt->bind_param("ii", $share['reward_points'], $share['member_id']);
                $stmt->execute();

                // 添加积分历史记录
                $stmt = $conn->prepare("INSERT INTO point_history 
                    (member_id, points_change, change_type, reason, created_by) 
                    VALUES (?, ?, 'add', '社交媒体分享奖励', ?)");
                $stmt->bind_param("iii", $share['member_id'], $share['reward_points'], $_SESSION['user_id']);
                $stmt->execute();
            }
        }

        $conn->commit();
        $success_message = "分享审核处理成功!";
    } catch (Exception $e) {
        $conn->rollback();
        $error_message = "处理失败: " . $e->getMessage();
    }
}

// 处理删除奖励规则
if (isset($_GET['action']) && $_GET['action'] == 'delete_reward' && isset($_GET['id'])) {
    $id = $_GET['id'];
    try {
        $stmt = $conn->prepare("DELETE FROM social_media_rewards WHERE id = ?");
        $stmt->bind_param("i", $id);
        $stmt->execute();
        $success_message = "分享奖励规则删除成功!";
    } catch (Exception $e) {
        $error_message = "删除失败: " . $e->getMessage();
    }
}

// 获取编辑的奖励规则数据
$editing = false;
$reward = [
    'platform' => 'wechat',
    'points' => 100,
    'min_followers' => '',
    'status' => 'active'
];

if (isset($_GET['action']) && $_GET['action'] == 'edit_reward' && isset($_GET['id'])) {
    $id = $_GET['id'];
    $stmt = $conn->prepare("SELECT * FROM social_media_rewards WHERE id = ?");
    $stmt->bind_param("i", $id);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        $editing = true;
        $reward = $result->fetch_assoc();
    }
}

// 获取奖励规则列表
$result = $conn->query("SELECT * FROM social_media_rewards ORDER BY platform ASC");
$rewards = [];
while ($row = $result->fetch_assoc()) {
    $rewards[] = $row;
}

// 获取社交媒体分享记录
$stmt = $conn->prepare("SELECT 
                        sms.*,
                        m.name as member_name,
                        m.phone as member_phone,
                        b.booking_number
                      FROM social_media_shares sms
                      LEFT JOIN members m ON sms.member_id = m.id
                      LEFT JOIN bookings b ON sms.booking_id = b.id
                      ORDER BY sms.created_at DESC
                      LIMIT 50");
$stmt->execute();
$result = $stmt->get_result();
$shares = [];
while ($row = $result->fetch_assoc()) {
    $shares[] = $row;
}
?>

<div class="content">
    <?php if (isset($success_message)): ?>
        <div class="alert alert-success"><?php echo $success_message; ?></div>
    <?php endif; ?>
    <?php if (isset($error_message)): ?>
        <div class="alert alert-danger"><?php echo $error_message; ?></div>
    <?php endif; ?>

    <!-- 分享奖励设置表单 -->
    <div class="card mb-4">
        <div class="card-header">
            <h3><?php echo $editing ? '编辑分享奖励规则' : '添加分享奖励规则'; ?></h3>
        </div>
        <div class="card-body">
            <form method="post" id="rewardForm">
                <?php if ($editing): ?>
                    <input type="hidden" name="id" value="<?php echo $reward['id']; ?>">
                <?php endif; ?>

                <div class="form-row">
                    <div class="form-group col-md-4">
                        <label for="platform">社交平台</label>
                        <select class="form-control" id="platform" name="platform" required <?php echo $editing ? 'disabled' : ''; ?>>
                            <option value="wechat" <?php echo $reward['platform'] == 'wechat' ? 'selected' : ''; ?>>微信朋友圈</option>
                            <option value="weibo" <?php echo $reward['platform'] == 'weibo' ? 'selected' : ''; ?>>微博</option>
                            <option value="douyin" <?php echo $reward['platform'] == 'douyin' ? 'selected' : ''; ?>>抖音</option>
                            <option value="other" <?php echo $reward['platform'] == 'other' ? 'selected' : ''; ?>>其他平台</option>
                        </select>
                        <?php if ($editing): ?>
                            <input type="hidden" name="platform" value="<?php echo $reward['platform']; ?>">
                        <?php endif; ?>
                    </div>
                    <div class="form-group col-md-4">
                        <label for="points">奖励积分</label>
                        <input type="number" class="form-control" id="points" name="points" required min="0"
                            value="<?php echo $reward['points']; ?>">
                    </div>
                    <div class="form-group col-md-4">
                        <label for="min_followers">最低粉丝要求</label>
                        <input type="number" class="form-control" id="min_followers" name="min_followers" min="0"
                            value="<?php echo $reward['min_followers']; ?>">
                        <small class="form-text text-muted">可选，留空表示不限制</small>
                    </div>
                </div>

                <div class="form-group">
                    <label for="status">状态</label>
                    <select class="form-control" id="status" name="status" required>
                        <option value="active" <?php echo $reward['status'] == 'active' ? 'selected' : ''; ?>>启用</option>
                        <option value="inactive" <?php echo $reward['status'] == 'inactive' ? 'selected' : ''; ?>>停用</option>
                    </select>
                </div>

                <button type="submit" name="save_reward" class="btn btn-primary"><?php echo $editing ? '更新规则' : '添加规则'; ?></button>
                <?php if ($editing): ?>
                    <a href="index.php?page=social_media" class="btn btn-secondary">取消编辑</a>
                <?php endif; ?>
            </form>
        </div>
    </div>

    <!-- 分享奖励规则列表 -->
    <div class="card mb-4">
        <div class="card-header">
            <h3>分享奖励规则列表</h3>
        </div>
        <div class="card-body">
            <div class="table-responsive">
                <table class="table">
                    <thead>
                        <tr>
                            <th>社交平台</th>
                            <th>奖励积分</th>
                            <th>最低粉丝要求</th>
                            <th>状态</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($rewards as $r): ?>
                            <tr>
                                <td><?php echo getPlatformName($r['platform']); ?></td>
                                <td><?php echo number_format($r['points']); ?> 积分</td>
                                <td><?php echo $r['min_followers'] ? number_format($r['min_followers']) . ' 粉丝' : '不限'; ?></td>
                                <td>
                                    <span class="status-badge <?php echo $r['status']; ?>">
                                        <?php echo $r['status'] == 'active' ? '启用' : '停用'; ?>
                                    </span>
                                </td>
                                <td>
                                    <a href="index.php?page=social_media&action=edit_reward&id=<?php echo $r['id']; ?>"
                                        class="btn btn-sm btn-primary">编辑</a>
                                    <a href="index.php?page=social_media&action=delete_reward&id=<?php echo $r['id']; ?>"
                                        class="btn btn-sm btn-danger"
                                        onclick="return confirm('确定要删除此奖励规则吗？')">删除</a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                        <?php if (empty($rewards)): ?>
                            <tr>
                                <td colspan="5" class="text-center">暂无分享奖励规则</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    <!-- 社交媒体分享记录 -->
    <div class="card">
        <div class="card-header">
            <h3>社交媒体分享记录</h3>
        </div>
        <div class="card-body">
            <div class="table-responsive">
                <table class="table">
                    <thead>
                        <tr>
                            <th>会员信息</th>
                            <th>订单号</th>
                            <th>分享平台</th>
                            <th>分享内容</th>
                            <th>分享时间</th>
                            <th>审核状态</th>
                            <th>奖励积分</th>
                            <th>奖励状态</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($shares as $share): ?>
                            <tr>
                                <td>
                                    <?php echo htmlspecialchars($share['member_name'] ?? '未知'); ?><br>
                                    <small class="text-muted"><?php echo $share['member_phone'] ?? ''; ?></small>
                                </td>
                                <td><?php echo $share['booking_number'] ?? '-'; ?></td>
                                <td><?php echo getPlatformName($share['share_platform']); ?></td>
                                <td><?php echo mb_substr(htmlspecialchars($share['share_content']), 0, 30) . (mb_strlen($share['share_content']) > 30 ? '...' : ''); ?></td>
                                <td><?php echo date('Y-m-d H:i', strtotime($share['share_date'] ?? $share['created_at'])); ?></td>
                                <td>
                                    <span class="status-badge <?php echo $share['share_status']; ?>">
                                        <?php echo getShareStatusName($share['share_status']); ?>
                                    </span>
                                </td>
                                <td><?php echo number_format($share['reward_points']); ?> 积分</td>
                                <td>
                                    <span class="status-badge <?php echo $share['reward_status']; ?>">
                                        <?php echo getRewardStatusName($share['reward_status']); ?>
                                    </span>
                                </td>
                                <td>
                                    <?php if ($share['share_status'] == 'pending'): ?>
                                        <button class="btn btn-sm btn-primary"
                                            onclick="showReviewDialog(<?php echo htmlspecialchars(json_encode($share)); ?>)">
                                            审核
                                        </button>
                                    <?php else: ?>
                                        <button class="btn btn-sm btn-secondary"
                                            onclick="showShareDetails(<?php echo htmlspecialchars(json_encode($share)); ?>)">
                                            详情
                                        </button>
                                    <?php endif; ?>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                        <?php if (empty($shares)): ?>
                            <tr>
                                <td colspan="9" class="text-center">暂无社交媒体分享记录</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</div>

<!-- 审核分享对话框 -->
<div class="modal fade" id="reviewShareModal" tabindex="-1" role="dialog" aria-labelledby="reviewShareModalLabel" aria-hidden="true">
    <div class="modal-dialog modal-lg" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="reviewShareModalLabel">审核社交媒体分享</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <form method="post">
                <div class="modal-body">
                    <input type="hidden" name="share_id" id="share_id">

                    <div class="form-row">
                        <div class="form-group col-md-6">
                            <label>会员信息</label>
                            <p id="member_info" class="form-control-static"></p>
                        </div>
                        <div class="form-group col-md-6">
                            <label>分享平台</label>
                            <p id="platform_info" class="form-control-static"></p>
                        </div>
                    </div>

                    <div class="form-group">
                        <label>分享内容</label>
                        <div id="share_content" class="p-2 border rounded"></div>
                    </div>

                    <div class="form-group" id="share_image_container" style="display:none;">
                        <label>分享图片</label>
                        <div class="text-center">
                            <img id="share_image" src="" alt="分享图片" class="img-fluid img-thumbnail" style="max-height: 300px;">
                        </div>
                    </div>

                    <div class="form-row">
                        <div class="form-group col-md-6">
                            <label for="share_status">审核结果</label>
                            <select class="form-control" name="share_status" id="share_status" required>
                                <option value="approved">通过</option>
                                <option value="rejected">拒绝</option>
                            </select>
                        </div>

                        <div class="form-group col-md-6">
                            <label for="reward_status">奖励状态</label>
                            <select class="form-control" name="reward_status" id="reward_status" required>
                                <option value="pending">待处理</option>
                                <option value="given">已发放</option>
                                <option value="cancelled">不予奖励</option>
                            </select>
                        </div>
                    </div>

                    <div class="form-group">
                        <label for="notes">审核备注</label>
                        <textarea class="form-control" name="notes" id="notes" rows="3"></textarea>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-dismiss="modal">关闭</button>
                    <button type="submit" name="review_share" class="btn btn-primary">确认审核</button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- 查看分享详情对话框 -->
<div class="modal fade" id="shareDetailsModal" tabindex="-1" role="dialog" aria-labelledby="shareDetailsModalLabel" aria-hidden="true">
    <div class="modal-dialog modal-lg" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="shareDetailsModalLabel">分享详情</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body">
                <div class="share-details-content"></div>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-dismiss="modal">关闭</button>
            </div>
        </div>
    </div>
</div>

<script>
    // 显示审核对话框
    function showReviewDialog(share) {
        $('#share_id').val(share.id);
        $('#member_info').text(share.member_name + (share.member_phone ? ' (' + share.member_phone + ')' : ''));
        $('#platform_info').text(getPlatformName(share.share_platform));
        $('#share_content').text(share.share_content);

        // 显示图片（如果有）
        if (share.share_image) {
            $('#share_image').attr('src', '../../uploads/shares/' + share.share_image);
            $('#share_image_container').show();
        } else {
            $('#share_image_container').hide();
        }

        // 设置审核默认值
        $('#share_status').val('approved');
        $('#reward_status').val('given');

        $('#reviewShareModal').modal('show');
    }

    // 显示分享详情
    function showShareDetails(share) {
        var html = '<table class="table table-bordered">';
        html += '<tr><th width="20%">会员姓名</th><td>' + (share.member_name || '未知') + '</td></tr>';
        html += '<tr><th>会员电话</th><td>' + (share.member_phone || '-') + '</td></tr>';
        html += '<tr><th>订单号</th><td>' + (share.booking_number || '-') + '</td></tr>';
        html += '<tr><th>分享平台</th><td>' + getPlatformName(share.share_platform) + '</td></tr>';
        html += '<tr><th>分享内容</th><td>' + share.share_content + '</td></tr>';

        if (share.share_image) {
            html += '<tr><th>分享图片</th><td class="text-center"><img src="../../uploads/shares/' + share.share_image + '" alt="分享图片" class="img-fluid img-thumbnail" style="max-height: 300px;"></td></tr>';
        }

        html += '<tr><th>分享时间</th><td>' + (share.share_date || share.created_at) + '</td></tr>';
        html += '<tr><th>审核状态</th><td>' + getShareStatusName(share.share_status) + '</td></tr>';
        html += '<tr><th>奖励积分</th><td>' + share.reward_points + ' 积分</td></tr>';
        html += '<tr><th>奖励状态</th><td>' + getRewardStatusName(share.reward_status) + '</td></tr>';
        html += '<tr><th>审核备注</th><td>' + (share.notes || '-') + '</td></tr>';
        html += '</table>';

        $('.share-details-content').html(html);
        $('#shareDetailsModal').modal('show');
    }

    // 辅助函数
    function getPlatformName(platform) {
        switch (platform) {
            case 'wechat':
                return '微信朋友圈';
            case 'weibo':
                return '微博';
            case 'douyin':
                return '抖音';
            case 'other':
                return '其他平台';
            default:
                return platform;
        }
    }

    function getShareStatusName(status) {
        switch (status) {
            case 'pending':
                return '待审核';
            case 'approved':
                return '已通过';
            case 'rejected':
                return '已拒绝';
            default:
                return status;
        }
    }

    function getRewardStatusName(status) {
        switch (status) {
            case 'pending':
                return '待处理';
            case 'given':
                return '已发放';
            case 'cancelled':
                return '不予奖励';
            default:
                return status;
        }
    }
</script>

<style>
    .status-badge {
        display: inline-block;
        padding: 4px 8px;
        border-radius: 4px;
        font-size: 0.9em;
    }

    .status-badge.active {
        background: #e3f2fd;
        color: #1976d2;
    }

    .status-badge.inactive {
        background: #ffebee;
        color: #c62828;
    }

    .status-badge.pending {
        background: #fff8e1;
        color: #f57f17;
    }

    .status-badge.approved {
        background: #e8f5e9;
        color: #2e7d32;
    }

    .status-badge.rejected,
    .status-badge.cancelled {
        background: #ffebee;
        color: #c62828;
    }

    .status-badge.given {
        background: #e8f5e9;
        color: #2e7d32;
    }
</style>

<?php
function getPlatformName($platform)
{
    $platforms = [
        'wechat' => '微信朋友圈',
        'weibo' => '微博',
        'douyin' => '抖音',
        'other' => '其他平台'
    ];
    return isset($platforms[$platform]) ? $platforms[$platform] : $platform;
}

function getShareStatusName($status)
{
    $statuses = [
        'pending' => '待审核',
        'approved' => '已通过',
        'rejected' => '已拒绝'
    ];
    return isset($statuses[$status]) ? $statuses[$status] : $status;
}

function getRewardStatusName($status)
{
    $statuses = [
        'pending' => '待处理',
        'given' => '已发放',
        'cancelled' => '不予奖励'
    ];
    return isset($statuses[$status]) ? $statuses[$status] : $status;
}
?>