<?php
require_once '../../config/config.php';
require_once '../../includes/functions.php';

// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

$memberId = isset($_GET['id']) ? (int)$_GET['id'] : 0;
$isAdd = $page === 'member_add' || $memberId === 0;
$pageTitle = $isAdd ? '添加会员' : '编辑会员';
$member = null;
$errors = [];
$success = false;

// 如果是编辑现有会员
if ($memberId > 0) {
    $sql = "SELECT * FROM members WHERE id = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param('i', $memberId);
    $stmt->execute();
    $result = $stmt->get_result();
    $member = $result->fetch_assoc();

    if (!$member) {
        echo '<div class="alert alert-danger">会员不存在</div>';
        exit;
    }
}

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $name = sanitize($_POST['name']);
    $phone = sanitize($_POST['phone']);
    $email = sanitize($_POST['email']);
    $idType = sanitize($_POST['id_type']);
    $idNumber = sanitize($_POST['id_number']);
    $gender = sanitize($_POST['gender']);
    $birthday = sanitize($_POST['birthday']);
    $address = sanitize($_POST['address']);
    $level = sanitize($_POST['level']);
    $status = sanitize($_POST['status']);
    $notes = sanitize($_POST['notes']);

    // 验证数据
    if (empty($name)) {
        $errors[] = '姓名不能为空';
    }

    if (empty($phone)) {
        $errors[] = '手机号不能为空';
    } elseif (!preg_match('/^1[3-9]\d{9}$/', $phone)) {
        $errors[] = '手机号格式不正确';
    } else {
        // 检查手机号是否已存在（排除当前会员）
        $sql = "SELECT id FROM members WHERE phone = ? AND id != ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param('si', $phone, $memberId);
        $stmt->execute();
        $result = $stmt->get_result();
        if ($result->num_rows > 0) {
            $errors[] = '该手机号已被注册';
        }
    }

    if (!empty($email) && !filter_var($email, FILTER_VALIDATE_EMAIL)) {
        $errors[] = '邮箱格式不正确';
    }

    if (empty($idType)) {
        $errors[] = '证件类型不能为空';
    }

    if (empty($idNumber)) {
        $errors[] = '证件号码不能为空';
    }

    if (empty($gender)) {
        $errors[] = '性别不能为空';
    }

    // 如果没有错误，保存数据
    if (empty($errors)) {
        if ($isAdd) {
            // 添加新会员
            $sql = "INSERT INTO members (name, phone, email, id_type, id_number, gender, birthday, address, level, status, notes, registration_date, created_at) 
                    VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, NOW(), NOW())";
            $stmt = $conn->prepare($sql);
            $stmt->bind_param('sssssssssss', $name, $phone, $email, $idType, $idNumber, $gender, $birthday, $address, $level, $status, $notes);
        } else {
            // 更新现有会员
            $sql = "UPDATE members SET name = ?, phone = ?, email = ?, id_type = ?, id_number = ?, gender = ?, 
                    birthday = ?, address = ?, level = ?, status = ?, notes = ?, updated_at = NOW() 
                    WHERE id = ?";
            $stmt = $conn->prepare($sql);
            $stmt->bind_param('sssssssssssi', $name, $phone, $email, $idType, $idNumber, $gender, $birthday, $address, $level, $status, $notes, $memberId);
        }

        if ($stmt->execute()) {
            $success = true;
            if ($isAdd) {
                $memberId = $conn->insert_id;
                // 重定向到编辑页面
                header("Location: index.php?page=member_edit&id=$memberId&success=1");
                exit;
            }
        } else {
            $errors[] = '保存失败: ' . $conn->error;
        }
    }
}

// 如果是GET请求且有success参数，显示成功消息
if ($_SERVER['REQUEST_METHOD'] == 'GET' && isset($_GET['success'])) {
    $success = true;
}
?>

<div class="content-wrapper">
    <?php if ($success): ?>
        <div class="alert alert-success">
            会员信息保存成功！
        </div>
    <?php endif; ?>

    <?php if (!empty($errors)): ?>
        <div class="alert alert-danger">
            <ul>
                <?php foreach ($errors as $error): ?>
                    <li><?php echo $error; ?></li>
                <?php endforeach; ?>
            </ul>
        </div>
    <?php endif; ?>

    <div class="card">
        <div class="card-header">
            <h5 class="card-title"><?php echo $pageTitle; ?></h5>
        </div>
        <div class="card-body">
            <form method="post" action="">
                <div class="row">
                    <div class="col-md-6">
                        <div class="form-group mb-3">
                            <label for="name">姓名 <span class="text-danger">*</span></label>
                            <input type="text" class="form-control" id="name" name="name" value="<?php echo isset($member['name']) ? $member['name'] : (isset($_POST['name']) ? $_POST['name'] : ''); ?>" required>
                        </div>
                    </div>
                    <div class="col-md-6">
                        <div class="form-group mb-3">
                            <label for="phone">手机号 <span class="text-danger">*</span></label>
                            <input type="text" class="form-control" id="phone" name="phone" value="<?php echo isset($member['phone']) ? $member['phone'] : (isset($_POST['phone']) ? $_POST['phone'] : ''); ?>" required>
                        </div>
                    </div>
                </div>

                <div class="row">
                    <div class="col-md-6">
                        <div class="form-group mb-3">
                            <label for="email">邮箱</label>
                            <input type="email" class="form-control" id="email" name="email" value="<?php echo isset($member['email']) ? $member['email'] : (isset($_POST['email']) ? $_POST['email'] : ''); ?>">
                        </div>
                    </div>
                    <div class="col-md-6">
                        <div class="form-group mb-3">
                            <label for="gender">性别 <span class="text-danger">*</span></label>
                            <select class="form-control" id="gender" name="gender" required>
                                <option value="">请选择</option>
                                <option value="male" <?php echo (isset($member['gender']) && $member['gender'] == 'male') ? 'selected' : ((isset($_POST['gender']) && $_POST['gender'] == 'male') ? 'selected' : ''); ?>>男</option>
                                <option value="female" <?php echo (isset($member['gender']) && $member['gender'] == 'female') ? 'selected' : ((isset($_POST['gender']) && $_POST['gender'] == 'female') ? 'selected' : ''); ?>>女</option>
                                <option value="other" <?php echo (isset($member['gender']) && $member['gender'] == 'other') ? 'selected' : ((isset($_POST['gender']) && $_POST['gender'] == 'other') ? 'selected' : ''); ?>>其他</option>
                            </select>
                        </div>
                    </div>
                </div>

                <div class="row">
                    <div class="col-md-6">
                        <div class="form-group mb-3">
                            <label for="id_type">证件类型 <span class="text-danger">*</span></label>
                            <select class="form-control" id="id_type" name="id_type" required>
                                <option value="">请选择</option>
                                <option value="id_card" <?php echo (isset($member['id_type']) && $member['id_type'] == 'id_card') ? 'selected' : ((isset($_POST['id_type']) && $_POST['id_type'] == 'id_card') ? 'selected' : ''); ?>>身份证</option>
                                <option value="passport" <?php echo (isset($member['id_type']) && $member['id_type'] == 'passport') ? 'selected' : ((isset($_POST['id_type']) && $_POST['id_type'] == 'passport') ? 'selected' : ''); ?>>护照</option>
                                <option value="driving_license" <?php echo (isset($member['id_type']) && $member['id_type'] == 'driving_license') ? 'selected' : ((isset($_POST['id_type']) && $_POST['id_type'] == 'driving_license') ? 'selected' : ''); ?>>驾驶证</option>
                                <option value="other" <?php echo (isset($member['id_type']) && $member['id_type'] == 'other') ? 'selected' : ((isset($_POST['id_type']) && $_POST['id_type'] == 'other') ? 'selected' : ''); ?>>其他</option>
                            </select>
                        </div>
                    </div>
                    <div class="col-md-6">
                        <div class="form-group mb-3">
                            <label for="id_number">证件号码 <span class="text-danger">*</span></label>
                            <input type="text" class="form-control" id="id_number" name="id_number" value="<?php echo isset($member['id_number']) ? $member['id_number'] : (isset($_POST['id_number']) ? $_POST['id_number'] : ''); ?>" required>
                        </div>
                    </div>
                </div>

                <div class="row">
                    <div class="col-md-6">
                        <div class="form-group mb-3">
                            <label for="birthday">生日</label>
                            <input type="date" class="form-control" id="birthday" name="birthday" value="<?php echo isset($member['birthday']) ? $member['birthday'] : (isset($_POST['birthday']) ? $_POST['birthday'] : ''); ?>">
                        </div>
                    </div>
                    <div class="col-md-6">
                        <div class="form-group mb-3">
                            <label for="level">会员等级 <span class="text-danger">*</span></label>
                            <select class="form-control" id="level" name="level" required>
                                <option value="regular" <?php echo (isset($member['level']) && $member['level'] == 'regular') ? 'selected' : ((isset($_POST['level']) && $_POST['level'] == 'regular') ? 'selected' : ''); ?>>普通会员</option>
                                <option value="silver" <?php echo (isset($member['level']) && $member['level'] == 'silver') ? 'selected' : ((isset($_POST['level']) && $_POST['level'] == 'silver') ? 'selected' : ''); ?>>白银会员</option>
                                <option value="gold" <?php echo (isset($member['level']) && $member['level'] == 'gold') ? 'selected' : ((isset($_POST['level']) && $_POST['level'] == 'gold') ? 'selected' : ''); ?>>黄金会员</option>
                                <option value="platinum" <?php echo (isset($member['level']) && $member['level'] == 'platinum') ? 'selected' : ((isset($_POST['level']) && $_POST['level'] == 'platinum') ? 'selected' : ''); ?>>铂金会员</option>
                            </select>
                        </div>
                    </div>
                </div>

                <div class="row">
                    <div class="col-md-6">
                        <div class="form-group mb-3">
                            <label for="status">状态 <span class="text-danger">*</span></label>
                            <select class="form-control" id="status" name="status" required>
                                <option value="active" <?php echo (isset($member['status']) && $member['status'] == 'active') ? 'selected' : ((isset($_POST['status']) && $_POST['status'] == 'active') ? 'selected' : ''); ?>>活跃</option>
                                <option value="inactive" <?php echo (isset($member['status']) && $member['status'] == 'inactive') ? 'selected' : ((isset($_POST['status']) && $_POST['status'] == 'inactive') ? 'selected' : ''); ?>>不活跃</option>
                            </select>
                        </div>
                    </div>
                    <div class="col-md-6">
                        <?php if (!$isAdd): ?>
                            <div class="form-group mb-3">
                                <label for="registration_date">注册日期</label>
                                <input type="text" class="form-control" id="registration_date" value="<?php echo isset($member['registration_date']) ? date('Y-m-d', strtotime($member['registration_date'])) : ''; ?>" readonly>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>

                <div class="form-group mb-3">
                    <label for="address">地址</label>
                    <textarea class="form-control" id="address" name="address" rows="2"><?php echo isset($member['address']) ? $member['address'] : (isset($_POST['address']) ? $_POST['address'] : ''); ?></textarea>
                </div>

                <div class="form-group mb-3">
                    <label for="notes">备注</label>
                    <textarea class="form-control" id="notes" name="notes" rows="3"><?php echo isset($member['notes']) ? $member['notes'] : (isset($_POST['notes']) ? $_POST['notes'] : ''); ?></textarea>
                </div>

                <?php if (!$isAdd): ?>
                    <div class="row">
                        <div class="col-md-4">
                            <div class="form-group mb-3">
                                <label>积分</label>
                                <input type="text" class="form-control" value="<?php echo isset($member['points']) ? $member['points'] : '0'; ?>" readonly>
                            </div>
                        </div>
                        <div class="col-md-4">
                            <div class="form-group mb-3">
                                <label>入住次数</label>
                                <input type="text" class="form-control" value="<?php echo isset($member['total_stays']) ? $member['total_stays'] : '0'; ?>" readonly>
                            </div>
                        </div>
                        <div class="col-md-4">
                            <div class="form-group mb-3">
                                <label>消费总额</label>
                                <input type="text" class="form-control" value="<?php echo isset($member['total_spent']) ? number_format($member['total_spent'], 2) : '0.00'; ?>" readonly>
                            </div>
                        </div>
                    </div>
                <?php endif; ?>

                <div class="form-group mt-4">
                    <button type="submit" class="btn btn-primary">保存</button>
                    <a href="index.php?page=member_list" class="btn btn-secondary ml-2">返回列表</a>
                    <?php if (!$isAdd): ?>
                        <a href="index.php?page=member_profile&id=<?php echo $memberId; ?>" class="btn btn-info ml-2">查看详情</a>
                    <?php endif; ?>
                </div>
            </form>
        </div>
    </div>
</div>

<style>
    .form-group label {
        font-weight: 500;
    }

    .text-danger {
        color: #dc3545;
    }

    .ml-2 {
        margin-left: 0.5rem;
    }
</style>