<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 连接数据库
$conn = mysqli_connect(DB_HOST, DB_USER, DB_PASS, DB_NAME);
if (!$conn) {
    die("连接失败: " . mysqli_connect_error());
}

// 检查安全巡查记录表是否存在，如果不存在则创建
$check_table_sql = "SHOW TABLES LIKE 'security_inspections'";
$table_exists = mysqli_query($conn, $check_table_sql)->num_rows > 0;

if (!$table_exists) {
    $create_table_sql = "CREATE TABLE IF NOT EXISTS security_inspections (
        id INT AUTO_INCREMENT PRIMARY KEY,
        inspection_date DATE NOT NULL,
        inspection_time TIME NOT NULL,
        area VARCHAR(100) NOT NULL,
        inspector_id INT NOT NULL,
        status ENUM('normal', 'issue_found', 'maintenance_required') NOT NULL DEFAULT 'normal',
        issue_description TEXT,
        action_taken TEXT,
        is_resolved TINYINT(1) NOT NULL DEFAULT 0,
        resolved_date DATETIME,
        resolved_by INT,
        created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
        updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
        FOREIGN KEY (inspector_id) REFERENCES users(id) ON DELETE CASCADE,
        FOREIGN KEY (resolved_by) REFERENCES users(id) ON DELETE SET NULL
    ) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4";

    if (!mysqli_query($conn, $create_table_sql)) {
        $error_message = "创建安全巡查记录表失败: " . mysqli_error($conn);
    }
}

// 处理添加安全巡查记录请求
if (isset($_POST['add_inspection'])) {
    $inspection_date = $_POST['inspection_date'];
    $inspection_time = $_POST['inspection_time'];
    $area = $_POST['area'];
    $status = $_POST['status'];
    $issue_description = $_POST['issue_description'] ?? '';
    $action_taken = $_POST['action_taken'] ?? '';

    $sql = "INSERT INTO security_inspections (inspection_date, inspection_time, area, inspector_id, status, issue_description, action_taken) 
            VALUES (?, ?, ?, ?, ?, ?, ?)";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("sssssss", $inspection_date, $inspection_time, $area, $_SESSION['user_id'], $status, $issue_description, $action_taken);

    if ($stmt->execute()) {
        $success_message = "安全巡查记录添加成功";
    } else {
        $error_message = "安全巡查记录添加失败: " . $stmt->error;
    }
}

// 处理更新安全巡查记录状态请求
if (isset($_POST['resolve_issue'])) {
    $inspection_id = $_POST['inspection_id'];
    $action_taken = $_POST['action_taken'];

    $sql = "UPDATE security_inspections 
            SET is_resolved = 1, 
                resolved_date = NOW(), 
                resolved_by = ?, 
                action_taken = CONCAT(IFNULL(action_taken,''), '\n', ?) 
            WHERE id = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("isi", $_SESSION['user_id'], $action_taken, $inspection_id);

    if ($stmt->execute()) {
        $success_message = "问题已标记为已解决";
    } else {
        $error_message = "更新记录失败: " . $stmt->error;
    }
}

// 获取安全巡查区域列表
$areas = [
    '前台大厅',
    '客房走廊',
    '电梯间',
    '消防通道',
    '停车场',
    '餐厅区域',
    '厨房',
    '员工区域',
    '设备房',
    '游泳池',
    '健身房',
    '户外区域'
];

// 获取安全巡查记录列表
$filter_status = isset($_GET['status']) ? $_GET['status'] : '';
$filter_area = isset($_GET['area']) ? $_GET['area'] : '';
$filter_date_from = isset($_GET['date_from']) ? $_GET['date_from'] : date('Y-m-d', strtotime('-30 days'));
$filter_date_to = isset($_GET['date_to']) ? $_GET['date_to'] : date('Y-m-d');

$sql = "SELECT s.*, 
        u1.name as inspector_name,
        u2.name as resolver_name
        FROM security_inspections s
        LEFT JOIN users u1 ON s.inspector_id = u1.id
        LEFT JOIN users u2 ON s.resolved_by = u2.id
        WHERE inspection_date BETWEEN ? AND ?";

$params = [$filter_date_from, $filter_date_to];
$types = "ss";

if (!empty($filter_status)) {
    $sql .= " AND status = ?";
    $params[] = $filter_status;
    $types .= "s";
}

if (!empty($filter_area)) {
    $sql .= " AND area = ?";
    $params[] = $filter_area;
    $types .= "s";
}

$sql .= " ORDER BY inspection_date DESC, inspection_time DESC";

$stmt = $conn->prepare($sql);
$stmt->bind_param($types, ...$params);
$stmt->execute();
$result = $stmt->get_result();
$inspections = [];
while ($row = $result->fetch_assoc()) {
    $inspections[] = $row;
}

// 关闭数据库连接
mysqli_close($conn);
?>

<div class="content">
    <?php if (isset($success_message)): ?>
        <div class="alert alert-success">
            <?php echo $success_message; ?>
        </div>
    <?php endif; ?>

    <?php if (isset($error_message)): ?>
        <div class="alert alert-danger">
            <?php echo $error_message; ?>
        </div>
    <?php endif; ?>

    <div class="action-buttons">
        <button class="btn btn-primary" onclick="showAddInspectionModal()">添加安全巡查记录</button>
    </div>

    <!-- 筛选器 -->
    <div class="filter-section">
        <form method="get" class="filter-form">
            <div class="form-group">
                <label>开始日期：</label>
                <input type="date" name="date_from" value="<?php echo $filter_date_from; ?>" class="form-control">
            </div>
            <div class="form-group">
                <label>结束日期：</label>
                <input type="date" name="date_to" value="<?php echo $filter_date_to; ?>" class="form-control">
            </div>
            <div class="form-group">
                <label>区域：</label>
                <select name="area" class="form-control">
                    <option value="">全部区域</option>
                    <?php foreach ($areas as $area): ?>
                        <option value="<?php echo $area; ?>" <?php echo $filter_area == $area ? 'selected' : ''; ?>>
                            <?php echo $area; ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
            <div class="form-group">
                <label>状态：</label>
                <select name="status" class="form-control">
                    <option value="">全部状态</option>
                    <option value="normal" <?php echo $filter_status == 'normal' ? 'selected' : ''; ?>>正常</option>
                    <option value="issue_found" <?php echo $filter_status == 'issue_found' ? 'selected' : ''; ?>>发现问题</option>
                    <option value="maintenance_required" <?php echo $filter_status == 'maintenance_required' ? 'selected' : ''; ?>>需要维修</option>
                </select>
            </div>
            <button type="submit" class="btn btn-primary">筛选</button>
        </form>
    </div>

    <!-- 安全巡查记录列表 -->
    <div class="records-list">
        <table class="data-table">
            <thead>
                <tr>
                    <th>日期</th>
                    <th>时间</th>
                    <th>区域</th>
                    <th>巡查人员</th>
                    <th>状态</th>
                    <th>问题描述</th>
                    <th>是否解决</th>
                    <th>操作</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($inspections as $inspection): ?>
                    <tr>
                        <td><?php echo date('Y-m-d', strtotime($inspection['inspection_date'])); ?></td>
                        <td><?php echo date('H:i', strtotime($inspection['inspection_time'])); ?></td>
                        <td><?php echo htmlspecialchars($inspection['area']); ?></td>
                        <td><?php echo htmlspecialchars($inspection['inspector_name']); ?></td>
                        <td>
                            <span class="badge badge-<?php
                                                        echo $inspection['status'] == 'normal' ? 'success' : ($inspection['status'] == 'issue_found' ? 'warning' : 'danger');
                                                        ?>">
                                <?php
                                echo $inspection['status'] == 'normal' ? '正常' : ($inspection['status'] == 'issue_found' ? '发现问题' : '需要维修');
                                ?>
                            </span>
                        </td>
                        <td><?php echo htmlspecialchars($inspection['issue_description'] ?? '无'); ?></td>
                        <td>
                            <?php if ($inspection['is_resolved']): ?>
                                <span class="badge badge-success">已解决</span>
                                <small><?php echo date('Y-m-d', strtotime($inspection['resolved_date'])); ?></small>
                            <?php else: ?>
                                <span class="badge badge-warning">未解决</span>
                            <?php endif; ?>
                        </td>
                        <td>
                            <button class="btn btn-sm btn-info" onclick="viewInspectionDetails(<?php echo $inspection['id']; ?>)">详情</button>

                            <?php if (!$inspection['is_resolved'] && ($inspection['status'] == 'issue_found' || $inspection['status'] == 'maintenance_required')): ?>
                                <button class="btn btn-sm btn-success" onclick="showResolveModal(<?php echo $inspection['id']; ?>)">标记为已解决</button>
                            <?php endif; ?>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>
</div>

<!-- 添加安全巡查记录模态框 -->
<div class="modal" id="addInspectionModal">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title">添加安全巡查记录</h4>
                <button type="button" class="close" onclick="closeModal('addInspectionModal')">&times;</button>
            </div>
            <div class="modal-body">
                <form id="addInspectionForm" method="post">
                    <div class="form-group">
                        <label>巡查日期</label>
                        <input type="date" class="form-control" name="inspection_date" required value="<?php echo date('Y-m-d'); ?>">
                    </div>

                    <div class="form-group">
                        <label>巡查时间</label>
                        <input type="time" class="form-control" name="inspection_time" required value="<?php echo date('H:i'); ?>">
                    </div>

                    <div class="form-group">
                        <label>巡查区域</label>
                        <select class="form-control" name="area" required>
                            <option value="">请选择区域</option>
                            <?php foreach ($areas as $area): ?>
                                <option value="<?php echo $area; ?>"><?php echo $area; ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <div class="form-group">
                        <label>状态</label>
                        <select class="form-control" name="status" required onchange="toggleIssueDescription(this.value)">
                            <option value="normal">正常</option>
                            <option value="issue_found">发现问题</option>
                            <option value="maintenance_required">需要维修</option>
                        </select>
                    </div>

                    <div class="form-group" id="issueDescriptionGroup" style="display: none;">
                        <label>问题描述</label>
                        <textarea class="form-control" name="issue_description" rows="3"></textarea>
                    </div>

                    <div class="form-group" id="actionTakenGroup" style="display: none;">
                        <label>采取的措施</label>
                        <textarea class="form-control" name="action_taken" rows="3"></textarea>
                    </div>

                    <input type="hidden" name="add_inspection" value="1">
                </form>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" onclick="closeModal('addInspectionModal')">取消</button>
                <button type="button" class="btn btn-primary" onclick="submitAddInspectionForm()">添加</button>
            </div>
        </div>
    </div>
</div>

<!-- 解决问题模态框 -->
<div class="modal" id="resolveModal">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title">解决安全问题</h4>
                <button type="button" class="close" onclick="closeModal('resolveModal')">&times;</button>
            </div>
            <div class="modal-body">
                <form id="resolveForm" method="post">
                    <div class="form-group">
                        <label>采取的措施</label>
                        <textarea class="form-control" name="action_taken" rows="3" required></textarea>
                    </div>
                    <input type="hidden" name="inspection_id" id="resolve_inspection_id">
                    <input type="hidden" name="resolve_issue" value="1">
                </form>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" onclick="closeModal('resolveModal')">取消</button>
                <button type="button" class="btn btn-primary" onclick="submitResolveForm()">标记为已解决</button>
            </div>
        </div>
    </div>
</div>

<!-- 查看详情模态框 -->
<div class="modal" id="detailsModal">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title">安全巡查详情</h4>
                <button type="button" class="close" onclick="closeModal('detailsModal')">&times;</button>
            </div>
            <div class="modal-body" id="detailsContent">
                <!-- 详情内容将通过JavaScript动态填充 -->
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" onclick="closeModal('detailsModal')">关闭</button>
            </div>
        </div>
    </div>
</div>

<style>
    .content {
        padding: 20px;
    }

    .filter-section {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        padding: 20px;
        margin: 20px 0;
    }

    .filter-form {
        display: flex;
        flex-wrap: wrap;
        gap: 15px;
        align-items: flex-end;
    }

    .filter-form .form-group {
        flex: 1;
        min-width: 200px;
    }

    .records-list {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        padding: 20px;
        margin-top: 20px;
    }

    .data-table {
        width: 100%;
        border-collapse: collapse;
    }

    .data-table th,
    .data-table td {
        padding: 12px;
        text-align: left;
        border-bottom: 1px solid #eee;
    }

    .data-table th {
        background-color: #f8f9fa;
        font-weight: bold;
    }

    .badge {
        display: inline-block;
        padding: 0.25em 0.6em;
        font-size: 75%;
        font-weight: 700;
        line-height: 1;
        text-align: center;
        white-space: nowrap;
        vertical-align: baseline;
        border-radius: 0.25rem;
    }

    .badge-success {
        color: #fff;
        background-color: #28a745;
    }

    .badge-warning {
        color: #212529;
        background-color: #ffc107;
    }

    .badge-danger {
        color: #fff;
        background-color: #dc3545;
    }

    .badge-info {
        color: #fff;
        background-color: #17a2b8;
    }

    .modal {
        display: none;
        position: fixed;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
        background-color: rgba(0, 0, 0, 0.5);
        z-index: 1000;
    }

    .modal-dialog {
        position: relative;
        width: 500px;
        margin: 50px auto;
    }

    .modal-content {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 3px 7px rgba(0, 0, 0, 0.3);
    }

    .modal-header {
        padding: 15px;
        border-bottom: 1px solid #e9ecef;
        display: flex;
        justify-content: space-between;
        align-items: center;
    }

    .modal-title {
        margin: 0;
        font-size: 18px;
    }

    .close {
        font-size: 24px;
        font-weight: bold;
        border: none;
        background: none;
        cursor: pointer;
    }

    .modal-body {
        padding: 15px;
    }

    .modal-footer {
        padding: 15px;
        border-top: 1px solid #e9ecef;
        text-align: right;
    }

    .btn {
        display: inline-block;
        padding: 8px 16px;
        border-radius: 4px;
        text-decoration: none;
        font-size: 14px;
        cursor: pointer;
        border: none;
        transition: background-color 0.3s;
    }

    .btn-sm {
        padding: 5px 10px;
        font-size: 12px;
    }

    .btn-primary {
        background-color: #007bff;
        color: #fff;
    }

    .btn-primary:hover {
        background-color: #0056b3;
    }

    .btn-secondary {
        background-color: #6c757d;
        color: #fff;
    }

    .btn-secondary:hover {
        background-color: #5a6268;
    }

    .btn-success {
        background-color: #28a745;
        color: #fff;
    }

    .btn-success:hover {
        background-color: #218838;
    }

    .btn-info {
        background-color: #17a2b8;
        color: #fff;
    }

    .btn-info:hover {
        background-color: #138496;
    }

    .alert {
        padding: 15px;
        margin-bottom: 20px;
        border: 1px solid transparent;
        border-radius: 4px;
    }

    .alert-success {
        color: #155724;
        background-color: #d4edda;
        border-color: #c3e6cb;
    }

    .alert-danger {
        color: #721c24;
        background-color: #f8d7da;
        border-color: #f5c6cb;
    }

    .detail-item {
        margin-bottom: 15px;
    }

    .detail-label {
        font-weight: bold;
        display: block;
        margin-bottom: 5px;
    }

    .detail-value {
        padding-left: 10px;
    }
</style>

<script>
    function showAddInspectionModal() {
        document.getElementById('addInspectionModal').style.display = 'block';
    }

    function closeModal(modalId) {
        document.getElementById(modalId).style.display = 'none';
    }

    function toggleIssueDescription(status) {
        const issueDescriptionGroup = document.getElementById('issueDescriptionGroup');
        const actionTakenGroup = document.getElementById('actionTakenGroup');

        if (status === 'normal') {
            issueDescriptionGroup.style.display = 'none';
            actionTakenGroup.style.display = 'none';
        } else {
            issueDescriptionGroup.style.display = 'block';
            actionTakenGroup.style.display = 'block';
        }
    }

    function submitAddInspectionForm() {
        const form = document.getElementById('addInspectionForm');

        if (!form.inspection_date.value) {
            alert('请选择巡查日期');
            return false;
        }

        if (!form.inspection_time.value) {
            alert('请选择巡查时间');
            return false;
        }

        if (!form.area.value) {
            alert('请选择巡查区域');
            return false;
        }

        if (form.status.value !== 'normal' && !form.issue_description.value) {
            alert('请填写问题描述');
            return false;
        }

        form.submit();
    }

    function showResolveModal(inspectionId) {
        document.getElementById('resolve_inspection_id').value = inspectionId;
        document.getElementById('resolveModal').style.display = 'block';
    }

    function submitResolveForm() {
        const form = document.getElementById('resolveForm');

        if (!form.action_taken.value) {
            alert('请填写采取的措施');
            return false;
        }

        form.submit();
    }

    function viewInspectionDetails(inspectionId) {
        // 在实际应用中，这里应该通过AJAX获取详细信息
        // 为了简化，我们假设从页面上已有的数据中获取
        const inspections = <?php echo json_encode($inspections); ?>;
        const inspection = inspections.find(i => i.id == inspectionId);

        if (!inspection) {
            alert('未找到记录');
            return;
        }

        let statusText = '';
        switch (inspection.status) {
            case 'normal':
                statusText = '正常';
                break;
            case 'issue_found':
                statusText = '发现问题';
                break;
            case 'maintenance_required':
                statusText = '需要维修';
                break;
        }

        let detailsHtml = `
        <div class="detail-item">
            <div class="detail-label">巡查日期:</div>
            <div class="detail-value">${new Date(inspection.inspection_date).toLocaleDateString()}</div>
        </div>
        <div class="detail-item">
            <div class="detail-label">巡查时间:</div>
            <div class="detail-value">${inspection.inspection_time}</div>
        </div>
        <div class="detail-item">
            <div class="detail-label">巡查区域:</div>
            <div class="detail-value">${inspection.area}</div>
        </div>
        <div class="detail-item">
            <div class="detail-label">巡查人员:</div>
            <div class="detail-value">${inspection.inspector_name}</div>
        </div>
        <div class="detail-item">
            <div class="detail-label">状态:</div>
            <div class="detail-value">${statusText}</div>
        </div>
    `;

        if (inspection.issue_description) {
            detailsHtml += `
            <div class="detail-item">
                <div class="detail-label">问题描述:</div>
                <div class="detail-value">${inspection.issue_description}</div>
            </div>
        `;
        }

        if (inspection.action_taken) {
            detailsHtml += `
            <div class="detail-item">
                <div class="detail-label">采取的措施:</div>
                <div class="detail-value">${inspection.action_taken}</div>
            </div>
        `;
        }

        if (inspection.is_resolved) {
            detailsHtml += `
            <div class="detail-item">
                <div class="detail-label">解决状态:</div>
                <div class="detail-value">已解决</div>
            </div>
            <div class="detail-item">
                <div class="detail-label">解决日期:</div>
                <div class="detail-value">${new Date(inspection.resolved_date).toLocaleString()}</div>
            </div>
            <div class="detail-item">
                <div class="detail-label">解决人员:</div>
                <div class="detail-value">${inspection.resolver_name}</div>
            </div>
        `;
        } else {
            detailsHtml += `
            <div class="detail-item">
                <div class="detail-label">解决状态:</div>
                <div class="detail-value">未解决</div>
            </div>
        `;
        }

        document.getElementById('detailsContent').innerHTML = detailsHtml;
        document.getElementById('detailsModal').style.display = 'block';
    }

    // 点击模态框外部关闭
    window.onclick = function(event) {
        if (event.target.className === 'modal') {
            event.target.style.display = 'none';
        }
    }
</script>