<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 处理添加房型
if (isset($_POST['action']) && $_POST['action'] == 'add') {
    $name = sanitize($_POST['name']);
    $description = sanitize($_POST['description']);
    $capacity = (int)$_POST['capacity'];
    $basePrice = (float)$_POST['base_price'];
    $status = sanitize($_POST['status']);

    // 验证数据
    $errors = [];

    if (empty($name)) {
        $errors[] = '房型名称不能为空';
    }

    if ($capacity <= 0) {
        $errors[] = '容纳人数必须大于0';
    }

    if ($basePrice <= 0) {
        $errors[] = '基础价格必须大于0';
    }

    // 检查房型名称是否已存在
    $checkSql = "SELECT id FROM room_types WHERE name = ?";
    $checkStmt = $conn->prepare($checkSql);
    $checkStmt->bind_param("s", $name);
    $checkStmt->execute();
    $checkResult = $checkStmt->get_result();

    if ($checkResult->num_rows > 0) {
        $errors[] = '房型名称已存在，请使用其他名称';
    }

    // 如果没有错误，插入数据
    if (empty($errors)) {
        $sql = "INSERT INTO room_types (name, description, capacity, base_price, status) VALUES (?, ?, ?, ?, ?)";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("ssids", $name, $description, $capacity, $basePrice, $status);

        if ($stmt->execute()) {
            // 记录操作日志
            logActivity('add_room_type', '添加房型: ' . $name);

            // 设置成功消息
            $successMessage = '房型添加成功';
        } else {
            $errors[] = '添加房型失败: ' . $conn->error;
        }
    }
}

// 处理编辑房型
if (isset($_POST['action']) && $_POST['action'] == 'edit') {
    $roomTypeId = (int)$_POST['room_type_id'];
    $name = sanitize($_POST['name']);
    $description = sanitize($_POST['description']);
    $capacity = (int)$_POST['capacity'];
    $basePrice = (float)$_POST['base_price'];
    $status = sanitize($_POST['status']);

    // 验证数据
    $errors = [];

    if (empty($name)) {
        $errors[] = '房型名称不能为空';
    }

    if ($capacity <= 0) {
        $errors[] = '容纳人数必须大于0';
    }

    if ($basePrice <= 0) {
        $errors[] = '基础价格必须大于0';
    }

    // 检查房型名称是否已存在（排除当前房型）
    $checkSql = "SELECT id FROM room_types WHERE name = ? AND id != ?";
    $checkStmt = $conn->prepare($checkSql);
    $checkStmt->bind_param("si", $name, $roomTypeId);
    $checkStmt->execute();
    $checkResult = $checkStmt->get_result();

    if ($checkResult->num_rows > 0) {
        $errors[] = '房型名称已存在，请使用其他名称';
    }

    // 如果没有错误，更新数据
    if (empty($errors)) {
        $sql = "UPDATE room_types SET name = ?, description = ?, capacity = ?, base_price = ?, status = ? WHERE id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("ssidsi", $name, $description, $capacity, $basePrice, $status, $roomTypeId);

        if ($stmt->execute()) {
            // 记录操作日志
            logActivity('edit_room_type', '编辑房型: ' . $name);

            // 设置成功消息
            $successMessage = '房型更新成功';
        } else {
            $errors[] = '更新房型失败: ' . $conn->error;
        }
    }
}

// 处理删除房型
if (isset($_GET['action']) && $_GET['action'] == 'delete' && isset($_GET['id'])) {
    $roomTypeId = (int)$_GET['id'];

    // 检查房型是否存在
    $checkSql = "SELECT name FROM room_types WHERE id = ?";
    $checkStmt = $conn->prepare($checkSql);
    $checkStmt->bind_param("i", $roomTypeId);
    $checkStmt->execute();
    $checkResult = $checkStmt->get_result();

    if ($checkResult->num_rows > 0) {
        $roomTypeName = $checkResult->fetch_assoc()['name'];

        // 检查是否有房间使用此房型
        $checkRoomsSql = "SELECT COUNT(*) as count FROM rooms WHERE room_type_id = ?";
        $checkRoomsStmt = $conn->prepare($checkRoomsSql);
        $checkRoomsStmt->bind_param("i", $roomTypeId);
        $checkRoomsStmt->execute();
        $checkRoomsResult = $checkRoomsStmt->get_result();
        $roomCount = $checkRoomsResult->fetch_assoc()['count'];

        if ($roomCount > 0) {
            $errorMessage = '无法删除房型，有 ' . $roomCount . ' 个房间正在使用此房型';
        } else {
            // 删除房型
            $deleteSql = "DELETE FROM room_types WHERE id = ?";
            $deleteStmt = $conn->prepare($deleteSql);
            $deleteStmt->bind_param("i", $roomTypeId);

            if ($deleteStmt->execute()) {
                // 记录操作日志
                logActivity('delete_room_type', '删除房型: ' . $roomTypeName);

                // 设置成功消息
                $successMessage = '房型删除成功';
            } else {
                $errorMessage = '删除房型失败: ' . $conn->error;
            }
        }
    } else {
        $errorMessage = '房型不存在';
    }
}

// 获取房型列表
$sql = "SELECT id, name, description, capacity, base_price, status FROM room_types ORDER BY name";
$result = $conn->query($sql);
$roomTypes = [];
if ($result && $result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $roomTypes[] = $row;
    }
}

// 获取要编辑的房型信息
$editRoomType = null;
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $roomTypeId = (int)$_GET['id'];

    $sql = "SELECT id, name, description, capacity, base_price, status FROM room_types WHERE id = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("i", $roomTypeId);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        $editRoomType = $result->fetch_assoc();
    }
}
?>

<div class="content-wrapper">
    <div class="page-header">
        <h2>房型管理</h2>
    </div>

    <?php if (isset($successMessage)): ?>
        <div class="alert alert-success"><?php echo $successMessage; ?></div>
    <?php endif; ?>

    <?php if (isset($errorMessage)): ?>
        <div class="alert alert-error"><?php echo $errorMessage; ?></div>
    <?php endif; ?>

    <div class="room-type-container">
        <div class="room-type-list">
            <div class="card">
                <div class="card-header">
                    <h3>房型列表</h3>
                </div>
                <div class="card-body">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>名称</th>
                                <th>容纳人数</th>
                                <th>基础价格</th>
                                <th>状态</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($roomTypes)): ?>
                                <tr>
                                    <td colspan="5" class="text-center">暂无房型数据</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($roomTypes as $type): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($type['name']); ?></td>
                                        <td><?php echo $type['capacity']; ?> 人</td>
                                        <td>¥<?php echo number_format($type['base_price'], 2); ?></td>
                                        <td>
                                            <span class="status-badge status-<?php echo $type['status']; ?>">
                                                <?php echo $type['status'] == 'active' ? '启用' : '禁用'; ?>
                                            </span>
                                        </td>
                                        <td class="actions">
                                            <a href="index.php?page=room_type&action=edit&id=<?php echo $type['id']; ?>" class="btn btn-sm btn-primary">编辑</a>
                                            <a href="index.php?page=room_type&action=delete&id=<?php echo $type['id']; ?>" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除此房型吗？此操作不可恢复！');">删除</a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>

        <div class="room-type-form">
            <div class="card">
                <div class="card-header">
                    <h3><?php echo $editRoomType ? '编辑房型' : '添加房型'; ?></h3>
                </div>
                <div class="card-body">
                    <?php if (!empty($errors)): ?>
                        <div class="alert alert-error">
                            <ul>
                                <?php foreach ($errors as $error): ?>
                                    <li><?php echo $error; ?></li>
                                <?php endforeach; ?>
                            </ul>
                        </div>
                    <?php endif; ?>

                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $editRoomType ? 'edit' : 'add'; ?>">
                        <?php if ($editRoomType): ?>
                            <input type="hidden" name="room_type_id" value="<?php echo $editRoomType['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="name">房型名称 <span class="required">*</span></label>
                            <input type="text" id="name" name="name" value="<?php echo $editRoomType ? htmlspecialchars($editRoomType['name']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="description">描述</label>
                            <textarea id="description" name="description" rows="3"><?php echo $editRoomType ? htmlspecialchars($editRoomType['description']) : ''; ?></textarea>
                        </div>

                        <div class="form-row">
                            <div class="form-group col-md-6">
                                <label for="capacity">容纳人数 <span class="required">*</span></label>
                                <input type="number" id="capacity" name="capacity" min="1" value="<?php echo $editRoomType ? $editRoomType['capacity'] : '1'; ?>" required>
                            </div>

                            <div class="form-group col-md-6">
                                <label for="base_price">基础价格 <span class="required">*</span></label>
                                <input type="number" id="base_price" name="base_price" min="0" step="0.01" value="<?php echo $editRoomType ? $editRoomType['base_price'] : '0.00'; ?>" required>
                            </div>
                        </div>

                        <div class="form-group">
                            <label for="status">状态</label>
                            <select id="status" name="status">
                                <option value="active" <?php echo ($editRoomType && $editRoomType['status'] == 'active') ? 'selected' : ''; ?>>启用</option>
                                <option value="inactive" <?php echo ($editRoomType && $editRoomType['status'] == 'inactive') ? 'selected' : ''; ?>>禁用</option>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-primary"><?php echo $editRoomType ? '更新' : '添加'; ?></button>
                            <?php if ($editRoomType): ?>
                                <a href="index.php?page=room_type" class="btn btn-secondary">取消</a>
                            <?php endif; ?>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>
</div>

<style>
    .content-wrapper {
        padding: 15px 0;
    }

    .page-header {
        margin-bottom: 20px;
    }

    .room-type-container {
        display: flex;
        flex-wrap: wrap;
        gap: 20px;
    }

    .room-type-list {
        flex: 2;
        min-width: 300px;
    }

    .room-type-form {
        flex: 1;
        min-width: 300px;
    }

    .card {
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
        margin-bottom: 20px;
        overflow: hidden;
    }

    .card-header {
        padding: 15px;
        border-bottom: 1px solid #e9ecef;
        background-color: #f8f9fa;
    }

    .card-header h3 {
        margin: 0;
        font-size: 18px;
        color: #0066cc;
    }

    .card-body {
        padding: 15px;
    }

    .form-group {
        margin-bottom: 15px;
    }

    .form-group label {
        display: block;
        margin-bottom: 5px;
        font-weight: bold;
    }

    .form-row {
        display: flex;
        flex-wrap: wrap;
        margin-right: -10px;
        margin-left: -10px;
    }

    .col-md-6 {
        flex: 0 0 50%;
        max-width: 50%;
        padding-right: 10px;
        padding-left: 10px;
    }

    .required {
        color: #dc3545;
    }

    .form-actions {
        margin-top: 20px;
        display: flex;
        gap: 10px;
    }

    .status-badge {
        display: inline-block;
        padding: 3px 8px;
        border-radius: 4px;
        font-size: 12px;
        color: #fff;
    }

    .status-active {
        background-color: #28a745;
    }

    .status-inactive {
        background-color: #6c757d;
    }

    .actions {
        display: flex;
        gap: 5px;
    }

    .btn-sm {
        padding: 4px 8px;
        font-size: 12px;
    }

    .text-center {
        text-align: center;
    }

    @media (max-width: 768px) {
        .room-type-container {
            flex-direction: column;
        }

        .col-md-6 {
            flex: 0 0 100%;
            max-width: 100%;
        }
    }
</style>