<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 检查用户是否有管理员权限
if ($_SESSION['user_role'] != 'admin') {
    header('Location: ../../home.php');
    exit;
}

require_once '../../config/config.php';
require_once '../../includes/functions.php';

// 确保备份表存在
$sql = "CREATE TABLE IF NOT EXISTS system_backups (
    id INT AUTO_INCREMENT PRIMARY KEY,
    filename VARCHAR(255) NOT NULL,
    backup_time DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    size BIGINT NOT NULL,
    status ENUM('completed', 'failed') NOT NULL,
    note TEXT,
    created_by INT,
    FOREIGN KEY (created_by) REFERENCES users(id) ON DELETE SET NULL
)";
$conn->query($sql);

// 处理备份创建
if (isset($_POST['create_backup'])) {
    try {
        // 创建备份目录
        $backup_dir = '../../backups';
        if (!file_exists($backup_dir)) {
            mkdir($backup_dir, 0755, true);
        }

        // 生成备份文件名
        $timestamp = date('Y-m-d_His');
        $backup_file = $backup_dir . '/backup_' . $timestamp . '.sql';

        // 获取数据库配置
        $db_host = DB_HOST;
        $db_name = DB_NAME;
        $db_user = DB_USER;
        $db_pass = DB_PASS;

        // 执行备份命令
        $command = sprintf(
            'mysqldump --host=%s --user=%s --password=%s %s > %s',
            escapeshellarg($db_host),
            escapeshellarg($db_user),
            escapeshellarg($db_pass),
            escapeshellarg($db_name),
            escapeshellarg($backup_file)
        );

        exec($command, $output, $return_var);

        if ($return_var === 0) {
            // 获取文件大小
            $size = filesize($backup_file);

            // 记录备份信息到数据库
            $query = "INSERT INTO system_backups (filename, size, status, created_by) VALUES (?, ?, 'completed', ?)";
            $stmt = $conn->prepare($query);
            if ($stmt) {
                $filename = basename($backup_file);
                $stmt->bind_param("sii", $filename, $size, $_SESSION['user_id']);
                $stmt->execute();
                $stmt->close();

                // 记录操作日志
                logSystemAction($_SESSION['user_id'], "创建了系统备份：" . $filename);

                $success_message = "备份创建成功！";
            } else {
                throw new Exception("数据库查询准备失败：" . $conn->error);
            }
        } else {
            throw new Exception("备份命令执行失败");
        }
    } catch (Exception $e) {
        $error_message = "备份创建失败：" . $e->getMessage();

        // 记录失败信息到数据库
        $query = "INSERT INTO system_backups (filename, size, status, note, created_by) VALUES (?, 0, 'failed', ?, ?)";
        $stmt = $conn->prepare($query);
        if ($stmt) {
            $filename = 'backup_' . $timestamp . '.sql';
            $error_note = $e->getMessage();
            $stmt->bind_param("ssi", $filename, $error_note, $_SESSION['user_id']);
            $stmt->execute();
            $stmt->close();
        }
    }
}

// 处理备份删除
if (isset($_POST['delete_backup'])) {
    $backup_id = isset($_POST['backup_id']) ? intval($_POST['backup_id']) : 0;
    if ($backup_id > 0) {
        try {
            $query = "SELECT filename FROM system_backups WHERE id = ?";
            $stmt = $conn->prepare($query);
            if (!$stmt) {
                throw new Exception("数据库查询准备失败：" . $conn->error);
            }

            $stmt->bind_param("i", $backup_id);
            $stmt->execute();
            $result = $stmt->get_result();
            $stmt->close();

            if ($backup = $result->fetch_assoc()) {
                $backup_file = '../../backups/' . $backup['filename'];

                // 删除文件
                if (file_exists($backup_file)) {
                    unlink($backup_file);
                }

                // 删除数据库记录
                $query = "DELETE FROM system_backups WHERE id = ?";
                $stmt = $conn->prepare($query);
                if (!$stmt) {
                    throw new Exception("数据库查询准备失败：" . $conn->error);
                }

                $stmt->bind_param("i", $backup_id);
                $stmt->execute();
                $stmt->close();

                // 记录操作日志
                logSystemAction($_SESSION['user_id'], "删除了系统备份：" . $backup['filename']);

                $success_message = "备份删除成功！";
            } else {
                $error_message = "找不到指定的备份文件！";
            }
        } catch (Exception $e) {
            $error_message = "备份删除失败：" . $e->getMessage();
        }
    } else {
        $error_message = "无效的备份ID！";
    }
}

// 处理备份恢复
if (isset($_POST['restore_backup'])) {
    $backup_id = isset($_POST['backup_id']) ? intval($_POST['backup_id']) : 0;
    if ($backup_id > 0) {
        try {
            $query = "SELECT filename FROM system_backups WHERE id = ?";
            $stmt = $conn->prepare($query);
            if (!$stmt) {
                throw new Exception("数据库查询准备失败：" . $conn->error);
            }

            $stmt->bind_param("i", $backup_id);
            $stmt->execute();
            $result = $stmt->get_result();
            $stmt->close();

            if ($backup = $result->fetch_assoc()) {
                $backup_file = '../../backups/' . $backup['filename'];

                if (file_exists($backup_file)) {
                    // 获取数据库配置
                    $db_host = DB_HOST;
                    $db_name = DB_NAME;
                    $db_user = DB_USER;
                    $db_pass = DB_PASS;

                    // 执行恢复命令
                    $command = sprintf(
                        'mysql --host=%s --user=%s --password=%s %s < %s',
                        escapeshellarg($db_host),
                        escapeshellarg($db_user),
                        escapeshellarg($db_pass),
                        escapeshellarg($db_name),
                        escapeshellarg($backup_file)
                    );

                    exec($command, $output, $return_var);

                    if ($return_var === 0) {
                        // 记录操作日志
                        logSystemAction($_SESSION['user_id'], "恢复了系统备份：" . $backup['filename']);

                        $success_message = "备份恢复成功！";
                    } else {
                        throw new Exception("恢复命令执行失败");
                    }
                } else {
                    throw new Exception("备份文件不存在");
                }
            } else {
                $error_message = "找不到指定的备份文件！";
            }
        } catch (Exception $e) {
            $error_message = "备份恢复失败：" . $e->getMessage();
        }
    } else {
        $error_message = "无效的备份ID！";
    }
}

// 获取备份列表
$backups = [];
$result = $conn->query("SELECT b.*, u.username FROM system_backups b LEFT JOIN users u ON b.created_by = u.id ORDER BY b.backup_time DESC");
if ($result) {
    while ($row = $result->fetch_assoc()) {
        $backups[] = $row;
    }
}
?>

<div class="content">
    <?php if (isset($success_message)): ?>
        <div class="alert alert-success"><?php echo $success_message; ?></div>
    <?php endif; ?>
    <?php if (isset($error_message)): ?>
        <div class="alert alert-danger"><?php echo $error_message; ?></div>
    <?php endif; ?>

    <!-- 操作按钮 -->
    <div class="action-buttons mb-4">
        <form method="post" style="display: inline;">
            <button type="submit" name="create_backup" class="btn btn-primary">创建备份</button>
        </form>
    </div>

    <!-- 备份列表 -->
    <div class="card">
        <div class="card-header">
            <h3>系统备份</h3>
        </div>
        <div class="card-body">
            <?php if (count($backups) > 0): ?>
                <div class="table-responsive">
                    <table class="table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>文件名</th>
                                <th>备份时间</th>
                                <th>大小</th>
                                <th>状态</th>
                                <th>创建者</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($backups as $backup): ?>
                                <tr>
                                    <td><?php echo $backup['id']; ?></td>
                                    <td><?php echo htmlspecialchars($backup['filename']); ?></td>
                                    <td><?php echo date('Y-m-d H:i:s', strtotime($backup['backup_time'])); ?></td>
                                    <td><?php echo formatBytes($backup['size']); ?></td>
                                    <td>
                                        <?php if ($backup['status'] == 'completed'): ?>
                                            <span class="badge badge-success">完成</span>
                                        <?php else: ?>
                                            <span class="badge badge-danger" title="<?php echo htmlspecialchars($backup['note']); ?>">失败</span>
                                        <?php endif; ?>
                                    </td>
                                    <td><?php echo htmlspecialchars($backup['username'] ?? '未知'); ?></td>
                                    <td>
                                        <?php if ($backup['status'] == 'completed'): ?>
                                            <button type="button" class="btn btn-sm btn-warning"
                                                onclick="confirmRestore(<?php echo $backup['id']; ?>, '<?php echo htmlspecialchars($backup['filename']); ?>')">
                                                恢复
                                            </button>
                                        <?php endif; ?>
                                        <button type="button" class="btn btn-sm btn-danger"
                                            onclick="confirmDelete(<?php echo $backup['id']; ?>, '<?php echo htmlspecialchars($backup['filename']); ?>')">
                                            删除
                                        </button>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            <?php else: ?>
                <div class="alert alert-info">暂无备份记录</div>
            <?php endif; ?>
        </div>
    </div>
</div>

<!-- 恢复确认模态框 -->
<div class="modal fade" id="restoreModal" tabindex="-1" role="dialog" style="display: none;">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">确认恢复</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <form method="post">
                <div class="modal-body">
                    <input type="hidden" name="backup_id" id="restore_backup_id">
                    <p>您确定要恢复备份文件 <strong id="restore_filename"></strong> 吗？</p>
                    <div class="alert alert-warning">
                        <i class="fas fa-exclamation-triangle"></i>
                        警告：此操作将覆盖当前数据库中的所有数据，请谨慎操作！
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-dismiss="modal">取消</button>
                    <button type="submit" name="restore_backup" class="btn btn-warning">确认恢复</button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- 删除确认模态框 -->
<div class="modal fade" id="deleteModal" tabindex="-1" role="dialog" style="display: none;">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">确认删除</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <form method="post">
                <div class="modal-body">
                    <input type="hidden" name="backup_id" id="delete_backup_id">
                    <p>您确定要删除备份文件 <strong id="delete_filename"></strong> 吗？</p>
                    <div class="alert alert-danger">
                        <i class="fas fa-exclamation-triangle"></i>
                        警告：此操作不可恢复！
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-dismiss="modal">取消</button>
                    <button type="submit" name="delete_backup" class="btn btn-danger">确认删除</button>
                </div>
            </form>
        </div>
    </div>
</div>

<style>
    .action-buttons {
        margin-bottom: 20px;
    }

    .action-buttons .btn {
        margin-right: 10px;
    }

    .badge {
        padding: 5px 10px;
        border-radius: 4px;
    }

    .badge-success {
        background-color: #28a745;
        color: white;
    }

    .badge-danger {
        background-color: #dc3545;
        color: white;
    }

    .btn-sm {
        padding: 0.25rem 0.5rem;
        font-size: 0.875rem;
        margin-right: 5px;
    }

    @media (max-width: 768px) {
        .table-responsive {
            margin-bottom: 15px;
            overflow-y: hidden;
            -ms-overflow-style: -ms-autohiding-scrollbar;
            border: 1px solid #dee2e6;
        }
    }
</style>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 确保jQuery和Bootstrap已加载
        if (typeof jQuery !== 'undefined' && typeof jQuery.fn.modal !== 'undefined') {
            console.log('jQuery和Bootstrap已正确加载');
            // 初始化并隐藏模态框
            jQuery('#restoreModal').modal('hide');
            jQuery('#deleteModal').modal('hide');
        } else {
            console.error('jQuery或Bootstrap未正确加载，模态框可能无法正常工作');
        }
    });

    function confirmRestore(id, filename) {
        console.log('正在尝试显示恢复模态框，ID: ' + id + ', 文件名: ' + filename);
        if (document.getElementById('restore_backup_id')) {
            document.getElementById('restore_backup_id').value = id;
        }
        if (document.getElementById('restore_filename')) {
            document.getElementById('restore_filename').innerText = filename;
        }

        if (typeof jQuery !== 'undefined' && typeof jQuery.fn.modal !== 'undefined') {
            jQuery('#restoreModal').modal('show');
        } else {
            alert('无法显示模态框：jQuery或Bootstrap未正确加载');
        }
    }

    function confirmDelete(id, filename) {
        console.log('正在尝试显示删除模态框，ID: ' + id + ', 文件名: ' + filename);
        if (document.getElementById('delete_backup_id')) {
            document.getElementById('delete_backup_id').value = id;
        }
        if (document.getElementById('delete_filename')) {
            document.getElementById('delete_filename').innerText = filename;
        }

        if (typeof jQuery !== 'undefined' && typeof jQuery.fn.modal !== 'undefined') {
            jQuery('#deleteModal').modal('show');
        } else {
            alert('无法显示模态框：jQuery或Bootstrap未正确加载');
        }
    }
</script>

<?php
// 辅助函数：格式化文件大小
function formatBytes($bytes, $precision = 2)
{
    $units = array('B', 'KB', 'MB', 'GB', 'TB');
    $bytes = max($bytes, 0);
    $pow = floor(($bytes ? log($bytes) : 0) / log(1024));
    $pow = min($pow, count($units) - 1);
    return round($bytes / pow(1024, $pow), $precision) . ' ' . $units[$pow];
}
