<?php
// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 检查用户是否有管理员权限
if ($_SESSION['user_role'] != 'admin') {
    header('Location: ../../home.php');
    exit;
}

require_once '../../config/config.php';
require_once '../../includes/functions.php';

// 处理添加/编辑管理员
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['save_user'])) {
    $id = isset($_POST['id']) ? intval($_POST['id']) : 0;
    $username = trim($_POST['username']);
    $password = isset($_POST['password']) && !empty($_POST['password']) ? password_hash($_POST['password'], PASSWORD_DEFAULT) : '';
    $email = trim($_POST['email']);
    $role = $_POST['role'];
    $status = $_POST['status'];

    // 验证数据
    $errors = [];
    if (empty($username)) {
        $errors[] = "用户名不能为空";
    }
    if ($id == 0 && empty($password)) {
        $errors[] = "新管理员必须设置密码";
    }
    if (empty($email)) {
        $errors[] = "邮箱不能为空";
    } elseif (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
        $errors[] = "邮箱格式不正确";
    }

    // 检查用户名是否已存在
    if (empty($errors)) {
        $checkStmt = $conn->prepare("SELECT id FROM users WHERE username = ? AND id != ?");
        $checkStmt->bind_param("si", $username, $id);
        $checkStmt->execute();
        $checkResult = $checkStmt->get_result();
        if ($checkResult->num_rows > 0) {
            $errors[] = "用户名 '{$username}' 已被使用";
        }
        $checkStmt->close();
    }

    if (empty($errors)) {
        try {
            if ($id > 0) {
                // 更新现有管理员
                if (!empty($password)) {
                    $stmt = $conn->prepare("UPDATE users SET username = ?, password = ?, email = ?, role = ?, status = ?, updated_at = NOW() WHERE id = ?");
                    $stmt->bind_param("sssssi", $username, $password, $email, $role, $status, $id);
                } else {
                    $stmt = $conn->prepare("UPDATE users SET username = ?, email = ?, role = ?, status = ?, updated_at = NOW() WHERE id = ?");
                    $stmt->bind_param("ssssi", $username, $email, $role, $status, $id);
                }

                if (!$stmt->execute()) {
                    throw new Exception("更新失败: " . $stmt->error);
                }

                $stmt->close();
                $success_message = "管理员信息更新成功！";

                // 记录日志
                logSystemAction($_SESSION['user_id'], "更新管理员信息：{$username}");
            } else {
                // 添加新管理员
                // 检查是否有created_at字段
                $checkFieldsQuery = "SHOW COLUMNS FROM users LIKE 'created_at'";
                $checkFieldsResult = $conn->query($checkFieldsQuery);
                $hasCreatedAtField = $checkFieldsResult->num_rows > 0;

                // 检查是否有name字段
                $checkNameQuery = "SHOW COLUMNS FROM users LIKE 'name'";
                $checkNameResult = $conn->query($checkNameQuery);
                $hasNameField = $checkNameResult->num_rows > 0;

                // 准备添加用户的SQL
                if ($hasNameField) {
                    // 如果有name字段，添加name值（使用username作为默认值）
                    if ($hasCreatedAtField) {
                        $stmt = $conn->prepare("INSERT INTO users (username, password, email, role, status, name, created_at, updated_at) VALUES (?, ?, ?, ?, ?, ?, NOW(), NOW())");
                        $stmt->bind_param("ssssss", $username, $password, $email, $role, $status, $username);
                    } else {
                        $stmt = $conn->prepare("INSERT INTO users (username, password, email, role, status, name) VALUES (?, ?, ?, ?, ?, ?)");
                        $stmt->bind_param("ssssss", $username, $password, $email, $role, $status, $username);
                    }
                } else {
                    // 如果没有name字段，使用原来的SQL
                    if ($hasCreatedAtField) {
                        $stmt = $conn->prepare("INSERT INTO users (username, password, email, role, status, created_at, updated_at) VALUES (?, ?, ?, ?, ?, NOW(), NOW())");
                        $stmt->bind_param("sssss", $username, $password, $email, $role, $status);
                    } else {
                        $stmt = $conn->prepare("INSERT INTO users (username, password, email, role, status) VALUES (?, ?, ?, ?, ?)");
                        $stmt->bind_param("sssss", $username, $password, $email, $role, $status);
                    }
                }

                if (!$stmt->execute()) {
                    throw new Exception("添加失败: " . $stmt->error);
                }

                $newId = $stmt->insert_id;
                $stmt->close();

                if ($newId) {
                    $success_message = "新管理员添加成功！ID: " . $newId;

                    // 记录日志
                    logSystemAction($_SESSION['user_id'], "添加新管理员：{$username}");
                } else {
                    throw new Exception("添加成功但未返回ID");
                }
            }

            // 强制刷新列表
            $users = [];
            $result = $conn->query("SELECT * FROM users WHERE role = 'admin' OR role = 'super_admin' ORDER BY id DESC");
            if ($result) {
                while ($row = $result->fetch_assoc()) {
                    $users[] = $row;
                }
            }
        } catch (Exception $e) {
            $error_message = "操作失败：" . $e->getMessage();
        }
    } else {
        $error_message = "表单错误：" . implode(", ", $errors);
    }
}

// 处理删除管理员 - POST方式（模态框提交）
if (isset($_POST['delete_user']) && isset($_POST['user_id'])) {
    $user_id = intval($_POST['user_id']);

    // 防止删除自己
    if ($user_id == $_SESSION['user_id']) {
        $error_message = "不能删除当前登录的管理员账号！";
    } else {
        try {
            // 获取要删除的用户名
            $stmt = $conn->prepare("SELECT username FROM users WHERE id = ?");
            $stmt->bind_param("i", $user_id);
            $stmt->execute();
            $result = $stmt->get_result();
            if ($row = $result->fetch_assoc()) {
                $username = $row['username'];

                // 执行删除
                $stmt = $conn->prepare("DELETE FROM users WHERE id = ?");
                $stmt->bind_param("i", $user_id);
                $stmt->execute();
                $success_message = "管理员删除成功！";

                // 记录日志
                logSystemAction($_SESSION['user_id'], "删除管理员：{$username}");

                // 强制刷新列表
                $users = [];
                $result = $conn->query("SELECT * FROM users WHERE role = 'admin' OR role = 'super_admin' ORDER BY id DESC");
                if ($result) {
                    while ($row = $result->fetch_assoc()) {
                        $users[] = $row;
                    }
                }
            } else {
                $error_message = "找不到指定的管理员账号！";
            }
        } catch (Exception $e) {
            $error_message = "删除失败：" . $e->getMessage();
        }
    }
}

// 处理删除管理员 - GET方式（直接链接）
if (isset($_GET['action']) && $_GET['action'] == 'delete' && isset($_GET['id'])) {
    $id = intval($_GET['id']);

    // 防止删除自己
    if ($id == $_SESSION['user_id']) {
        $error_message = "不能删除当前登录的管理员账号！";
    } else {
        try {
            // 获取要删除的用户名
            $stmt = $conn->prepare("SELECT username FROM users WHERE id = ?");
            $stmt->bind_param("i", $id);
            $stmt->execute();
            $result = $stmt->get_result();
            if ($row = $result->fetch_assoc()) {
                $username = $row['username'];

                // 执行删除
                $stmt = $conn->prepare("DELETE FROM users WHERE id = ?");
                $stmt->bind_param("i", $id);
                $stmt->execute();
                $success_message = "管理员删除成功！";

                // 记录日志
                logSystemAction($_SESSION['user_id'], "删除管理员：{$username}");
            } else {
                $error_message = "找不到指定的管理员账号！";
            }
        } catch (Exception $e) {
            $error_message = "删除失败：" . $e->getMessage();
        }
    }
}

// 获取要编辑的管理员信息
$editing = false;
$user = [
    'username' => '',
    'email' => '',
    'role' => 'admin',
    'status' => 'active'
];

if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $id = intval($_GET['id']);
    $stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
    $stmt->bind_param("i", $id);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        $editing = true;
        $user = $result->fetch_assoc();
    }
}

// 获取所有管理员列表
$users = [];
$result = $conn->query("SELECT * FROM users WHERE role = 'admin' OR role = 'super_admin' ORDER BY id DESC");
if ($result) {
    while ($row = $result->fetch_assoc()) {
        $users[] = $row;
    }
}
?>

<div class="content">
    <?php if (isset($success_message)): ?>
        <div class="alert alert-success"><?php echo $success_message; ?></div>
    <?php endif; ?>
    <?php if (isset($error_message)): ?>
        <div class="alert alert-danger"><?php echo $error_message; ?></div>
    <?php endif; ?>

    <!-- 添加/编辑管理员表单 -->
    <div class="card mb-4">
        <div class="card-header">
            <h3><?php echo $editing ? '编辑管理员' : '添加管理员'; ?></h3>
        </div>
        <div class="card-body">
            <form method="post" action="index.php?page=user_management" id="userForm">
                <?php if ($editing): ?>
                    <input type="hidden" name="id" value="<?php echo $user['id']; ?>">
                <?php endif; ?>

                <div class="form-row">
                    <div class="form-group col-md-6">
                        <label for="username">用户名</label>
                        <input type="text" class="form-control" id="username" name="username"
                            value="<?php echo htmlspecialchars($user['username']); ?>" required>
                    </div>
                    <div class="form-group col-md-6">
                        <label for="password">密码<?php echo $editing ? '（留空表示不修改）' : ''; ?></label>
                        <input type="password" class="form-control" id="password" name="password"
                            <?php echo !$editing ? 'required' : ''; ?>>
                    </div>
                </div>

                <div class="form-row">
                    <div class="form-group col-md-6">
                        <label for="email">邮箱</label>
                        <input type="email" class="form-control" id="email" name="email"
                            value="<?php echo htmlspecialchars($user['email']); ?>" required>
                    </div>
                    <div class="form-group col-md-6">
                        <label for="role">角色</label>
                        <select class="form-control" id="role" name="role" required>
                            <option value="admin" <?php echo $user['role'] == 'admin' ? 'selected' : ''; ?>>管理员</option>
                            <option value="super_admin" <?php echo $user['role'] == 'super_admin' ? 'selected' : ''; ?>>超级管理员</option>
                        </select>
                    </div>
                </div>

                <div class="form-group">
                    <label for="status">状态</label>
                    <select class="form-control" id="status" name="status" required>
                        <option value="active" <?php echo $user['status'] == 'active' ? 'selected' : ''; ?>>启用</option>
                        <option value="inactive" <?php echo $user['status'] == 'inactive' ? 'selected' : ''; ?>>停用</option>
                    </select>
                </div>

                <button type="submit" name="save_user" class="btn btn-primary"><?php echo $editing ? '更新' : '添加'; ?></button>
                <?php if ($editing): ?>
                    <a href="index.php?page=user_management" class="btn btn-secondary">取消</a>
                <?php endif; ?>
            </form>
        </div>
    </div>

    <!-- 管理员列表 -->
    <div class="card">
        <div class="card-header">
            <h3>管理员列表</h3>
        </div>
        <div class="card-body">
            <?php if (count($users) > 0): ?>
                <div class="table-responsive">
                    <table class="table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>用户名</th>
                                <th>邮箱</th>
                                <th>角色</th>
                                <th>状态</th>
                                <th>最后登录</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($users as $u): ?>
                                <tr>
                                    <td><?php echo $u['id']; ?></td>
                                    <td><?php echo htmlspecialchars($u['username']); ?></td>
                                    <td><?php echo htmlspecialchars($u['email']); ?></td>
                                    <td><?php echo $u['role'] == 'super_admin' ? '超级管理员' : '管理员'; ?></td>
                                    <td>
                                        <span class="status-badge <?php echo $u['status']; ?>">
                                            <?php echo $u['status'] == 'active' ? '启用' : '停用'; ?>
                                        </span>
                                    </td>
                                    <td>
                                        <?php echo $u['last_login'] ? date('Y-m-d H:i', strtotime($u['last_login'])) : '从未登录'; ?>
                                    </td>
                                    <td>
                                        <div class="btn-group">
                                            <a href="index.php?page=user_management&action=edit&id=<?php echo $u['id']; ?>"
                                                class="btn btn-sm btn-primary">编辑</a>
                                            <?php if ($u['id'] != $_SESSION['user_id']): ?>
                                                <button type="button" class="btn btn-sm btn-danger"
                                                    onclick="deleteUser(<?php echo $u['id']; ?>, '<?php echo htmlspecialchars($u['username']); ?>')">
                                                    删除
                                                </button>
                                            <?php endif; ?>
                                        </div>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            <?php else: ?>
                <div class="alert alert-info">暂无管理员记录</div>
            <?php endif; ?>
        </div>
    </div>
</div>

<!-- 删除确认模态框 -->
<div class="modal fade" id="deleteUserModal" tabindex="-1" role="dialog" style="display: none;">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">确认删除</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <form method="post">
                <div class="modal-body">
                    <input type="hidden" name="user_id" id="delete_user_id">
                    <p>您确定要删除管理员 <strong id="delete_username"></strong> 吗？</p>
                    <div class="alert alert-danger">
                        <i class="fas fa-exclamation-triangle"></i>
                        警告：此操作不可恢复！
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-dismiss="modal">取消</button>
                    <button type="submit" name="delete_user" class="btn btn-danger">确认删除</button>
                </div>
            </form>
        </div>
    </div>
</div>

<style>
    .status-badge {
        display: inline-block;
        padding: 4px 8px;
        border-radius: 4px;
        font-size: 0.8rem;
    }

    .status-badge.active {
        background-color: #d4edda;
        color: #155724;
    }

    .status-badge.inactive {
        background-color: #f8d7da;
        color: #721c24;
    }

    .btn-group {
        display: flex;
        gap: 5px;
    }

    .form-row {
        display: flex;
        flex-wrap: wrap;
        margin-right: -5px;
        margin-left: -5px;
        margin-bottom: 15px;
    }

    .form-group {
        margin-bottom: 1rem;
    }

    .col-md-6 {
        flex: 0 0 50%;
        max-width: 50%;
        padding-right: 5px;
        padding-left: 5px;
    }

    @media (max-width: 768px) {
        .col-md-6 {
            flex: 0 0 100%;
            max-width: 100%;
        }
    }
</style>

<script>
    document.addEventListener('DOMContentLoaded', function() {
        // 确保jQuery和Bootstrap已加载
        if (typeof jQuery !== 'undefined' && typeof jQuery.fn.modal !== 'undefined') {
            console.log('jQuery和Bootstrap已正确加载');
            // 初始化并隐藏模态框
            jQuery('#deleteUserModal').modal('hide');
        } else {
            console.error('jQuery或Bootstrap未正确加载，模态框可能无法正常工作');
        }

        // 表单验证
        jQuery('#userForm').submit(function(e) {
            var password = jQuery('#password').val();
            if (!<?php echo $editing ? 'true' : 'false'; ?> && password.length < 6) {
                alert('密码长度必须至少为6个字符！');
                e.preventDefault();
                return false;
            }
            return true;
        });
    });

    function deleteUser(id, username) {
        console.log('正在尝试显示删除用户模态框，ID: ' + id + ', 用户名: ' + username);
        if (document.getElementById('delete_user_id')) {
            document.getElementById('delete_user_id').value = id;
        }
        if (document.getElementById('delete_username')) {
            document.getElementById('delete_username').innerText = username;
        }

        if (typeof jQuery !== 'undefined' && typeof jQuery.fn.modal !== 'undefined') {
            jQuery('#deleteUserModal').modal('show');
        } else {
            alert('无法显示模态框：jQuery或Bootstrap未正确加载');
        }
    }
</script>