<?php
require_once '../../config/config.php';
require_once '../../includes/functions.php';

// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../../login.php');
    exit;
}

// 确保数据表存在
$sql = "SHOW TABLES LIKE 'tourism_services'";
$tableExistsResult = $conn->query($sql);
if ($tableExistsResult->num_rows == 0) {
    // 如果表不存在，创建表
    $conn->query("CREATE TABLE IF NOT EXISTS tourism_services (
        id INT AUTO_INCREMENT PRIMARY KEY,
        name VARCHAR(100) NOT NULL,
        category ENUM(
            'ticket',
            'transport',
            'guide',
            'activity',
            'other'
        ) NOT NULL,
        description TEXT,
        price DECIMAL(10, 2) NOT NULL,
        commission_rate DECIMAL(5, 2) DEFAULT 0.00,
        provider VARCHAR(100),
        contact_info TEXT,
        status ENUM('active', 'inactive') NOT NULL DEFAULT 'active',
        created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
        updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
    ) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;");
}

$sql = "SHOW TABLES LIKE 'tourism_bookings'";
$tableExistsResult = $conn->query($sql);
if ($tableExistsResult->num_rows == 0) {
    // 如果表不存在，创建表
    $conn->query("CREATE TABLE IF NOT EXISTS tourism_bookings (
        id INT AUTO_INCREMENT PRIMARY KEY,
        service_id INT NOT NULL,
        booking_id INT,
        member_id INT,
        guest_name VARCHAR(100) NOT NULL,
        guest_phone VARCHAR(20) NOT NULL,
        service_date DATE NOT NULL,
        service_time TIME,
        quantity INT NOT NULL DEFAULT 1,
        total_price DECIMAL(12, 2) NOT NULL,
        payment_status ENUM('unpaid', 'paid', 'refunded') NOT NULL DEFAULT 'unpaid',
        status ENUM('pending', 'confirmed', 'completed', 'cancelled') NOT NULL DEFAULT 'pending',
        notes TEXT,
        created_by INT,
        created_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
        updated_at DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
        FOREIGN KEY (service_id) REFERENCES tourism_services(id) ON DELETE RESTRICT
    ) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4;");
}

// 获取各类旅游服务数量
$sql = "SELECT category, COUNT(*) as count FROM tourism_services WHERE status = 'active' GROUP BY category";
$result = $conn->query($sql);
$serviceStats = [];
while ($row = $result->fetch_assoc()) {
    $serviceStats[$row['category']] = $row['count'];
}

// 获取默认值，确保所有类别都有值
$serviceTypes = ['ticket' => '景区门票', 'transport' => '租车服务', 'guide' => '本地导游', 'activity' => '特色活动', 'other' => '其他服务'];
foreach ($serviceTypes as $key => $value) {
    if (!isset($serviceStats[$key])) {
        $serviceStats[$key] = 0;
    }
}

// 获取未处理的预订数量
$pendingBookings = 0;
$stmt = $conn->prepare("SELECT COUNT(*) FROM tourism_bookings WHERE status = 'pending'");
if ($stmt) {
    $stmt->execute();
    $stmt->bind_result($pendingBookings);
    $stmt->fetch();
    $stmt->close();
} else {
    $pendingBookings = 0;
}

// 获取本月收入
$monthlyRevenue = 0;
$firstDayOfMonth = date('Y-m-01');
$lastDayOfMonth = date('Y-m-t');
$stmt = $conn->prepare("SELECT SUM(total_price) FROM tourism_bookings WHERE status IN ('confirmed', 'completed') AND payment_status = 'paid' AND created_at BETWEEN ? AND ?");
if ($stmt) {
    $stmt->bind_param("ss", $firstDayOfMonth, $lastDayOfMonth);
    $stmt->execute();
    $stmt->bind_result($monthlyRevenue);
    $stmt->fetch();
    $stmt->close();
}
$monthlyRevenue = $monthlyRevenue ? $monthlyRevenue : 0;

// 获取最近预订
$recentBookings = [];
$query = "SELECT tb.id, tb.guest_name, tb.service_date, tb.total_price, tb.status, tb.payment_status, 
                 ts.name as service_name, ts.category
          FROM tourism_bookings tb
          JOIN tourism_services ts ON tb.service_id = ts.id
          ORDER BY tb.created_at DESC LIMIT 5";
$result = $conn->query($query);
if ($result && $result !== false) {
    while ($row = $result->fetch_assoc()) {
        $recentBookings[] = $row;
    }
}

// 获取热门服务
$popularServices = [];
$query = "SELECT ts.id, ts.name, ts.category, ts.price, COUNT(tb.id) as booking_count
          FROM tourism_services ts
          LEFT JOIN tourism_bookings tb ON ts.id = tb.service_id
          WHERE ts.status = 'active'
          GROUP BY ts.id
          ORDER BY booking_count DESC
          LIMIT 5";
$result = $conn->query($query);
if ($result && $result !== false) {
    while ($row = $result->fetch_assoc()) {
        $popularServices[] = $row;
    }
}
?>

<div class="dashboard">
    <!-- 统计卡片 -->
    <div class="stats-cards">
        <div class="stat-card">
            <div class="stat-card-value"><?php echo array_sum($serviceStats); ?></div>
            <div class="stat-card-title">服务总数</div>
        </div>
        <div class="stat-card">
            <div class="stat-card-value"><?php echo $pendingBookings; ?></div>
            <div class="stat-card-title">未处理预订</div>
        </div>
        <div class="stat-card">
            <div class="stat-card-value">¥<?php echo number_format($monthlyRevenue, 2); ?></div>
            <div class="stat-card-title">本月收入</div>
        </div>
    </div>

    <!-- 服务类型统计 -->
    <div class="card mb-4">
        <div class="card-header">
            <h3>服务类型统计</h3>
        </div>
        <div class="card-body">
            <div class="service-stats">
                <?php foreach ($serviceTypes as $key => $label): ?>
                    <div class="service-stat-item">
                        <div class="service-stat-label"><?php echo $label; ?></div>
                        <div class="service-stat-bar">
                            <div class="service-stat-fill" style="width: <?php echo $serviceStats[$key] > 0 ? min(100, ($serviceStats[$key] / max(1, array_sum($serviceStats))) * 100) : 0; ?>%"></div>
                        </div>
                        <div class="service-stat-value"><?php echo $serviceStats[$key]; ?></div>
                    </div>
                <?php endforeach; ?>
            </div>
        </div>
    </div>

    <div class="row">
        <!-- 最近预订 -->
        <div class="col-md-6">
            <div class="card mb-4">
                <div class="card-header">
                    <h3>最近预订</h3>
                </div>
                <div class="card-body">
                    <?php if (count($recentBookings) > 0): ?>
                        <div class="table-responsive">
                            <table class="table">
                                <thead>
                                    <tr>
                                        <th>预订ID</th>
                                        <th>客户</th>
                                        <th>服务</th>
                                        <th>日期</th>
                                        <th>状态</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($recentBookings as $booking): ?>
                                        <tr>
                                            <td><?php echo $booking['id']; ?></td>
                                            <td><?php echo htmlspecialchars($booking['guest_name']); ?></td>
                                            <td><?php echo htmlspecialchars($booking['service_name']); ?></td>
                                            <td><?php echo date('Y-m-d', strtotime($booking['service_date'])); ?></td>
                                            <td>
                                                <span class="status-badge <?php echo $booking['status']; ?>">
                                                    <?php echo getBookingStatusName($booking['status']); ?>
                                                </span>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    <?php else: ?>
                        <div class="alert alert-info">暂无预订记录</div>
                    <?php endif; ?>
                </div>
            </div>
        </div>

        <!-- 热门服务 -->
        <div class="col-md-6">
            <div class="card mb-4">
                <div class="card-header">
                    <h3>热门服务</h3>
                </div>
                <div class="card-body">
                    <?php if (count($popularServices) > 0): ?>
                        <div class="table-responsive">
                            <table class="table">
                                <thead>
                                    <tr>
                                        <th>服务名称</th>
                                        <th>类型</th>
                                        <th>价格</th>
                                        <th>预订次数</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($popularServices as $service): ?>
                                        <tr>
                                            <td><?php echo htmlspecialchars($service['name']); ?></td>
                                            <td><?php echo getServiceCategoryName($service['category']); ?></td>
                                            <td>¥<?php echo number_format($service['price'], 2); ?></td>
                                            <td><?php echo $service['booking_count']; ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    <?php else: ?>
                        <div class="alert alert-info">暂无服务数据</div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>

    <!-- 快速链接 -->
    <div class="quick-links">
        <a href="index.php?page=ticket" class="quick-link-card">
            <div class="quick-link-icon ticket-icon">🎫</div>
            <div class="quick-link-title">景区门票预订</div>
        </a>
        <a href="index.php?page=car_rental" class="quick-link-card">
            <div class="quick-link-icon car-icon">🚗</div>
            <div class="quick-link-title">租车服务</div>
        </a>
        <a href="index.php?page=guide" class="quick-link-card">
            <div class="quick-link-icon guide-icon">🧭</div>
            <div class="quick-link-title">本地导游</div>
        </a>
        <a href="index.php?page=activity" class="quick-link-card">
            <div class="quick-link-icon activity-icon">🏕️</div>
            <div class="quick-link-title">特色活动</div>
        </a>
    </div>
</div>

<style>
    .dashboard {
        padding: 15px;
    }

    .stats-cards {
        display: flex;
        gap: 20px;
        margin-bottom: 20px;
    }

    .stat-card {
        flex: 1;
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        padding: 20px;
        text-align: center;
    }

    .stat-card-value {
        font-size: 24px;
        font-weight: bold;
        margin-bottom: 5px;
    }

    .stat-card-title {
        color: #6c757d;
        font-size: 14px;
    }

    .service-stats {
        padding: 10px;
    }

    .service-stat-item {
        display: flex;
        align-items: center;
        margin-bottom: 12px;
    }

    .service-stat-label {
        width: 120px;
        text-align: right;
        padding-right: 15px;
    }

    .service-stat-bar {
        flex-grow: 1;
        height: 20px;
        background-color: #e9ecef;
        border-radius: 3px;
        overflow: hidden;
    }

    .service-stat-fill {
        height: 100%;
        background-color: #007bff;
    }

    .service-stat-value {
        width: 50px;
        padding-left: 15px;
        text-align: left;
    }

    .row {
        display: flex;
        flex-wrap: wrap;
        margin: 0 -10px;
    }

    .col-md-6 {
        flex: 0 0 50%;
        max-width: 50%;
        padding: 0 10px;
    }

    .quick-links {
        display: flex;
        gap: 15px;
        margin-top: 20px;
    }

    .quick-link-card {
        flex: 1;
        background-color: #fff;
        border-radius: 8px;
        box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
        padding: 20px;
        text-align: center;
        text-decoration: none;
        color: #333;
        transition: transform 0.2s;
    }

    .quick-link-card:hover {
        transform: translateY(-5px);
    }

    .quick-link-icon {
        font-size: 32px;
        margin-bottom: 10px;
    }

    .status-badge {
        display: inline-block;
        padding: 3px 8px;
        border-radius: 3px;
        font-size: 12px;
    }

    .status-badge.pending {
        background-color: #ffeeba;
        color: #856404;
    }

    .status-badge.confirmed {
        background-color: #d4edda;
        color: #155724;
    }

    .status-badge.completed {
        background-color: #c3e6cb;
        color: #155724;
    }

    .status-badge.cancelled {
        background-color: #f8d7da;
        color: #721c24;
    }

    @media (max-width: 768px) {
        .stats-cards {
            flex-direction: column;
        }

        .col-md-6 {
            flex: 0 0 100%;
            max-width: 100%;
        }

        .quick-links {
            flex-wrap: wrap;
        }

        .quick-link-card {
            flex: 0 0 calc(50% - 15px);
        }
    }
</style>

<?php
function getServiceCategoryName($category)
{
    $categories = [
        'ticket' => '景区门票',
        'transport' => '租车服务',
        'guide' => '本地导游',
        'activity' => '特色活动',
        'other' => '其他服务'
    ];
    return isset($categories[$category]) ? $categories[$category] : $category;
}

function getBookingStatusName($status)
{
    $statuses = [
        'pending' => '待确认',
        'confirmed' => '已确认',
        'completed' => '已完成',
        'cancelled' => '已取消'
    ];
    return isset($statuses[$status]) ? $statuses[$status] : $status;
}
?>